
// this file was generated by codegen.py

// __AVR_LIBC_VERSION_STRING__ = "1.8.0"
// __AVR_LIBC_DATE_STRING__ = "20111228"
            

#ifdef AC0CON
    DEFINE(AC0CON)
#else
    MISSING(AC0CON)
#endif

#ifdef AC1CON
    DEFINE(AC1CON)
#else
    MISSING(AC1CON)
#endif

#ifdef AC1ECON
    DEFINE(AC1ECON)
#else
    MISSING(AC1ECON)
#endif

#ifdef AC2CON
    DEFINE(AC2CON)
#else
    MISSING(AC2CON)
#endif

#ifdef AC2ECON
    DEFINE(AC2ECON)
#else
    MISSING(AC2ECON)
#endif

#ifdef AC3CON
    DEFINE(AC3CON)
#else
    MISSING(AC3CON)
#endif

#ifdef AC3ECON
    DEFINE(AC3ECON)
#else
    MISSING(AC3ECON)
#endif

#ifdef ACA_AC0CTRL
    DEFINE(ACA_AC0CTRL)
#else
    MISSING(ACA_AC0CTRL)
#endif

#ifdef ACA_AC0MUXCTRL
    DEFINE(ACA_AC0MUXCTRL)
#else
    MISSING(ACA_AC0MUXCTRL)
#endif

#ifdef ACA_AC1CTRL
    DEFINE(ACA_AC1CTRL)
#else
    MISSING(ACA_AC1CTRL)
#endif

#ifdef ACA_AC1MUXCTRL
    DEFINE(ACA_AC1MUXCTRL)
#else
    MISSING(ACA_AC1MUXCTRL)
#endif

#ifdef ACA_CTRLA
    DEFINE(ACA_CTRLA)
#else
    MISSING(ACA_CTRLA)
#endif

#ifdef ACA_CTRLB
    DEFINE(ACA_CTRLB)
#else
    MISSING(ACA_CTRLB)
#endif

#ifdef ACA_STATUS
    DEFINE(ACA_STATUS)
#else
    MISSING(ACA_STATUS)
#endif

#ifdef ACA_WINCTRL
    DEFINE(ACA_WINCTRL)
#else
    MISSING(ACA_WINCTRL)
#endif

#ifdef ACB_AC0CTRL
    DEFINE(ACB_AC0CTRL)
#else
    MISSING(ACB_AC0CTRL)
#endif

#ifdef ACB_AC0MUXCTRL
    DEFINE(ACB_AC0MUXCTRL)
#else
    MISSING(ACB_AC0MUXCTRL)
#endif

#ifdef ACB_AC1CTRL
    DEFINE(ACB_AC1CTRL)
#else
    MISSING(ACB_AC1CTRL)
#endif

#ifdef ACB_AC1MUXCTRL
    DEFINE(ACB_AC1MUXCTRL)
#else
    MISSING(ACB_AC1MUXCTRL)
#endif

#ifdef ACB_CTRLA
    DEFINE(ACB_CTRLA)
#else
    MISSING(ACB_CTRLA)
#endif

#ifdef ACB_CTRLB
    DEFINE(ACB_CTRLB)
#else
    MISSING(ACB_CTRLB)
#endif

#ifdef ACB_STATUS
    DEFINE(ACB_STATUS)
#else
    MISSING(ACB_STATUS)
#endif

#ifdef ACB_WINCTRL
    DEFINE(ACB_WINCTRL)
#else
    MISSING(ACB_WINCTRL)
#endif

#ifdef ACSR
    DEFINE(ACSR)
#else
    MISSING(ACSR)
#endif

#ifdef ACSRA
    DEFINE(ACSRA)
#else
    MISSING(ACSRA)
#endif

#ifdef ACSRB
    DEFINE(ACSRB)
#else
    MISSING(ACSRB)
#endif

#ifdef ADC
    DEFINE(ADC)
#else
    MISSING(ADC)
#endif

#ifdef ADCA_CAL
    DEFINE(ADCA_CAL)
#else
    MISSING(ADCA_CAL)
#endif

#ifdef ADCA_CH0RES
    DEFINE(ADCA_CH0RES)
#else
    MISSING(ADCA_CH0RES)
#endif

#ifdef ADCA_CH0_CTRL
    DEFINE(ADCA_CH0_CTRL)
#else
    MISSING(ADCA_CH0_CTRL)
#endif

#ifdef ADCA_CH0_INTCTRL
    DEFINE(ADCA_CH0_INTCTRL)
#else
    MISSING(ADCA_CH0_INTCTRL)
#endif

#ifdef ADCA_CH0_INTFLAGS
    DEFINE(ADCA_CH0_INTFLAGS)
#else
    MISSING(ADCA_CH0_INTFLAGS)
#endif

#ifdef ADCA_CH0_MUXCTRL
    DEFINE(ADCA_CH0_MUXCTRL)
#else
    MISSING(ADCA_CH0_MUXCTRL)
#endif

#ifdef ADCA_CH0_RES
    DEFINE(ADCA_CH0_RES)
#else
    MISSING(ADCA_CH0_RES)
#endif

#ifdef ADCA_CH1RES
    DEFINE(ADCA_CH1RES)
#else
    MISSING(ADCA_CH1RES)
#endif

#ifdef ADCA_CH1_CTRL
    DEFINE(ADCA_CH1_CTRL)
#else
    MISSING(ADCA_CH1_CTRL)
#endif

#ifdef ADCA_CH1_INTCTRL
    DEFINE(ADCA_CH1_INTCTRL)
#else
    MISSING(ADCA_CH1_INTCTRL)
#endif

#ifdef ADCA_CH1_INTFLAGS
    DEFINE(ADCA_CH1_INTFLAGS)
#else
    MISSING(ADCA_CH1_INTFLAGS)
#endif

#ifdef ADCA_CH1_MUXCTRL
    DEFINE(ADCA_CH1_MUXCTRL)
#else
    MISSING(ADCA_CH1_MUXCTRL)
#endif

#ifdef ADCA_CH1_RES
    DEFINE(ADCA_CH1_RES)
#else
    MISSING(ADCA_CH1_RES)
#endif

#ifdef ADCA_CH2RES
    DEFINE(ADCA_CH2RES)
#else
    MISSING(ADCA_CH2RES)
#endif

#ifdef ADCA_CH2_CTRL
    DEFINE(ADCA_CH2_CTRL)
#else
    MISSING(ADCA_CH2_CTRL)
#endif

#ifdef ADCA_CH2_INTCTRL
    DEFINE(ADCA_CH2_INTCTRL)
#else
    MISSING(ADCA_CH2_INTCTRL)
#endif

#ifdef ADCA_CH2_INTFLAGS
    DEFINE(ADCA_CH2_INTFLAGS)
#else
    MISSING(ADCA_CH2_INTFLAGS)
#endif

#ifdef ADCA_CH2_MUXCTRL
    DEFINE(ADCA_CH2_MUXCTRL)
#else
    MISSING(ADCA_CH2_MUXCTRL)
#endif

#ifdef ADCA_CH2_RES
    DEFINE(ADCA_CH2_RES)
#else
    MISSING(ADCA_CH2_RES)
#endif

#ifdef ADCA_CH3RES
    DEFINE(ADCA_CH3RES)
#else
    MISSING(ADCA_CH3RES)
#endif

#ifdef ADCA_CH3_CTRL
    DEFINE(ADCA_CH3_CTRL)
#else
    MISSING(ADCA_CH3_CTRL)
#endif

#ifdef ADCA_CH3_INTCTRL
    DEFINE(ADCA_CH3_INTCTRL)
#else
    MISSING(ADCA_CH3_INTCTRL)
#endif

#ifdef ADCA_CH3_INTFLAGS
    DEFINE(ADCA_CH3_INTFLAGS)
#else
    MISSING(ADCA_CH3_INTFLAGS)
#endif

#ifdef ADCA_CH3_MUXCTRL
    DEFINE(ADCA_CH3_MUXCTRL)
#else
    MISSING(ADCA_CH3_MUXCTRL)
#endif

#ifdef ADCA_CH3_RES
    DEFINE(ADCA_CH3_RES)
#else
    MISSING(ADCA_CH3_RES)
#endif

#ifdef ADCA_CMP
    DEFINE(ADCA_CMP)
#else
    MISSING(ADCA_CMP)
#endif

#ifdef ADCA_CTRLA
    DEFINE(ADCA_CTRLA)
#else
    MISSING(ADCA_CTRLA)
#endif

#ifdef ADCA_CTRLB
    DEFINE(ADCA_CTRLB)
#else
    MISSING(ADCA_CTRLB)
#endif

#ifdef ADCA_EVCTRL
    DEFINE(ADCA_EVCTRL)
#else
    MISSING(ADCA_EVCTRL)
#endif

#ifdef ADCA_INTFLAGS
    DEFINE(ADCA_INTFLAGS)
#else
    MISSING(ADCA_INTFLAGS)
#endif

#ifdef ADCA_PRESCALER
    DEFINE(ADCA_PRESCALER)
#else
    MISSING(ADCA_PRESCALER)
#endif

#ifdef ADCA_REFCTRL
    DEFINE(ADCA_REFCTRL)
#else
    MISSING(ADCA_REFCTRL)
#endif

#ifdef ADCA_TEMP
    DEFINE(ADCA_TEMP)
#else
    MISSING(ADCA_TEMP)
#endif

#ifdef ADCB_CAL
    DEFINE(ADCB_CAL)
#else
    MISSING(ADCB_CAL)
#endif

#ifdef ADCB_CH0RES
    DEFINE(ADCB_CH0RES)
#else
    MISSING(ADCB_CH0RES)
#endif

#ifdef ADCB_CH0_CTRL
    DEFINE(ADCB_CH0_CTRL)
#else
    MISSING(ADCB_CH0_CTRL)
#endif

#ifdef ADCB_CH0_INTCTRL
    DEFINE(ADCB_CH0_INTCTRL)
#else
    MISSING(ADCB_CH0_INTCTRL)
#endif

#ifdef ADCB_CH0_INTFLAGS
    DEFINE(ADCB_CH0_INTFLAGS)
#else
    MISSING(ADCB_CH0_INTFLAGS)
#endif

#ifdef ADCB_CH0_MUXCTRL
    DEFINE(ADCB_CH0_MUXCTRL)
#else
    MISSING(ADCB_CH0_MUXCTRL)
#endif

#ifdef ADCB_CH0_RES
    DEFINE(ADCB_CH0_RES)
#else
    MISSING(ADCB_CH0_RES)
#endif

#ifdef ADCB_CH1RES
    DEFINE(ADCB_CH1RES)
#else
    MISSING(ADCB_CH1RES)
#endif

#ifdef ADCB_CH1_CTRL
    DEFINE(ADCB_CH1_CTRL)
#else
    MISSING(ADCB_CH1_CTRL)
#endif

#ifdef ADCB_CH1_INTCTRL
    DEFINE(ADCB_CH1_INTCTRL)
#else
    MISSING(ADCB_CH1_INTCTRL)
#endif

#ifdef ADCB_CH1_INTFLAGS
    DEFINE(ADCB_CH1_INTFLAGS)
#else
    MISSING(ADCB_CH1_INTFLAGS)
#endif

#ifdef ADCB_CH1_MUXCTRL
    DEFINE(ADCB_CH1_MUXCTRL)
#else
    MISSING(ADCB_CH1_MUXCTRL)
#endif

#ifdef ADCB_CH1_RES
    DEFINE(ADCB_CH1_RES)
#else
    MISSING(ADCB_CH1_RES)
#endif

#ifdef ADCB_CH2RES
    DEFINE(ADCB_CH2RES)
#else
    MISSING(ADCB_CH2RES)
#endif

#ifdef ADCB_CH2_CTRL
    DEFINE(ADCB_CH2_CTRL)
#else
    MISSING(ADCB_CH2_CTRL)
#endif

#ifdef ADCB_CH2_INTCTRL
    DEFINE(ADCB_CH2_INTCTRL)
#else
    MISSING(ADCB_CH2_INTCTRL)
#endif

#ifdef ADCB_CH2_INTFLAGS
    DEFINE(ADCB_CH2_INTFLAGS)
#else
    MISSING(ADCB_CH2_INTFLAGS)
#endif

#ifdef ADCB_CH2_MUXCTRL
    DEFINE(ADCB_CH2_MUXCTRL)
#else
    MISSING(ADCB_CH2_MUXCTRL)
#endif

#ifdef ADCB_CH2_RES
    DEFINE(ADCB_CH2_RES)
#else
    MISSING(ADCB_CH2_RES)
#endif

#ifdef ADCB_CH3RES
    DEFINE(ADCB_CH3RES)
#else
    MISSING(ADCB_CH3RES)
#endif

#ifdef ADCB_CH3_CTRL
    DEFINE(ADCB_CH3_CTRL)
#else
    MISSING(ADCB_CH3_CTRL)
#endif

#ifdef ADCB_CH3_INTCTRL
    DEFINE(ADCB_CH3_INTCTRL)
#else
    MISSING(ADCB_CH3_INTCTRL)
#endif

#ifdef ADCB_CH3_INTFLAGS
    DEFINE(ADCB_CH3_INTFLAGS)
#else
    MISSING(ADCB_CH3_INTFLAGS)
#endif

#ifdef ADCB_CH3_MUXCTRL
    DEFINE(ADCB_CH3_MUXCTRL)
#else
    MISSING(ADCB_CH3_MUXCTRL)
#endif

#ifdef ADCB_CH3_RES
    DEFINE(ADCB_CH3_RES)
#else
    MISSING(ADCB_CH3_RES)
#endif

#ifdef ADCB_CMP
    DEFINE(ADCB_CMP)
#else
    MISSING(ADCB_CMP)
#endif

#ifdef ADCB_CTRLA
    DEFINE(ADCB_CTRLA)
#else
    MISSING(ADCB_CTRLA)
#endif

#ifdef ADCB_CTRLB
    DEFINE(ADCB_CTRLB)
#else
    MISSING(ADCB_CTRLB)
#endif

#ifdef ADCB_EVCTRL
    DEFINE(ADCB_EVCTRL)
#else
    MISSING(ADCB_EVCTRL)
#endif

#ifdef ADCB_INTFLAGS
    DEFINE(ADCB_INTFLAGS)
#else
    MISSING(ADCB_INTFLAGS)
#endif

#ifdef ADCB_PRESCALER
    DEFINE(ADCB_PRESCALER)
#else
    MISSING(ADCB_PRESCALER)
#endif

#ifdef ADCB_REFCTRL
    DEFINE(ADCB_REFCTRL)
#else
    MISSING(ADCB_REFCTRL)
#endif

#ifdef ADCB_TEMP
    DEFINE(ADCB_TEMP)
#else
    MISSING(ADCB_TEMP)
#endif

#ifdef ADCH
    DEFINE(ADCH)
#else
    MISSING(ADCH)
#endif

#ifdef ADCL
    DEFINE(ADCL)
#else
    MISSING(ADCL)
#endif

#ifdef ADCRA
    DEFINE(ADCRA)
#else
    MISSING(ADCRA)
#endif

#ifdef ADCRB
    DEFINE(ADCRB)
#else
    MISSING(ADCRB)
#endif

#ifdef ADCRC
    DEFINE(ADCRC)
#else
    MISSING(ADCRC)
#endif

#ifdef ADCRD
    DEFINE(ADCRD)
#else
    MISSING(ADCRD)
#endif

#ifdef ADCRE
    DEFINE(ADCRE)
#else
    MISSING(ADCRE)
#endif

#ifdef ADCSR
    DEFINE(ADCSR)
#else
    MISSING(ADCSR)
#endif

#ifdef ADCSRA
    DEFINE(ADCSRA)
#else
    MISSING(ADCSRA)
#endif

#ifdef ADCSRB
    DEFINE(ADCSRB)
#else
    MISSING(ADCSRB)
#endif

#ifdef ADCSRC
    DEFINE(ADCSRC)
#else
    MISSING(ADCSRC)
#endif

#ifdef ADCW
    DEFINE(ADCW)
#else
    MISSING(ADCW)
#endif

#ifdef ADCWH
    DEFINE(ADCWH)
#else
    MISSING(ADCWH)
#endif

#ifdef ADCWL
    DEFINE(ADCWL)
#else
    MISSING(ADCWL)
#endif

#ifdef ADIFR
    DEFINE(ADIFR)
#else
    MISSING(ADIFR)
#endif

#ifdef ADIMR
    DEFINE(ADIMR)
#else
    MISSING(ADIMR)
#endif

#ifdef ADMUX
    DEFINE(ADMUX)
#else
    MISSING(ADMUX)
#endif

#ifdef ADRSLT
    DEFINE(ADRSLT)
#else
    MISSING(ADRSLT)
#endif

#ifdef ADRSLTH
    DEFINE(ADRSLTH)
#else
    MISSING(ADRSLTH)
#endif

#ifdef ADRSLTHI
    DEFINE(ADRSLTHI)
#else
    MISSING(ADRSLTHI)
#endif

#ifdef ADRSLTL
    DEFINE(ADRSLTL)
#else
    MISSING(ADRSLTL)
#endif

#ifdef ADRSLTLO
    DEFINE(ADRSLTLO)
#else
    MISSING(ADRSLTLO)
#endif

#ifdef ADSCSRA
    DEFINE(ADSCSRA)
#else
    MISSING(ADSCSRA)
#endif

#ifdef ADSCSRB
    DEFINE(ADSCSRB)
#else
    MISSING(ADSCSRB)
#endif

#ifdef AESACR
    DEFINE(AESACR)
#else
    MISSING(AESACR)
#endif

#ifdef AESADDR
    DEFINE(AESADDR)
#else
    MISSING(AESADDR)
#endif

#ifdef AESCR
    DEFINE(AESCR)
#else
    MISSING(AESCR)
#endif

#ifdef AESDR
    DEFINE(AESDR)
#else
    MISSING(AESDR)
#endif

#ifdef AES_CTRL
    DEFINE(AES_CTRL)
#else
    MISSING(AES_CTRL)
#endif

#ifdef AES_INTCTRL
    DEFINE(AES_INTCTRL)
#else
    MISSING(AES_INTCTRL)
#endif

#ifdef AES_KEY
    DEFINE(AES_KEY)
#else
    MISSING(AES_KEY)
#endif

#ifdef AES_STATE
    DEFINE(AES_STATE)
#else
    MISSING(AES_STATE)
#endif

#ifdef AES_STATUS
    DEFINE(AES_STATUS)
#else
    MISSING(AES_STATUS)
#endif

#ifdef AGPDDR
    DEFINE(AGPDDR)
#else
    MISSING(AGPDDR)
#endif

#ifdef AGPPIN
    DEFINE(AGPPIN)
#else
    MISSING(AGPPIN)
#endif

#ifdef AGPPORT
    DEFINE(AGPPORT)
#else
    MISSING(AGPPORT)
#endif

#ifdef AMISCR
    DEFINE(AMISCR)
#else
    MISSING(AMISCR)
#endif

#ifdef AMP0CSR
    DEFINE(AMP0CSR)
#else
    MISSING(AMP0CSR)
#endif

#ifdef AMP1CSR
    DEFINE(AMP1CSR)
#else
    MISSING(AMP1CSR)
#endif

#ifdef AMP2CSR
    DEFINE(AMP2CSR)
#else
    MISSING(AMP2CSR)
#endif

#ifdef AMUXCTL
    DEFINE(AMUXCTL)
#else
    MISSING(AMUXCTL)
#endif

#ifdef ANT_DIV
    DEFINE(ANT_DIV)
#else
    MISSING(ANT_DIV)
#endif

#ifdef ASSR
    DEFINE(ASSR)
#else
    MISSING(ASSR)
#endif

#ifdef AVR_CONFIG
    DEFINE(AVR_CONFIG)
#else
    MISSING(AVR_CONFIG)
#endif

#ifdef AWEXC_CTRL
    DEFINE(AWEXC_CTRL)
#else
    MISSING(AWEXC_CTRL)
#endif

#ifdef AWEXC_DTBOTH
    DEFINE(AWEXC_DTBOTH)
#else
    MISSING(AWEXC_DTBOTH)
#endif

#ifdef AWEXC_DTBOTHBUF
    DEFINE(AWEXC_DTBOTHBUF)
#else
    MISSING(AWEXC_DTBOTHBUF)
#endif

#ifdef AWEXC_DTHS
    DEFINE(AWEXC_DTHS)
#else
    MISSING(AWEXC_DTHS)
#endif

#ifdef AWEXC_DTHSBUF
    DEFINE(AWEXC_DTHSBUF)
#else
    MISSING(AWEXC_DTHSBUF)
#endif

#ifdef AWEXC_DTLS
    DEFINE(AWEXC_DTLS)
#else
    MISSING(AWEXC_DTLS)
#endif

#ifdef AWEXC_DTLSBUF
    DEFINE(AWEXC_DTLSBUF)
#else
    MISSING(AWEXC_DTLSBUF)
#endif

#ifdef AWEXC_FDCTRL
    DEFINE(AWEXC_FDCTRL)
#else
    MISSING(AWEXC_FDCTRL)
#endif

#ifdef AWEXC_FDEMASK
    DEFINE(AWEXC_FDEMASK)
#else
    MISSING(AWEXC_FDEMASK)
#endif

#ifdef AWEXC_OUTOVEN
    DEFINE(AWEXC_OUTOVEN)
#else
    MISSING(AWEXC_OUTOVEN)
#endif

#ifdef AWEXC_STATUS
    DEFINE(AWEXC_STATUS)
#else
    MISSING(AWEXC_STATUS)
#endif

#ifdef AWEXE_CTRL
    DEFINE(AWEXE_CTRL)
#else
    MISSING(AWEXE_CTRL)
#endif

#ifdef AWEXE_DTBOTH
    DEFINE(AWEXE_DTBOTH)
#else
    MISSING(AWEXE_DTBOTH)
#endif

#ifdef AWEXE_DTBOTHBUF
    DEFINE(AWEXE_DTBOTHBUF)
#else
    MISSING(AWEXE_DTBOTHBUF)
#endif

#ifdef AWEXE_DTHS
    DEFINE(AWEXE_DTHS)
#else
    MISSING(AWEXE_DTHS)
#endif

#ifdef AWEXE_DTHSBUF
    DEFINE(AWEXE_DTHSBUF)
#else
    MISSING(AWEXE_DTHSBUF)
#endif

#ifdef AWEXE_DTLS
    DEFINE(AWEXE_DTLS)
#else
    MISSING(AWEXE_DTLS)
#endif

#ifdef AWEXE_DTLSBUF
    DEFINE(AWEXE_DTLSBUF)
#else
    MISSING(AWEXE_DTLSBUF)
#endif

#ifdef AWEXE_FDCTRL
    DEFINE(AWEXE_FDCTRL)
#else
    MISSING(AWEXE_FDCTRL)
#endif

#ifdef AWEXE_FDEMASK
    DEFINE(AWEXE_FDEMASK)
#else
    MISSING(AWEXE_FDEMASK)
#endif

#ifdef AWEXE_OUTOVEN
    DEFINE(AWEXE_OUTOVEN)
#else
    MISSING(AWEXE_OUTOVEN)
#endif

#ifdef AWEXE_STATUS
    DEFINE(AWEXE_STATUS)
#else
    MISSING(AWEXE_STATUS)
#endif

#ifdef BATMON
    DEFINE(BATMON)
#else
    MISSING(BATMON)
#endif

#ifdef BGCAL
    DEFINE(BGCAL)
#else
    MISSING(BGCAL)
#endif

#ifdef BGCCR
    DEFINE(BGCCR)
#else
    MISSING(BGCCR)
#endif

#ifdef BGCR
    DEFINE(BGCR)
#else
    MISSING(BGCR)
#endif

#ifdef BGCRA
    DEFINE(BGCRA)
#else
    MISSING(BGCRA)
#endif

#ifdef BGCRB
    DEFINE(BGCRB)
#else
    MISSING(BGCRB)
#endif

#ifdef BGCRR
    DEFINE(BGCRR)
#else
    MISSING(BGCRR)
#endif

#ifdef BGCSR
    DEFINE(BGCSR)
#else
    MISSING(BGCSR)
#endif

#ifdef BGCSRA
    DEFINE(BGCSRA)
#else
    MISSING(BGCSRA)
#endif

#ifdef BGLR
    DEFINE(BGLR)
#else
    MISSING(BGLR)
#endif

#ifdef BGPDDR
    DEFINE(BGPDDR)
#else
    MISSING(BGPDDR)
#endif

#ifdef BGPPIN
    DEFINE(BGPPIN)
#else
    MISSING(BGPPIN)
#endif

#ifdef BGPPORT
    DEFINE(BGPPORT)
#else
    MISSING(BGPPORT)
#endif

#ifdef BL_CONFIG
    DEFINE(BL_CONFIG)
#else
    MISSING(BL_CONFIG)
#endif

#ifdef BODCR
    DEFINE(BODCR)
#else
    MISSING(BODCR)
#endif

#ifdef BPCHCD
    DEFINE(BPCHCD)
#else
    MISSING(BPCHCD)
#endif

#ifdef BPCOCD
    DEFINE(BPCOCD)
#else
    MISSING(BPCOCD)
#endif

#ifdef BPCR
    DEFINE(BPCR)
#else
    MISSING(BPCR)
#endif

#ifdef BPDHCD
    DEFINE(BPDHCD)
#else
    MISSING(BPDHCD)
#endif

#ifdef BPDOCD
    DEFINE(BPDOCD)
#else
    MISSING(BPDOCD)
#endif

#ifdef BPDUV
    DEFINE(BPDUV)
#else
    MISSING(BPDUV)
#endif

#ifdef BPHCTR
    DEFINE(BPHCTR)
#else
    MISSING(BPHCTR)
#endif

#ifdef BPIFR
    DEFINE(BPIFR)
#else
    MISSING(BPIFR)
#endif

#ifdef BPIMSK
    DEFINE(BPIMSK)
#else
    MISSING(BPIMSK)
#endif

#ifdef BPIR
    DEFINE(BPIR)
#else
    MISSING(BPIR)
#endif

#ifdef BPOCD
    DEFINE(BPOCD)
#else
    MISSING(BPOCD)
#endif

#ifdef BPOCTR
    DEFINE(BPOCTR)
#else
    MISSING(BPOCTR)
#endif

#ifdef BPPLR
    DEFINE(BPPLR)
#else
    MISSING(BPPLR)
#endif

#ifdef BPSCD
    DEFINE(BPSCD)
#else
    MISSING(BPSCD)
#endif

#ifdef BPSCTR
    DEFINE(BPSCTR)
#else
    MISSING(BPSCTR)
#endif

#ifdef BTCNT
    DEFINE(BTCNT)
#else
    MISSING(BTCNT)
#endif

#ifdef BTCR
    DEFINE(BTCR)
#else
    MISSING(BTCR)
#endif

#ifdef B_DET
    DEFINE(B_DET)
#else
    MISSING(B_DET)
#endif

#ifdef CADAC0
    DEFINE(CADAC0)
#else
    MISSING(CADAC0)
#endif

#ifdef CADAC1
    DEFINE(CADAC1)
#else
    MISSING(CADAC1)
#endif

#ifdef CADAC2
    DEFINE(CADAC2)
#else
    MISSING(CADAC2)
#endif

#ifdef CADAC3
    DEFINE(CADAC3)
#else
    MISSING(CADAC3)
#endif

#ifdef CADCSRA
    DEFINE(CADCSRA)
#else
    MISSING(CADCSRA)
#endif

#ifdef CADCSRB
    DEFINE(CADCSRB)
#else
    MISSING(CADCSRB)
#endif

#ifdef CADCSRC
    DEFINE(CADCSRC)
#else
    MISSING(CADCSRC)
#endif

#ifdef CADIC
    DEFINE(CADIC)
#else
    MISSING(CADIC)
#endif

#ifdef CADICH
    DEFINE(CADICH)
#else
    MISSING(CADICH)
#endif

#ifdef CADICL
    DEFINE(CADICL)
#else
    MISSING(CADICL)
#endif

#ifdef CADRC
    DEFINE(CADRC)
#else
    MISSING(CADRC)
#endif

#ifdef CADRCC
    DEFINE(CADRCC)
#else
    MISSING(CADRCC)
#endif

#ifdef CADRCL
    DEFINE(CADRCL)
#else
    MISSING(CADRCL)
#endif

#ifdef CADRCLH
    DEFINE(CADRCLH)
#else
    MISSING(CADRCLH)
#endif

#ifdef CADRCLL
    DEFINE(CADRCLL)
#else
    MISSING(CADRCLL)
#endif

#ifdef CADRDC
    DEFINE(CADRDC)
#else
    MISSING(CADRDC)
#endif

#ifdef CANBT1
    DEFINE(CANBT1)
#else
    MISSING(CANBT1)
#endif

#ifdef CANBT2
    DEFINE(CANBT2)
#else
    MISSING(CANBT2)
#endif

#ifdef CANBT3
    DEFINE(CANBT3)
#else
    MISSING(CANBT3)
#endif

#ifdef CANCDMOB
    DEFINE(CANCDMOB)
#else
    MISSING(CANCDMOB)
#endif

#ifdef CANEN
    DEFINE(CANEN)
#else
    MISSING(CANEN)
#endif

#ifdef CANEN1
    DEFINE(CANEN1)
#else
    MISSING(CANEN1)
#endif

#ifdef CANEN2
    DEFINE(CANEN2)
#else
    MISSING(CANEN2)
#endif

#ifdef CANGCON
    DEFINE(CANGCON)
#else
    MISSING(CANGCON)
#endif

#ifdef CANGIE
    DEFINE(CANGIE)
#else
    MISSING(CANGIE)
#endif

#ifdef CANGIT
    DEFINE(CANGIT)
#else
    MISSING(CANGIT)
#endif

#ifdef CANGSTA
    DEFINE(CANGSTA)
#else
    MISSING(CANGSTA)
#endif

#ifdef CANHPMOB
    DEFINE(CANHPMOB)
#else
    MISSING(CANHPMOB)
#endif

#ifdef CANIDM1
    DEFINE(CANIDM1)
#else
    MISSING(CANIDM1)
#endif

#ifdef CANIDM2
    DEFINE(CANIDM2)
#else
    MISSING(CANIDM2)
#endif

#ifdef CANIDM3
    DEFINE(CANIDM3)
#else
    MISSING(CANIDM3)
#endif

#ifdef CANIDM4
    DEFINE(CANIDM4)
#else
    MISSING(CANIDM4)
#endif

#ifdef CANIDT1
    DEFINE(CANIDT1)
#else
    MISSING(CANIDT1)
#endif

#ifdef CANIDT2
    DEFINE(CANIDT2)
#else
    MISSING(CANIDT2)
#endif

#ifdef CANIDT3
    DEFINE(CANIDT3)
#else
    MISSING(CANIDT3)
#endif

#ifdef CANIDT4
    DEFINE(CANIDT4)
#else
    MISSING(CANIDT4)
#endif

#ifdef CANIE
    DEFINE(CANIE)
#else
    MISSING(CANIE)
#endif

#ifdef CANIE1
    DEFINE(CANIE1)
#else
    MISSING(CANIE1)
#endif

#ifdef CANIE2
    DEFINE(CANIE2)
#else
    MISSING(CANIE2)
#endif

#ifdef CANMSG
    DEFINE(CANMSG)
#else
    MISSING(CANMSG)
#endif

#ifdef CANPAGE
    DEFINE(CANPAGE)
#else
    MISSING(CANPAGE)
#endif

#ifdef CANREC
    DEFINE(CANREC)
#else
    MISSING(CANREC)
#endif

#ifdef CANSIT
    DEFINE(CANSIT)
#else
    MISSING(CANSIT)
#endif

#ifdef CANSIT1
    DEFINE(CANSIT1)
#else
    MISSING(CANSIT1)
#endif

#ifdef CANSIT2
    DEFINE(CANSIT2)
#else
    MISSING(CANSIT2)
#endif

#ifdef CANSTM
    DEFINE(CANSTM)
#else
    MISSING(CANSTM)
#endif

#ifdef CANSTMH
    DEFINE(CANSTMH)
#else
    MISSING(CANSTMH)
#endif

#ifdef CANSTML
    DEFINE(CANSTML)
#else
    MISSING(CANSTML)
#endif

#ifdef CANSTMOB
    DEFINE(CANSTMOB)
#else
    MISSING(CANSTMOB)
#endif

#ifdef CANTCON
    DEFINE(CANTCON)
#else
    MISSING(CANTCON)
#endif

#ifdef CANTEC
    DEFINE(CANTEC)
#else
    MISSING(CANTEC)
#endif

#ifdef CANTIM
    DEFINE(CANTIM)
#else
    MISSING(CANTIM)
#endif

#ifdef CANTIMH
    DEFINE(CANTIMH)
#else
    MISSING(CANTIMH)
#endif

#ifdef CANTIML
    DEFINE(CANTIML)
#else
    MISSING(CANTIML)
#endif

#ifdef CANTTC
    DEFINE(CANTTC)
#else
    MISSING(CANTTC)
#endif

#ifdef CANTTCH
    DEFINE(CANTTCH)
#else
    MISSING(CANTTCH)
#endif

#ifdef CANTTCL
    DEFINE(CANTTCL)
#else
    MISSING(CANTTCL)
#endif

#ifdef CBCR
    DEFINE(CBCR)
#else
    MISSING(CBCR)
#endif

#ifdef CBPTR
    DEFINE(CBPTR)
#else
    MISSING(CBPTR)
#endif

#ifdef CBTR1
    DEFINE(CBTR1)
#else
    MISSING(CBTR1)
#endif

#ifdef CBTR2
    DEFINE(CBTR2)
#else
    MISSING(CBTR2)
#endif

#ifdef CBTR3
    DEFINE(CBTR3)
#else
    MISSING(CBTR3)
#endif

#ifdef CCA_THRES
    DEFINE(CCA_THRES)
#else
    MISSING(CCA_THRES)
#endif

#ifdef CCFLG
    DEFINE(CCFLG)
#else
    MISSING(CCFLG)
#endif

#ifdef CCISR
    DEFINE(CCISR)
#else
    MISSING(CCISR)
#endif

#ifdef CCP
    DEFINE(CCP)
#else
    MISSING(CCP)
#endif

#ifdef CCSR
    DEFINE(CCSR)
#else
    MISSING(CCSR)
#endif

#ifdef CDIVCAN
    DEFINE(CDIVCAN)
#else
    MISSING(CDIVCAN)
#endif

#ifdef CEFR
    DEFINE(CEFR)
#else
    MISSING(CEFR)
#endif

#ifdef CGPDDR
    DEFINE(CGPDDR)
#else
    MISSING(CGPDDR)
#endif

#ifdef CGPPIN
    DEFINE(CGPPIN)
#else
    MISSING(CGPPIN)
#endif

#ifdef CGPPORT
    DEFINE(CGPPORT)
#else
    MISSING(CGPPORT)
#endif

#ifdef CHGDCSR
    DEFINE(CHGDCSR)
#else
    MISSING(CHGDCSR)
#endif

#ifdef CIDAH0
    DEFINE(CIDAH0)
#else
    MISSING(CIDAH0)
#endif

#ifdef CIDAH1
    DEFINE(CIDAH1)
#else
    MISSING(CIDAH1)
#endif

#ifdef CIER
    DEFINE(CIER)
#else
    MISSING(CIER)
#endif

#ifdef CKSEL0
    DEFINE(CKSEL0)
#else
    MISSING(CKSEL0)
#endif

#ifdef CKSEL1
    DEFINE(CKSEL1)
#else
    MISSING(CKSEL1)
#endif

#ifdef CKSTA
    DEFINE(CKSTA)
#else
    MISSING(CKSTA)
#endif

#ifdef CLKCSR
    DEFINE(CLKCSR)
#else
    MISSING(CLKCSR)
#endif

#ifdef CLKMSR
    DEFINE(CLKMSR)
#else
    MISSING(CLKMSR)
#endif

#ifdef CLKPR
    DEFINE(CLKPR)
#else
    MISSING(CLKPR)
#endif

#ifdef CLKPSR
    DEFINE(CLKPSR)
#else
    MISSING(CLKPSR)
#endif

#ifdef CLKSEL0
    DEFINE(CLKSEL0)
#else
    MISSING(CLKSEL0)
#endif

#ifdef CLKSEL1
    DEFINE(CLKSEL1)
#else
    MISSING(CLKSEL1)
#endif

#ifdef CLKSELR
    DEFINE(CLKSELR)
#else
    MISSING(CLKSELR)
#endif

#ifdef CLKSTA
    DEFINE(CLKSTA)
#else
    MISSING(CLKSTA)
#endif

#ifdef CLK_CNTR
    DEFINE(CLK_CNTR)
#else
    MISSING(CLK_CNTR)
#endif

#ifdef CLK_CTRL
    DEFINE(CLK_CTRL)
#else
    MISSING(CLK_CTRL)
#endif

#ifdef CLK_LOCK
    DEFINE(CLK_LOCK)
#else
    MISSING(CLK_LOCK)
#endif

#ifdef CLK_PSCTRL
    DEFINE(CLK_PSCTRL)
#else
    MISSING(CLK_PSCTRL)
#endif

#ifdef CLK_RTCCTRL
    DEFINE(CLK_RTCCTRL)
#else
    MISSING(CLK_RTCCTRL)
#endif

#ifdef CLK_USBCTRL
    DEFINE(CLK_USBCTRL)
#else
    MISSING(CLK_USBCTRL)
#endif

#ifdef CMCR
    DEFINE(CMCR)
#else
    MISSING(CMCR)
#endif

#ifdef CMIMR
    DEFINE(CMIMR)
#else
    MISSING(CMIMR)
#endif

#ifdef CMSR
    DEFINE(CMSR)
#else
    MISSING(CMSR)
#endif

#ifdef COSDAC
    DEFINE(COSDAC)
#else
    MISSING(COSDAC)
#endif

#ifdef COSDACH
    DEFINE(COSDACH)
#else
    MISSING(COSDACH)
#endif

#ifdef COSDACL
    DEFINE(COSDACL)
#else
    MISSING(COSDACL)
#endif

#ifdef CPU_CCP
    DEFINE(CPU_CCP)
#else
    MISSING(CPU_CCP)
#endif

#ifdef CPU_EIND
    DEFINE(CPU_EIND)
#else
    MISSING(CPU_EIND)
#endif

#ifdef CPU_RAMPD
    DEFINE(CPU_RAMPD)
#else
    MISSING(CPU_RAMPD)
#endif

#ifdef CPU_RAMPX
    DEFINE(CPU_RAMPX)
#else
    MISSING(CPU_RAMPX)
#endif

#ifdef CPU_RAMPY
    DEFINE(CPU_RAMPY)
#else
    MISSING(CPU_RAMPY)
#endif

#ifdef CPU_RAMPZ
    DEFINE(CPU_RAMPZ)
#else
    MISSING(CPU_RAMPZ)
#endif

#ifdef CPU_SPH
    DEFINE(CPU_SPH)
#else
    MISSING(CPU_SPH)
#endif

#ifdef CPU_SPL
    DEFINE(CPU_SPL)
#else
    MISSING(CPU_SPL)
#endif

#ifdef CPU_SREG
    DEFINE(CPU_SREG)
#else
    MISSING(CPU_SREG)
#endif

#ifdef CRAFEN
    DEFINE(CRAFEN)
#else
    MISSING(CRAFEN)
#endif

#ifdef CRC_CHECKSUM0
    DEFINE(CRC_CHECKSUM0)
#else
    MISSING(CRC_CHECKSUM0)
#endif

#ifdef CRC_CHECKSUM1
    DEFINE(CRC_CHECKSUM1)
#else
    MISSING(CRC_CHECKSUM1)
#endif

#ifdef CRC_CHECKSUM2
    DEFINE(CRC_CHECKSUM2)
#else
    MISSING(CRC_CHECKSUM2)
#endif

#ifdef CRC_CHECKSUM3
    DEFINE(CRC_CHECKSUM3)
#else
    MISSING(CRC_CHECKSUM3)
#endif

#ifdef CRC_CTRL
    DEFINE(CRC_CTRL)
#else
    MISSING(CRC_CTRL)
#endif

#ifdef CRC_DATAIN
    DEFINE(CRC_DATAIN)
#else
    MISSING(CRC_DATAIN)
#endif

#ifdef CRC_STATUS
    DEFINE(CRC_STATUS)
#else
    MISSING(CRC_STATUS)
#endif

#ifdef CRXERR
    DEFINE(CRXERR)
#else
    MISSING(CRXERR)
#endif

#ifdef CSMA_BE
    DEFINE(CSMA_BE)
#else
    MISSING(CSMA_BE)
#endif

#ifdef CSMA_SEED_0
    DEFINE(CSMA_SEED_0)
#else
    MISSING(CSMA_SEED_0)
#endif

#ifdef CSMA_SEED_1
    DEFINE(CSMA_SEED_1)
#else
    MISSING(CSMA_SEED_1)
#endif

#ifdef CTARR
    DEFINE(CTARR)
#else
    MISSING(CTARR)
#endif

#ifdef CTXERR
    DEFINE(CTXERR)
#else
    MISSING(CTXERR)
#endif

#ifdef CURIRED
    DEFINE(CURIRED)
#else
    MISSING(CURIRED)
#endif

#ifdef CURIRUN
    DEFINE(CURIRUN)
#else
    MISSING(CURIRUN)
#endif

#ifdef CURRDLY
    DEFINE(CURRDLY)
#else
    MISSING(CURRDLY)
#endif

#ifdef CVER
    DEFINE(CVER)
#else
    MISSING(CVER)
#endif

#ifdef DAC
    DEFINE(DAC)
#else
    MISSING(DAC)
#endif

#ifdef DACA_CH0DATA
    DEFINE(DACA_CH0DATA)
#else
    MISSING(DACA_CH0DATA)
#endif

#ifdef DACA_CH0GAINCAL
    DEFINE(DACA_CH0GAINCAL)
#else
    MISSING(DACA_CH0GAINCAL)
#endif

#ifdef DACA_CH0OFFSETCAL
    DEFINE(DACA_CH0OFFSETCAL)
#else
    MISSING(DACA_CH0OFFSETCAL)
#endif

#ifdef DACA_CH1DATA
    DEFINE(DACA_CH1DATA)
#else
    MISSING(DACA_CH1DATA)
#endif

#ifdef DACA_CH1GAINCAL
    DEFINE(DACA_CH1GAINCAL)
#else
    MISSING(DACA_CH1GAINCAL)
#endif

#ifdef DACA_CH1OFFSETCAL
    DEFINE(DACA_CH1OFFSETCAL)
#else
    MISSING(DACA_CH1OFFSETCAL)
#endif

#ifdef DACA_CTRLA
    DEFINE(DACA_CTRLA)
#else
    MISSING(DACA_CTRLA)
#endif

#ifdef DACA_CTRLB
    DEFINE(DACA_CTRLB)
#else
    MISSING(DACA_CTRLB)
#endif

#ifdef DACA_CTRLC
    DEFINE(DACA_CTRLC)
#else
    MISSING(DACA_CTRLC)
#endif

#ifdef DACA_EVCTRL
    DEFINE(DACA_EVCTRL)
#else
    MISSING(DACA_EVCTRL)
#endif

#ifdef DACA_GAINCAL
    DEFINE(DACA_GAINCAL)
#else
    MISSING(DACA_GAINCAL)
#endif

#ifdef DACA_OFFSETCAL
    DEFINE(DACA_OFFSETCAL)
#else
    MISSING(DACA_OFFSETCAL)
#endif

#ifdef DACA_STATUS
    DEFINE(DACA_STATUS)
#else
    MISSING(DACA_STATUS)
#endif

#ifdef DACA_TIMCTRL
    DEFINE(DACA_TIMCTRL)
#else
    MISSING(DACA_TIMCTRL)
#endif

#ifdef DACB_CH0DATA
    DEFINE(DACB_CH0DATA)
#else
    MISSING(DACB_CH0DATA)
#endif

#ifdef DACB_CH0GAINCAL
    DEFINE(DACB_CH0GAINCAL)
#else
    MISSING(DACB_CH0GAINCAL)
#endif

#ifdef DACB_CH0OFFSETCAL
    DEFINE(DACB_CH0OFFSETCAL)
#else
    MISSING(DACB_CH0OFFSETCAL)
#endif

#ifdef DACB_CH1DATA
    DEFINE(DACB_CH1DATA)
#else
    MISSING(DACB_CH1DATA)
#endif

#ifdef DACB_CH1GAINCAL
    DEFINE(DACB_CH1GAINCAL)
#else
    MISSING(DACB_CH1GAINCAL)
#endif

#ifdef DACB_CH1OFFSETCAL
    DEFINE(DACB_CH1OFFSETCAL)
#else
    MISSING(DACB_CH1OFFSETCAL)
#endif

#ifdef DACB_CTRLA
    DEFINE(DACB_CTRLA)
#else
    MISSING(DACB_CTRLA)
#endif

#ifdef DACB_CTRLB
    DEFINE(DACB_CTRLB)
#else
    MISSING(DACB_CTRLB)
#endif

#ifdef DACB_CTRLC
    DEFINE(DACB_CTRLC)
#else
    MISSING(DACB_CTRLC)
#endif

#ifdef DACB_EVCTRL
    DEFINE(DACB_EVCTRL)
#else
    MISSING(DACB_EVCTRL)
#endif

#ifdef DACB_GAINCAL
    DEFINE(DACB_GAINCAL)
#else
    MISSING(DACB_GAINCAL)
#endif

#ifdef DACB_OFFSETCAL
    DEFINE(DACB_OFFSETCAL)
#else
    MISSING(DACB_OFFSETCAL)
#endif

#ifdef DACB_STATUS
    DEFINE(DACB_STATUS)
#else
    MISSING(DACB_STATUS)
#endif

#ifdef DACB_TIMCTRL
    DEFINE(DACB_TIMCTRL)
#else
    MISSING(DACB_TIMCTRL)
#endif

#ifdef DACCTRL
    DEFINE(DACCTRL)
#else
    MISSING(DACCTRL)
#endif

#ifdef DACH
    DEFINE(DACH)
#else
    MISSING(DACH)
#endif

#ifdef DACL
    DEFINE(DACL)
#else
    MISSING(DACL)
#endif

#ifdef DACON
    DEFINE(DACON)
#else
    MISSING(DACON)
#endif

#ifdef DACVAL
    DEFINE(DACVAL)
#else
    MISSING(DACVAL)
#endif

#ifdef DACVALH
    DEFINE(DACVALH)
#else
    MISSING(DACVALH)
#endif

#ifdef DACVALHI
    DEFINE(DACVALHI)
#else
    MISSING(DACVALHI)
#endif

#ifdef DACVALL
    DEFINE(DACVALL)
#else
    MISSING(DACVALL)
#endif

#ifdef DACVALLO
    DEFINE(DACVALLO)
#else
    MISSING(DACVALLO)
#endif

#ifdef DCCR
    DEFINE(DCCR)
#else
    MISSING(DCCR)
#endif

#ifdef DDRA
    DEFINE(DDRA)
#else
    MISSING(DDRA)
#endif

#ifdef DDRB
    DEFINE(DDRB)
#else
    MISSING(DDRB)
#endif

#ifdef DDRC
    DEFINE(DDRC)
#else
    MISSING(DDRC)
#endif

#ifdef DDRD
    DEFINE(DDRD)
#else
    MISSING(DDRD)
#endif

#ifdef DDRE
    DEFINE(DDRE)
#else
    MISSING(DDRE)
#endif

#ifdef DDRF
    DEFINE(DDRF)
#else
    MISSING(DDRF)
#endif

#ifdef DDRG
    DEFINE(DDRG)
#else
    MISSING(DDRG)
#endif

#ifdef DDRH
    DEFINE(DDRH)
#else
    MISSING(DDRH)
#endif

#ifdef DDRJ
    DEFINE(DDRJ)
#else
    MISSING(DDRJ)
#endif

#ifdef DDRK
    DEFINE(DDRK)
#else
    MISSING(DDRK)
#endif

#ifdef DDRL
    DEFINE(DDRL)
#else
    MISSING(DDRL)
#endif

#ifdef DEEAR
    DEFINE(DEEAR)
#else
    MISSING(DEEAR)
#endif

#ifdef DEEARL
    DEFINE(DEEARL)
#else
    MISSING(DEEARL)
#endif

#ifdef DEECR
    DEFINE(DEECR)
#else
    MISSING(DEECR)
#endif

#ifdef DEEDR
    DEFINE(DEEDR)
#else
    MISSING(DEEDR)
#endif

#ifdef DFLLRC2M_CALA
    DEFINE(DFLLRC2M_CALA)
#else
    MISSING(DFLLRC2M_CALA)
#endif

#ifdef DFLLRC2M_CALB
    DEFINE(DFLLRC2M_CALB)
#else
    MISSING(DFLLRC2M_CALB)
#endif

#ifdef DFLLRC2M_COMP0
    DEFINE(DFLLRC2M_COMP0)
#else
    MISSING(DFLLRC2M_COMP0)
#endif

#ifdef DFLLRC2M_COMP1
    DEFINE(DFLLRC2M_COMP1)
#else
    MISSING(DFLLRC2M_COMP1)
#endif

#ifdef DFLLRC2M_COMP2
    DEFINE(DFLLRC2M_COMP2)
#else
    MISSING(DFLLRC2M_COMP2)
#endif

#ifdef DFLLRC2M_CTRL
    DEFINE(DFLLRC2M_CTRL)
#else
    MISSING(DFLLRC2M_CTRL)
#endif

#ifdef DFLLRC32M_CALA
    DEFINE(DFLLRC32M_CALA)
#else
    MISSING(DFLLRC32M_CALA)
#endif

#ifdef DFLLRC32M_CALB
    DEFINE(DFLLRC32M_CALB)
#else
    MISSING(DFLLRC32M_CALB)
#endif

#ifdef DFLLRC32M_COMP0
    DEFINE(DFLLRC32M_COMP0)
#else
    MISSING(DFLLRC32M_COMP0)
#endif

#ifdef DFLLRC32M_COMP1
    DEFINE(DFLLRC32M_COMP1)
#else
    MISSING(DFLLRC32M_COMP1)
#endif

#ifdef DFLLRC32M_COMP2
    DEFINE(DFLLRC32M_COMP2)
#else
    MISSING(DFLLRC32M_COMP2)
#endif

#ifdef DFLLRC32M_CTRL
    DEFINE(DFLLRC32M_CTRL)
#else
    MISSING(DFLLRC32M_CTRL)
#endif

#ifdef DIDR
    DEFINE(DIDR)
#else
    MISSING(DIDR)
#endif

#ifdef DIDR0
    DEFINE(DIDR0)
#else
    MISSING(DIDR0)
#endif

#ifdef DIDR1
    DEFINE(DIDR1)
#else
    MISSING(DIDR1)
#endif

#ifdef DIDR2
    DEFINE(DIDR2)
#else
    MISSING(DIDR2)
#endif

#ifdef DMA_CH0_ADDRCTRL
    DEFINE(DMA_CH0_ADDRCTRL)
#else
    MISSING(DMA_CH0_ADDRCTRL)
#endif

#ifdef DMA_CH0_CTRLA
    DEFINE(DMA_CH0_CTRLA)
#else
    MISSING(DMA_CH0_CTRLA)
#endif

#ifdef DMA_CH0_CTRLB
    DEFINE(DMA_CH0_CTRLB)
#else
    MISSING(DMA_CH0_CTRLB)
#endif

#ifdef DMA_CH0_DESTADDR0
    DEFINE(DMA_CH0_DESTADDR0)
#else
    MISSING(DMA_CH0_DESTADDR0)
#endif

#ifdef DMA_CH0_DESTADDR1
    DEFINE(DMA_CH0_DESTADDR1)
#else
    MISSING(DMA_CH0_DESTADDR1)
#endif

#ifdef DMA_CH0_DESTADDR2
    DEFINE(DMA_CH0_DESTADDR2)
#else
    MISSING(DMA_CH0_DESTADDR2)
#endif

#ifdef DMA_CH0_REPCNT
    DEFINE(DMA_CH0_REPCNT)
#else
    MISSING(DMA_CH0_REPCNT)
#endif

#ifdef DMA_CH0_SRCADDR0
    DEFINE(DMA_CH0_SRCADDR0)
#else
    MISSING(DMA_CH0_SRCADDR0)
#endif

#ifdef DMA_CH0_SRCADDR1
    DEFINE(DMA_CH0_SRCADDR1)
#else
    MISSING(DMA_CH0_SRCADDR1)
#endif

#ifdef DMA_CH0_SRCADDR2
    DEFINE(DMA_CH0_SRCADDR2)
#else
    MISSING(DMA_CH0_SRCADDR2)
#endif

#ifdef DMA_CH0_TRFCNT
    DEFINE(DMA_CH0_TRFCNT)
#else
    MISSING(DMA_CH0_TRFCNT)
#endif

#ifdef DMA_CH0_TRIGSRC
    DEFINE(DMA_CH0_TRIGSRC)
#else
    MISSING(DMA_CH0_TRIGSRC)
#endif

#ifdef DMA_CH1_ADDRCTRL
    DEFINE(DMA_CH1_ADDRCTRL)
#else
    MISSING(DMA_CH1_ADDRCTRL)
#endif

#ifdef DMA_CH1_CTRLA
    DEFINE(DMA_CH1_CTRLA)
#else
    MISSING(DMA_CH1_CTRLA)
#endif

#ifdef DMA_CH1_CTRLB
    DEFINE(DMA_CH1_CTRLB)
#else
    MISSING(DMA_CH1_CTRLB)
#endif

#ifdef DMA_CH1_DESTADDR0
    DEFINE(DMA_CH1_DESTADDR0)
#else
    MISSING(DMA_CH1_DESTADDR0)
#endif

#ifdef DMA_CH1_DESTADDR1
    DEFINE(DMA_CH1_DESTADDR1)
#else
    MISSING(DMA_CH1_DESTADDR1)
#endif

#ifdef DMA_CH1_DESTADDR2
    DEFINE(DMA_CH1_DESTADDR2)
#else
    MISSING(DMA_CH1_DESTADDR2)
#endif

#ifdef DMA_CH1_REPCNT
    DEFINE(DMA_CH1_REPCNT)
#else
    MISSING(DMA_CH1_REPCNT)
#endif

#ifdef DMA_CH1_SRCADDR0
    DEFINE(DMA_CH1_SRCADDR0)
#else
    MISSING(DMA_CH1_SRCADDR0)
#endif

#ifdef DMA_CH1_SRCADDR1
    DEFINE(DMA_CH1_SRCADDR1)
#else
    MISSING(DMA_CH1_SRCADDR1)
#endif

#ifdef DMA_CH1_SRCADDR2
    DEFINE(DMA_CH1_SRCADDR2)
#else
    MISSING(DMA_CH1_SRCADDR2)
#endif

#ifdef DMA_CH1_TRFCNT
    DEFINE(DMA_CH1_TRFCNT)
#else
    MISSING(DMA_CH1_TRFCNT)
#endif

#ifdef DMA_CH1_TRIGSRC
    DEFINE(DMA_CH1_TRIGSRC)
#else
    MISSING(DMA_CH1_TRIGSRC)
#endif

#ifdef DMA_CH2_ADDRCTRL
    DEFINE(DMA_CH2_ADDRCTRL)
#else
    MISSING(DMA_CH2_ADDRCTRL)
#endif

#ifdef DMA_CH2_CTRLA
    DEFINE(DMA_CH2_CTRLA)
#else
    MISSING(DMA_CH2_CTRLA)
#endif

#ifdef DMA_CH2_CTRLB
    DEFINE(DMA_CH2_CTRLB)
#else
    MISSING(DMA_CH2_CTRLB)
#endif

#ifdef DMA_CH2_DESTADDR0
    DEFINE(DMA_CH2_DESTADDR0)
#else
    MISSING(DMA_CH2_DESTADDR0)
#endif

#ifdef DMA_CH2_DESTADDR1
    DEFINE(DMA_CH2_DESTADDR1)
#else
    MISSING(DMA_CH2_DESTADDR1)
#endif

#ifdef DMA_CH2_DESTADDR2
    DEFINE(DMA_CH2_DESTADDR2)
#else
    MISSING(DMA_CH2_DESTADDR2)
#endif

#ifdef DMA_CH2_REPCNT
    DEFINE(DMA_CH2_REPCNT)
#else
    MISSING(DMA_CH2_REPCNT)
#endif

#ifdef DMA_CH2_SRCADDR0
    DEFINE(DMA_CH2_SRCADDR0)
#else
    MISSING(DMA_CH2_SRCADDR0)
#endif

#ifdef DMA_CH2_SRCADDR1
    DEFINE(DMA_CH2_SRCADDR1)
#else
    MISSING(DMA_CH2_SRCADDR1)
#endif

#ifdef DMA_CH2_SRCADDR2
    DEFINE(DMA_CH2_SRCADDR2)
#else
    MISSING(DMA_CH2_SRCADDR2)
#endif

#ifdef DMA_CH2_TRFCNT
    DEFINE(DMA_CH2_TRFCNT)
#else
    MISSING(DMA_CH2_TRFCNT)
#endif

#ifdef DMA_CH2_TRIGSRC
    DEFINE(DMA_CH2_TRIGSRC)
#else
    MISSING(DMA_CH2_TRIGSRC)
#endif

#ifdef DMA_CH3_ADDRCTRL
    DEFINE(DMA_CH3_ADDRCTRL)
#else
    MISSING(DMA_CH3_ADDRCTRL)
#endif

#ifdef DMA_CH3_CTRLA
    DEFINE(DMA_CH3_CTRLA)
#else
    MISSING(DMA_CH3_CTRLA)
#endif

#ifdef DMA_CH3_CTRLB
    DEFINE(DMA_CH3_CTRLB)
#else
    MISSING(DMA_CH3_CTRLB)
#endif

#ifdef DMA_CH3_DESTADDR0
    DEFINE(DMA_CH3_DESTADDR0)
#else
    MISSING(DMA_CH3_DESTADDR0)
#endif

#ifdef DMA_CH3_DESTADDR1
    DEFINE(DMA_CH3_DESTADDR1)
#else
    MISSING(DMA_CH3_DESTADDR1)
#endif

#ifdef DMA_CH3_DESTADDR2
    DEFINE(DMA_CH3_DESTADDR2)
#else
    MISSING(DMA_CH3_DESTADDR2)
#endif

#ifdef DMA_CH3_REPCNT
    DEFINE(DMA_CH3_REPCNT)
#else
    MISSING(DMA_CH3_REPCNT)
#endif

#ifdef DMA_CH3_SRCADDR0
    DEFINE(DMA_CH3_SRCADDR0)
#else
    MISSING(DMA_CH3_SRCADDR0)
#endif

#ifdef DMA_CH3_SRCADDR1
    DEFINE(DMA_CH3_SRCADDR1)
#else
    MISSING(DMA_CH3_SRCADDR1)
#endif

#ifdef DMA_CH3_SRCADDR2
    DEFINE(DMA_CH3_SRCADDR2)
#else
    MISSING(DMA_CH3_SRCADDR2)
#endif

#ifdef DMA_CH3_TRFCNT
    DEFINE(DMA_CH3_TRFCNT)
#else
    MISSING(DMA_CH3_TRFCNT)
#endif

#ifdef DMA_CH3_TRIGSRC
    DEFINE(DMA_CH3_TRIGSRC)
#else
    MISSING(DMA_CH3_TRIGSRC)
#endif

#ifdef DMA_CTRL
    DEFINE(DMA_CTRL)
#else
    MISSING(DMA_CTRL)
#endif

#ifdef DMA_INTFLAGS
    DEFINE(DMA_INTFLAGS)
#else
    MISSING(DMA_INTFLAGS)
#endif

#ifdef DMA_STATUS
    DEFINE(DMA_STATUS)
#else
    MISSING(DMA_STATUS)
#endif

#ifdef DMA_TEMP
    DEFINE(DMA_TEMP)
#else
    MISSING(DMA_TEMP)
#endif

#ifdef DPDS0
    DEFINE(DPDS0)
#else
    MISSING(DPDS0)
#endif

#ifdef DPDS1
    DEFINE(DPDS1)
#else
    MISSING(DPDS1)
#endif

#ifdef DRTRAM0
    DEFINE(DRTRAM0)
#else
    MISSING(DRTRAM0)
#endif

#ifdef DRTRAM1
    DEFINE(DRTRAM1)
#else
    MISSING(DRTRAM1)
#endif

#ifdef DRTRAM2
    DEFINE(DRTRAM2)
#else
    MISSING(DRTRAM2)
#endif

#ifdef DRTRAM3
    DEFINE(DRTRAM3)
#else
    MISSING(DRTRAM3)
#endif

#ifdef DT1
    DEFINE(DT1)
#else
    MISSING(DT1)
#endif

#ifdef DT1A
    DEFINE(DT1A)
#else
    MISSING(DT1A)
#endif

#ifdef DT1B
    DEFINE(DT1B)
#else
    MISSING(DT1B)
#endif

#ifdef DT4
    DEFINE(DT4)
#else
    MISSING(DT4)
#endif

#ifdef DTPS1
    DEFINE(DTPS1)
#else
    MISSING(DTPS1)
#endif

#ifdef DWDR
    DEFINE(DWDR)
#else
    MISSING(DWDR)
#endif

#ifdef EBI_CS0_BASEADDR
    DEFINE(EBI_CS0_BASEADDR)
#else
    MISSING(EBI_CS0_BASEADDR)
#endif

#ifdef EBI_CS0_CTRLA
    DEFINE(EBI_CS0_CTRLA)
#else
    MISSING(EBI_CS0_CTRLA)
#endif

#ifdef EBI_CS0_CTRLB
    DEFINE(EBI_CS0_CTRLB)
#else
    MISSING(EBI_CS0_CTRLB)
#endif

#ifdef EBI_CS1_BASEADDR
    DEFINE(EBI_CS1_BASEADDR)
#else
    MISSING(EBI_CS1_BASEADDR)
#endif

#ifdef EBI_CS1_CTRLA
    DEFINE(EBI_CS1_CTRLA)
#else
    MISSING(EBI_CS1_CTRLA)
#endif

#ifdef EBI_CS1_CTRLB
    DEFINE(EBI_CS1_CTRLB)
#else
    MISSING(EBI_CS1_CTRLB)
#endif

#ifdef EBI_CS2_BASEADDR
    DEFINE(EBI_CS2_BASEADDR)
#else
    MISSING(EBI_CS2_BASEADDR)
#endif

#ifdef EBI_CS2_CTRLA
    DEFINE(EBI_CS2_CTRLA)
#else
    MISSING(EBI_CS2_CTRLA)
#endif

#ifdef EBI_CS2_CTRLB
    DEFINE(EBI_CS2_CTRLB)
#else
    MISSING(EBI_CS2_CTRLB)
#endif

#ifdef EBI_CS3_BASEADDR
    DEFINE(EBI_CS3_BASEADDR)
#else
    MISSING(EBI_CS3_BASEADDR)
#endif

#ifdef EBI_CS3_CTRLA
    DEFINE(EBI_CS3_CTRLA)
#else
    MISSING(EBI_CS3_CTRLA)
#endif

#ifdef EBI_CS3_CTRLB
    DEFINE(EBI_CS3_CTRLB)
#else
    MISSING(EBI_CS3_CTRLB)
#endif

#ifdef EBI_CTRL
    DEFINE(EBI_CTRL)
#else
    MISSING(EBI_CTRL)
#endif

#ifdef EBI_INITDLY
    DEFINE(EBI_INITDLY)
#else
    MISSING(EBI_INITDLY)
#endif

#ifdef EBI_REFRESH
    DEFINE(EBI_REFRESH)
#else
    MISSING(EBI_REFRESH)
#endif

#ifdef EBI_SDRAMCTRLA
    DEFINE(EBI_SDRAMCTRLA)
#else
    MISSING(EBI_SDRAMCTRLA)
#endif

#ifdef EBI_SDRAMCTRLB
    DEFINE(EBI_SDRAMCTRLB)
#else
    MISSING(EBI_SDRAMCTRLB)
#endif

#ifdef EBI_SDRAMCTRLC
    DEFINE(EBI_SDRAMCTRLC)
#else
    MISSING(EBI_SDRAMCTRLC)
#endif

#ifdef EEAR
    DEFINE(EEAR)
#else
    MISSING(EEAR)
#endif

#ifdef EEARH
    DEFINE(EEARH)
#else
    MISSING(EEARH)
#endif

#ifdef EEARL
    DEFINE(EEARL)
#else
    MISSING(EEARL)
#endif

#ifdef EECR
    DEFINE(EECR)
#else
    MISSING(EECR)
#endif

#ifdef EEDR
    DEFINE(EEDR)
#else
    MISSING(EEDR)
#endif

#ifdef EICR
    DEFINE(EICR)
#else
    MISSING(EICR)
#endif

#ifdef EICRA
    DEFINE(EICRA)
#else
    MISSING(EICRA)
#endif

#ifdef EICRB
    DEFINE(EICRB)
#else
    MISSING(EICRB)
#endif

#ifdef EIFR
    DEFINE(EIFR)
#else
    MISSING(EIFR)
#endif

#ifdef EIMF
    DEFINE(EIMF)
#else
    MISSING(EIMF)
#endif

#ifdef EIMSK
    DEFINE(EIMSK)
#else
    MISSING(EIMSK)
#endif

#ifdef EIND
    DEFINE(EIND)
#else
    MISSING(EIND)
#endif

#ifdef EIRR
    DEFINE(EIRR)
#else
    MISSING(EIRR)
#endif

#ifdef EMCUCR
    DEFINE(EMCUCR)
#else
    MISSING(EMCUCR)
#endif

#ifdef ETIFR
    DEFINE(ETIFR)
#else
    MISSING(ETIFR)
#endif

#ifdef ETIMSK
    DEFINE(ETIMSK)
#else
    MISSING(ETIMSK)
#endif

#ifdef EUCSRA
    DEFINE(EUCSRA)
#else
    MISSING(EUCSRA)
#endif

#ifdef EUCSRB
    DEFINE(EUCSRB)
#else
    MISSING(EUCSRB)
#endif

#ifdef EUCSRC
    DEFINE(EUCSRC)
#else
    MISSING(EUCSRC)
#endif

#ifdef EUDR
    DEFINE(EUDR)
#else
    MISSING(EUDR)
#endif

#ifdef EVSYS_CH0CTRL
    DEFINE(EVSYS_CH0CTRL)
#else
    MISSING(EVSYS_CH0CTRL)
#endif

#ifdef EVSYS_CH0MUX
    DEFINE(EVSYS_CH0MUX)
#else
    MISSING(EVSYS_CH0MUX)
#endif

#ifdef EVSYS_CH1CTRL
    DEFINE(EVSYS_CH1CTRL)
#else
    MISSING(EVSYS_CH1CTRL)
#endif

#ifdef EVSYS_CH1MUX
    DEFINE(EVSYS_CH1MUX)
#else
    MISSING(EVSYS_CH1MUX)
#endif

#ifdef EVSYS_CH2CTRL
    DEFINE(EVSYS_CH2CTRL)
#else
    MISSING(EVSYS_CH2CTRL)
#endif

#ifdef EVSYS_CH2MUX
    DEFINE(EVSYS_CH2MUX)
#else
    MISSING(EVSYS_CH2MUX)
#endif

#ifdef EVSYS_CH3CTRL
    DEFINE(EVSYS_CH3CTRL)
#else
    MISSING(EVSYS_CH3CTRL)
#endif

#ifdef EVSYS_CH3MUX
    DEFINE(EVSYS_CH3MUX)
#else
    MISSING(EVSYS_CH3MUX)
#endif

#ifdef EVSYS_CH4CTRL
    DEFINE(EVSYS_CH4CTRL)
#else
    MISSING(EVSYS_CH4CTRL)
#endif

#ifdef EVSYS_CH4MUX
    DEFINE(EVSYS_CH4MUX)
#else
    MISSING(EVSYS_CH4MUX)
#endif

#ifdef EVSYS_CH5CTRL
    DEFINE(EVSYS_CH5CTRL)
#else
    MISSING(EVSYS_CH5CTRL)
#endif

#ifdef EVSYS_CH5MUX
    DEFINE(EVSYS_CH5MUX)
#else
    MISSING(EVSYS_CH5MUX)
#endif

#ifdef EVSYS_CH6CTRL
    DEFINE(EVSYS_CH6CTRL)
#else
    MISSING(EVSYS_CH6CTRL)
#endif

#ifdef EVSYS_CH6MUX
    DEFINE(EVSYS_CH6MUX)
#else
    MISSING(EVSYS_CH6MUX)
#endif

#ifdef EVSYS_CH7CTRL
    DEFINE(EVSYS_CH7CTRL)
#else
    MISSING(EVSYS_CH7CTRL)
#endif

#ifdef EVSYS_CH7MUX
    DEFINE(EVSYS_CH7MUX)
#else
    MISSING(EVSYS_CH7MUX)
#endif

#ifdef EVSYS_DATA
    DEFINE(EVSYS_DATA)
#else
    MISSING(EVSYS_DATA)
#endif

#ifdef EVSYS_STROBE
    DEFINE(EVSYS_STROBE)
#else
    MISSING(EVSYS_STROBE)
#endif

#ifdef EXOCR1A
    DEFINE(EXOCR1A)
#else
    MISSING(EXOCR1A)
#endif

#ifdef EXOCR1AH
    DEFINE(EXOCR1AH)
#else
    MISSING(EXOCR1AH)
#endif

#ifdef EXOCR1AL
    DEFINE(EXOCR1AL)
#else
    MISSING(EXOCR1AL)
#endif

#ifdef EXOCR1B
    DEFINE(EXOCR1B)
#else
    MISSING(EXOCR1B)
#endif

#ifdef EXOCR1BH
    DEFINE(EXOCR1BH)
#else
    MISSING(EXOCR1BH)
#endif

#ifdef EXOCR1BL
    DEFINE(EXOCR1BL)
#else
    MISSING(EXOCR1BL)
#endif

#ifdef EXTCCR0
    DEFINE(EXTCCR0)
#else
    MISSING(EXTCCR0)
#endif

#ifdef EXTCCR1A
    DEFINE(EXTCCR1A)
#else
    MISSING(EXTCCR1A)
#endif

#ifdef EXTCCR1B
    DEFINE(EXTCCR1B)
#else
    MISSING(EXTCCR1B)
#endif

#ifdef EXTCNT
    DEFINE(EXTCNT)
#else
    MISSING(EXTCNT)
#endif

#ifdef EXTCNT1
    DEFINE(EXTCNT1)
#else
    MISSING(EXTCNT1)
#endif

#ifdef EXTCNT1H
    DEFINE(EXTCNT1H)
#else
    MISSING(EXTCNT1H)
#endif

#ifdef EXTCNT1L
    DEFINE(EXTCNT1L)
#else
    MISSING(EXTCNT1L)
#endif

#ifdef EXTIFR
    DEFINE(EXTIFR)
#else
    MISSING(EXTIFR)
#endif

#ifdef EXTIMSK
    DEFINE(EXTIMSK)
#else
    MISSING(EXTIMSK)
#endif

#ifdef FCSR
    DEFINE(FCSR)
#else
    MISSING(FCSR)
#endif

#ifdef FISCR
    DEFINE(FISCR)
#else
    MISSING(FISCR)
#endif

#ifdef FISUA
    DEFINE(FISUA)
#else
    MISSING(FISUA)
#endif

#ifdef FISUB
    DEFINE(FISUB)
#else
    MISSING(FISUB)
#endif

#ifdef FISUC
    DEFINE(FISUC)
#else
    MISSING(FISUC)
#endif

#ifdef FISUD
    DEFINE(FISUD)
#else
    MISSING(FISUD)
#endif

#ifdef FOSCCAL
    DEFINE(FOSCCAL)
#else
    MISSING(FOSCCAL)
#endif

#ifdef FPGAD
    DEFINE(FPGAD)
#else
    MISSING(FPGAD)
#endif

#ifdef FPGAX
    DEFINE(FPGAX)
#else
    MISSING(FPGAX)
#endif

#ifdef FPGAY
    DEFINE(FPGAY)
#else
    MISSING(FPGAY)
#endif

#ifdef FPGAZ
    DEFINE(FPGAZ)
#else
    MISSING(FPGAZ)
#endif

#ifdef FRCCAL
    DEFINE(FRCCAL)
#else
    MISSING(FRCCAL)
#endif

#ifdef FTN_CTRL
    DEFINE(FTN_CTRL)
#else
    MISSING(FTN_CTRL)
#endif

#ifdef GAINDAC
    DEFINE(GAINDAC)
#else
    MISSING(GAINDAC)
#endif

#ifdef GICR
    DEFINE(GICR)
#else
    MISSING(GICR)
#endif

#ifdef GIFR
    DEFINE(GIFR)
#else
    MISSING(GIFR)
#endif

#ifdef GIMSK
    DEFINE(GIMSK)
#else
    MISSING(GIMSK)
#endif

#ifdef GIPR
    DEFINE(GIPR)
#else
    MISSING(GIPR)
#endif

#ifdef GPIO0
    DEFINE(GPIO0)
#else
    MISSING(GPIO0)
#endif

#ifdef GPIO1
    DEFINE(GPIO1)
#else
    MISSING(GPIO1)
#endif

#ifdef GPIO2
    DEFINE(GPIO2)
#else
    MISSING(GPIO2)
#endif

#ifdef GPIO3
    DEFINE(GPIO3)
#else
    MISSING(GPIO3)
#endif

#ifdef GPIO4
    DEFINE(GPIO4)
#else
    MISSING(GPIO4)
#endif

#ifdef GPIO5
    DEFINE(GPIO5)
#else
    MISSING(GPIO5)
#endif

#ifdef GPIO6
    DEFINE(GPIO6)
#else
    MISSING(GPIO6)
#endif

#ifdef GPIO7
    DEFINE(GPIO7)
#else
    MISSING(GPIO7)
#endif

#ifdef GPIO8
    DEFINE(GPIO8)
#else
    MISSING(GPIO8)
#endif

#ifdef GPIO9
    DEFINE(GPIO9)
#else
    MISSING(GPIO9)
#endif

#ifdef GPIOA
    DEFINE(GPIOA)
#else
    MISSING(GPIOA)
#endif

#ifdef GPIOB
    DEFINE(GPIOB)
#else
    MISSING(GPIOB)
#endif

#ifdef GPIOC
    DEFINE(GPIOC)
#else
    MISSING(GPIOC)
#endif

#ifdef GPIOD
    DEFINE(GPIOD)
#else
    MISSING(GPIOD)
#endif

#ifdef GPIOE
    DEFINE(GPIOE)
#else
    MISSING(GPIOE)
#endif

#ifdef GPIOF
    DEFINE(GPIOF)
#else
    MISSING(GPIOF)
#endif

#ifdef GPIOR0
    DEFINE(GPIOR0)
#else
    MISSING(GPIOR0)
#endif

#ifdef GPIOR1
    DEFINE(GPIOR1)
#else
    MISSING(GPIOR1)
#endif

#ifdef GPIOR2
    DEFINE(GPIOR2)
#else
    MISSING(GPIOR2)
#endif

#ifdef GPIOR3
    DEFINE(GPIOR3)
#else
    MISSING(GPIOR3)
#endif

#ifdef GPIOR4
    DEFINE(GPIOR4)
#else
    MISSING(GPIOR4)
#endif

#ifdef GPIOR5
    DEFINE(GPIOR5)
#else
    MISSING(GPIOR5)
#endif

#ifdef GPIOR6
    DEFINE(GPIOR6)
#else
    MISSING(GPIOR6)
#endif

#ifdef GPIOR7
    DEFINE(GPIOR7)
#else
    MISSING(GPIOR7)
#endif

#ifdef GPIOR8
    DEFINE(GPIOR8)
#else
    MISSING(GPIOR8)
#endif

#ifdef GPIOR9
    DEFINE(GPIOR9)
#else
    MISSING(GPIOR9)
#endif

#ifdef GPIORA
    DEFINE(GPIORA)
#else
    MISSING(GPIORA)
#endif

#ifdef GPIORB
    DEFINE(GPIORB)
#else
    MISSING(GPIORB)
#endif

#ifdef GPIORC
    DEFINE(GPIORC)
#else
    MISSING(GPIORC)
#endif

#ifdef GPIORD
    DEFINE(GPIORD)
#else
    MISSING(GPIORD)
#endif

#ifdef GPIORE
    DEFINE(GPIORE)
#else
    MISSING(GPIORE)
#endif

#ifdef GPIORF
    DEFINE(GPIORF)
#else
    MISSING(GPIORF)
#endif

#ifdef GPIO_GPIO0
    DEFINE(GPIO_GPIO0)
#else
    MISSING(GPIO_GPIO0)
#endif

#ifdef GPIO_GPIO1
    DEFINE(GPIO_GPIO1)
#else
    MISSING(GPIO_GPIO1)
#endif

#ifdef GPIO_GPIO2
    DEFINE(GPIO_GPIO2)
#else
    MISSING(GPIO_GPIO2)
#endif

#ifdef GPIO_GPIO3
    DEFINE(GPIO_GPIO3)
#else
    MISSING(GPIO_GPIO3)
#endif

#ifdef GPIO_GPIO4
    DEFINE(GPIO_GPIO4)
#else
    MISSING(GPIO_GPIO4)
#endif

#ifdef GPIO_GPIO5
    DEFINE(GPIO_GPIO5)
#else
    MISSING(GPIO_GPIO5)
#endif

#ifdef GPIO_GPIO6
    DEFINE(GPIO_GPIO6)
#else
    MISSING(GPIO_GPIO6)
#endif

#ifdef GPIO_GPIO7
    DEFINE(GPIO_GPIO7)
#else
    MISSING(GPIO_GPIO7)
#endif

#ifdef GPIO_GPIO8
    DEFINE(GPIO_GPIO8)
#else
    MISSING(GPIO_GPIO8)
#endif

#ifdef GPIO_GPIO9
    DEFINE(GPIO_GPIO9)
#else
    MISSING(GPIO_GPIO9)
#endif

#ifdef GPIO_GPIOA
    DEFINE(GPIO_GPIOA)
#else
    MISSING(GPIO_GPIOA)
#endif

#ifdef GPIO_GPIOB
    DEFINE(GPIO_GPIOB)
#else
    MISSING(GPIO_GPIOB)
#endif

#ifdef GPIO_GPIOC
    DEFINE(GPIO_GPIOC)
#else
    MISSING(GPIO_GPIOC)
#endif

#ifdef GPIO_GPIOD
    DEFINE(GPIO_GPIOD)
#else
    MISSING(GPIO_GPIOD)
#endif

#ifdef GPIO_GPIOE
    DEFINE(GPIO_GPIOE)
#else
    MISSING(GPIO_GPIOE)
#endif

#ifdef GPIO_GPIOF
    DEFINE(GPIO_GPIOF)
#else
    MISSING(GPIO_GPIOF)
#endif

#ifdef GPIO_GPIOR0
    DEFINE(GPIO_GPIOR0)
#else
    MISSING(GPIO_GPIOR0)
#endif

#ifdef GPIO_GPIOR1
    DEFINE(GPIO_GPIOR1)
#else
    MISSING(GPIO_GPIOR1)
#endif

#ifdef GPIO_GPIOR2
    DEFINE(GPIO_GPIOR2)
#else
    MISSING(GPIO_GPIOR2)
#endif

#ifdef GPIO_GPIOR3
    DEFINE(GPIO_GPIOR3)
#else
    MISSING(GPIO_GPIOR3)
#endif

#ifdef GPIO_GPIOR4
    DEFINE(GPIO_GPIOR4)
#else
    MISSING(GPIO_GPIOR4)
#endif

#ifdef GPIO_GPIOR5
    DEFINE(GPIO_GPIOR5)
#else
    MISSING(GPIO_GPIOR5)
#endif

#ifdef GPIO_GPIOR6
    DEFINE(GPIO_GPIOR6)
#else
    MISSING(GPIO_GPIOR6)
#endif

#ifdef GPIO_GPIOR7
    DEFINE(GPIO_GPIOR7)
#else
    MISSING(GPIO_GPIOR7)
#endif

#ifdef GPIO_GPIOR8
    DEFINE(GPIO_GPIOR8)
#else
    MISSING(GPIO_GPIOR8)
#endif

#ifdef GPIO_GPIOR9
    DEFINE(GPIO_GPIOR9)
#else
    MISSING(GPIO_GPIOR9)
#endif

#ifdef GPIO_GPIORA
    DEFINE(GPIO_GPIORA)
#else
    MISSING(GPIO_GPIORA)
#endif

#ifdef GPIO_GPIORB
    DEFINE(GPIO_GPIORB)
#else
    MISSING(GPIO_GPIORB)
#endif

#ifdef GPIO_GPIORC
    DEFINE(GPIO_GPIORC)
#else
    MISSING(GPIO_GPIORC)
#endif

#ifdef GPIO_GPIORD
    DEFINE(GPIO_GPIORD)
#else
    MISSING(GPIO_GPIORD)
#endif

#ifdef GPIO_GPIORE
    DEFINE(GPIO_GPIORE)
#else
    MISSING(GPIO_GPIORE)
#endif

#ifdef GPIO_GPIORF
    DEFINE(GPIO_GPIORF)
#else
    MISSING(GPIO_GPIORF)
#endif

#ifdef GTCCR
    DEFINE(GTCCR)
#else
    MISSING(GTCCR)
#endif

#ifdef HIRESC_CTRLA
    DEFINE(HIRESC_CTRLA)
#else
    MISSING(HIRESC_CTRLA)
#endif

#ifdef HIRESD_CTRLA
    DEFINE(HIRESD_CTRLA)
#else
    MISSING(HIRESD_CTRLA)
#endif

#ifdef HIRESE_CTRLA
    DEFINE(HIRESE_CTRLA)
#else
    MISSING(HIRESE_CTRLA)
#endif

#ifdef HIRESF_CTRLA
    DEFINE(HIRESF_CTRLA)
#else
    MISSING(HIRESF_CTRLA)
#endif

#ifdef HSSPICFG
    DEFINE(HSSPICFG)
#else
    MISSING(HSSPICFG)
#endif

#ifdef HSSPICNT
    DEFINE(HSSPICNT)
#else
    MISSING(HSSPICNT)
#endif

#ifdef HSSPICR
    DEFINE(HSSPICR)
#else
    MISSING(HSSPICR)
#endif

#ifdef HSSPIDMAB
    DEFINE(HSSPIDMAB)
#else
    MISSING(HSSPIDMAB)
#endif

#ifdef HSSPIDMACS
    DEFINE(HSSPIDMACS)
#else
    MISSING(HSSPIDMACS)
#endif

#ifdef HSSPIDMAD
    DEFINE(HSSPIDMAD)
#else
    MISSING(HSSPIDMAD)
#endif

#ifdef HSSPIDMADH
    DEFINE(HSSPIDMADH)
#else
    MISSING(HSSPIDMADH)
#endif

#ifdef HSSPIDMADL
    DEFINE(HSSPIDMADL)
#else
    MISSING(HSSPIDMADL)
#endif

#ifdef HSSPIGTR
    DEFINE(HSSPIGTR)
#else
    MISSING(HSSPIGTR)
#endif

#ifdef HSSPIIER
    DEFINE(HSSPIIER)
#else
    MISSING(HSSPIIER)
#endif

#ifdef HSSPIIR
    DEFINE(HSSPIIR)
#else
    MISSING(HSSPIIR)
#endif

#ifdef HSSPIRDR
    DEFINE(HSSPIRDR)
#else
    MISSING(HSSPIRDR)
#endif

#ifdef HSSPISR
    DEFINE(HSSPISR)
#else
    MISSING(HSSPISR)
#endif

#ifdef HSSPITDR
    DEFINE(HSSPITDR)
#else
    MISSING(HSSPITDR)
#endif

#ifdef HSSPITO
    DEFINE(HSSPITO)
#else
    MISSING(HSSPITO)
#endif

#ifdef HSSPITOH
    DEFINE(HSSPITOH)
#else
    MISSING(HSSPITOH)
#endif

#ifdef HSSPITOL
    DEFINE(HSSPITOL)
#else
    MISSING(HSSPITOL)
#endif

#ifdef ICR
    DEFINE(ICR)
#else
    MISSING(ICR)
#endif

#ifdef ICR0
    DEFINE(ICR0)
#else
    MISSING(ICR0)
#endif

#ifdef ICR0H
    DEFINE(ICR0H)
#else
    MISSING(ICR0H)
#endif

#ifdef ICR0L
    DEFINE(ICR0L)
#else
    MISSING(ICR0L)
#endif

#ifdef ICR1
    DEFINE(ICR1)
#else
    MISSING(ICR1)
#endif

#ifdef ICR1H
    DEFINE(ICR1H)
#else
    MISSING(ICR1H)
#endif

#ifdef ICR1L
    DEFINE(ICR1L)
#else
    MISSING(ICR1L)
#endif

#ifdef ICR3
    DEFINE(ICR3)
#else
    MISSING(ICR3)
#endif

#ifdef ICR3H
    DEFINE(ICR3H)
#else
    MISSING(ICR3H)
#endif

#ifdef ICR3L
    DEFINE(ICR3L)
#else
    MISSING(ICR3L)
#endif

#ifdef ICR4
    DEFINE(ICR4)
#else
    MISSING(ICR4)
#endif

#ifdef ICR4H
    DEFINE(ICR4H)
#else
    MISSING(ICR4H)
#endif

#ifdef ICR4L
    DEFINE(ICR4L)
#else
    MISSING(ICR4L)
#endif

#ifdef ICR5
    DEFINE(ICR5)
#else
    MISSING(ICR5)
#endif

#ifdef ICR5H
    DEFINE(ICR5H)
#else
    MISSING(ICR5H)
#endif

#ifdef ICR5L
    DEFINE(ICR5L)
#else
    MISSING(ICR5L)
#endif

#ifdef IDXCTRL
    DEFINE(IDXCTRL)
#else
    MISSING(IDXCTRL)
#endif

#ifdef IDXIFLG
    DEFINE(IDXIFLG)
#else
    MISSING(IDXIFLG)
#endif

#ifdef IDXIMSK
    DEFINE(IDXIMSK)
#else
    MISSING(IDXIMSK)
#endif

#ifdef IDXMSDT
    DEFINE(IDXMSDT)
#else
    MISSING(IDXMSDT)
#endif

#ifdef IDXSTRB
    DEFINE(IDXSTRB)
#else
    MISSING(IDXSTRB)
#endif

#ifdef IEEE_ADDR_0
    DEFINE(IEEE_ADDR_0)
#else
    MISSING(IEEE_ADDR_0)
#endif

#ifdef IEEE_ADDR_1
    DEFINE(IEEE_ADDR_1)
#else
    MISSING(IEEE_ADDR_1)
#endif

#ifdef IEEE_ADDR_2
    DEFINE(IEEE_ADDR_2)
#else
    MISSING(IEEE_ADDR_2)
#endif

#ifdef IEEE_ADDR_3
    DEFINE(IEEE_ADDR_3)
#else
    MISSING(IEEE_ADDR_3)
#endif

#ifdef IEEE_ADDR_4
    DEFINE(IEEE_ADDR_4)
#else
    MISSING(IEEE_ADDR_4)
#endif

#ifdef IEEE_ADDR_5
    DEFINE(IEEE_ADDR_5)
#else
    MISSING(IEEE_ADDR_5)
#endif

#ifdef IEEE_ADDR_6
    DEFINE(IEEE_ADDR_6)
#else
    MISSING(IEEE_ADDR_6)
#endif

#ifdef IEEE_ADDR_7
    DEFINE(IEEE_ADDR_7)
#else
    MISSING(IEEE_ADDR_7)
#endif

#ifdef IFR
    DEFINE(IFR)
#else
    MISSING(IFR)
#endif

#ifdef INOCR1A
    DEFINE(INOCR1A)
#else
    MISSING(INOCR1A)
#endif

#ifdef INOCR1AH
    DEFINE(INOCR1AH)
#else
    MISSING(INOCR1AH)
#endif

#ifdef INOCR1AL
    DEFINE(INOCR1AL)
#else
    MISSING(INOCR1AL)
#endif

#ifdef INOCR1B
    DEFINE(INOCR1B)
#else
    MISSING(INOCR1B)
#endif

#ifdef INOCR1BH
    DEFINE(INOCR1BH)
#else
    MISSING(INOCR1BH)
#endif

#ifdef INOCR1BL
    DEFINE(INOCR1BL)
#else
    MISSING(INOCR1BL)
#endif

#ifdef INTCCR0
    DEFINE(INTCCR0)
#else
    MISSING(INTCCR0)
#endif

#ifdef INTCCR1A
    DEFINE(INTCCR1A)
#else
    MISSING(INTCCR1A)
#endif

#ifdef INTCCR1B
    DEFINE(INTCCR1B)
#else
    MISSING(INTCCR1B)
#endif

#ifdef INTCNT
    DEFINE(INTCNT)
#else
    MISSING(INTCNT)
#endif

#ifdef INTCNT1
    DEFINE(INTCNT1)
#else
    MISSING(INTCNT1)
#endif

#ifdef INTCNT1H
    DEFINE(INTCNT1H)
#else
    MISSING(INTCNT1H)
#endif

#ifdef INTCNT1L
    DEFINE(INTCNT1L)
#else
    MISSING(INTCNT1L)
#endif

#ifdef INTIFR
    DEFINE(INTIFR)
#else
    MISSING(INTIFR)
#endif

#ifdef INTIMSK
    DEFINE(INTIMSK)
#else
    MISSING(INTIMSK)
#endif

#ifdef IOF
    DEFINE(IOF)
#else
    MISSING(IOF)
#endif

#ifdef IO_DATIN
    DEFINE(IO_DATIN)
#else
    MISSING(IO_DATIN)
#endif

#ifdef IO_DATOUT
    DEFINE(IO_DATOUT)
#else
    MISSING(IO_DATOUT)
#endif

#ifdef IO_ENAB
    DEFINE(IO_ENAB)
#else
    MISSING(IO_ENAB)
#endif

#ifdef IPA
    DEFINE(IPA)
#else
    MISSING(IPA)
#endif

#ifdef IPAH
    DEFINE(IPAH)
#else
    MISSING(IPAH)
#endif

#ifdef IPAL
    DEFINE(IPAL)
#else
    MISSING(IPAL)
#endif

#ifdef IPCR
    DEFINE(IPCR)
#else
    MISSING(IPCR)
#endif

#ifdef IPD
    DEFINE(IPD)
#else
    MISSING(IPD)
#endif

#ifdef IPDH
    DEFINE(IPDH)
#else
    MISSING(IPDH)
#endif

#ifdef IPDL
    DEFINE(IPDL)
#else
    MISSING(IPDL)
#endif

#ifdef IRCOM_CTRL
    DEFINE(IRCOM_CTRL)
#else
    MISSING(IRCOM_CTRL)
#endif

#ifdef IRCOM_RXPLCTRL
    DEFINE(IRCOM_RXPLCTRL)
#else
    MISSING(IRCOM_RXPLCTRL)
#endif

#ifdef IRCOM_TXPLCTRL
    DEFINE(IRCOM_TXPLCTRL)
#else
    MISSING(IRCOM_TXPLCTRL)
#endif

#ifdef IRDAMOD
    DEFINE(IRDAMOD)
#else
    MISSING(IRDAMOD)
#endif

#ifdef IRQ_MASK
    DEFINE(IRQ_MASK)
#else
    MISSING(IRQ_MASK)
#endif

#ifdef IRQ_STATUS
    DEFINE(IRQ_STATUS)
#else
    MISSING(IRQ_STATUS)
#endif

#ifdef KBER
    DEFINE(KBER)
#else
    MISSING(KBER)
#endif

#ifdef KBFR
    DEFINE(KBFR)
#else
    MISSING(KBFR)
#endif

#ifdef KBLSR
    DEFINE(KBLSR)
#else
    MISSING(KBLSR)
#endif

#ifdef LCDCCR
    DEFINE(LCDCCR)
#else
    MISSING(LCDCCR)
#endif

#ifdef LCDCRA
    DEFINE(LCDCRA)
#else
    MISSING(LCDCRA)
#endif

#ifdef LCDCRB
    DEFINE(LCDCRB)
#else
    MISSING(LCDCRB)
#endif

#ifdef LCDDR0
    DEFINE(LCDDR0)
#else
    MISSING(LCDDR0)
#endif

#ifdef LCDDR00
    DEFINE(LCDDR00)
#else
    MISSING(LCDDR00)
#endif

#ifdef LCDDR01
    DEFINE(LCDDR01)
#else
    MISSING(LCDDR01)
#endif

#ifdef LCDDR02
    DEFINE(LCDDR02)
#else
    MISSING(LCDDR02)
#endif

#ifdef LCDDR03
    DEFINE(LCDDR03)
#else
    MISSING(LCDDR03)
#endif

#ifdef LCDDR04
    DEFINE(LCDDR04)
#else
    MISSING(LCDDR04)
#endif

#ifdef LCDDR05
    DEFINE(LCDDR05)
#else
    MISSING(LCDDR05)
#endif

#ifdef LCDDR06
    DEFINE(LCDDR06)
#else
    MISSING(LCDDR06)
#endif

#ifdef LCDDR07
    DEFINE(LCDDR07)
#else
    MISSING(LCDDR07)
#endif

#ifdef LCDDR08
    DEFINE(LCDDR08)
#else
    MISSING(LCDDR08)
#endif

#ifdef LCDDR09
    DEFINE(LCDDR09)
#else
    MISSING(LCDDR09)
#endif

#ifdef LCDDR1
    DEFINE(LCDDR1)
#else
    MISSING(LCDDR1)
#endif

#ifdef LCDDR10
    DEFINE(LCDDR10)
#else
    MISSING(LCDDR10)
#endif

#ifdef LCDDR11
    DEFINE(LCDDR11)
#else
    MISSING(LCDDR11)
#endif

#ifdef LCDDR12
    DEFINE(LCDDR12)
#else
    MISSING(LCDDR12)
#endif

#ifdef LCDDR13
    DEFINE(LCDDR13)
#else
    MISSING(LCDDR13)
#endif

#ifdef LCDDR14
    DEFINE(LCDDR14)
#else
    MISSING(LCDDR14)
#endif

#ifdef LCDDR15
    DEFINE(LCDDR15)
#else
    MISSING(LCDDR15)
#endif

#ifdef LCDDR16
    DEFINE(LCDDR16)
#else
    MISSING(LCDDR16)
#endif

#ifdef LCDDR17
    DEFINE(LCDDR17)
#else
    MISSING(LCDDR17)
#endif

#ifdef LCDDR18
    DEFINE(LCDDR18)
#else
    MISSING(LCDDR18)
#endif

#ifdef LCDDR19
    DEFINE(LCDDR19)
#else
    MISSING(LCDDR19)
#endif

#ifdef LCDDR2
    DEFINE(LCDDR2)
#else
    MISSING(LCDDR2)
#endif

#ifdef LCDDR3
    DEFINE(LCDDR3)
#else
    MISSING(LCDDR3)
#endif

#ifdef LCDDR4
    DEFINE(LCDDR4)
#else
    MISSING(LCDDR4)
#endif

#ifdef LCDDR5
    DEFINE(LCDDR5)
#else
    MISSING(LCDDR5)
#endif

#ifdef LCDDR6
    DEFINE(LCDDR6)
#else
    MISSING(LCDDR6)
#endif

#ifdef LCDDR7
    DEFINE(LCDDR7)
#else
    MISSING(LCDDR7)
#endif

#ifdef LCDDR8
    DEFINE(LCDDR8)
#else
    MISSING(LCDDR8)
#endif

#ifdef LCDDR9
    DEFINE(LCDDR9)
#else
    MISSING(LCDDR9)
#endif

#ifdef LCDFRR
    DEFINE(LCDFRR)
#else
    MISSING(LCDFRR)
#endif

#ifdef LEDCR
    DEFINE(LEDCR)
#else
    MISSING(LEDCR)
#endif

#ifdef LFCAL
    DEFINE(LFCAL)
#else
    MISSING(LFCAL)
#endif

#ifdef LFCALH
    DEFINE(LFCALH)
#else
    MISSING(LFCALH)
#endif

#ifdef LFCALL
    DEFINE(LFCALL)
#else
    MISSING(LFCALL)
#endif

#ifdef LFCDR
    DEFINE(LFCDR)
#else
    MISSING(LFCDR)
#endif

#ifdef LFFR
    DEFINE(LFFR)
#else
    MISSING(LFFR)
#endif

#ifdef LFHCR
    DEFINE(LFHCR)
#else
    MISSING(LFHCR)
#endif

#ifdef LFIDC
    DEFINE(LFIDC)
#else
    MISSING(LFIDC)
#endif

#ifdef LFIDCH
    DEFINE(LFIDCH)
#else
    MISSING(LFIDCH)
#endif

#ifdef LFIDCL
    DEFINE(LFIDCL)
#else
    MISSING(LFIDCL)
#endif

#ifdef LFIMR
    DEFINE(LFIMR)
#else
    MISSING(LFIMR)
#endif

#ifdef LFRB
    DEFINE(LFRB)
#else
    MISSING(LFRB)
#endif

#ifdef LFRCR
    DEFINE(LFRCR)
#else
    MISSING(LFRCR)
#endif

#ifdef LFRR
    DEFINE(LFRR)
#else
    MISSING(LFRR)
#endif

#ifdef LFSR0
    DEFINE(LFSR0)
#else
    MISSING(LFSR0)
#endif

#ifdef LFSR1
    DEFINE(LFSR1)
#else
    MISSING(LFSR1)
#endif

#ifdef LFSR2
    DEFINE(LFSR2)
#else
    MISSING(LFSR2)
#endif

#ifdef LFSR3
    DEFINE(LFSR3)
#else
    MISSING(LFSR3)
#endif

#ifdef LINBRR
    DEFINE(LINBRR)
#else
    MISSING(LINBRR)
#endif

#ifdef LINBRRH
    DEFINE(LINBRRH)
#else
    MISSING(LINBRRH)
#endif

#ifdef LINBRRL
    DEFINE(LINBRRL)
#else
    MISSING(LINBRRL)
#endif

#ifdef LINBTR
    DEFINE(LINBTR)
#else
    MISSING(LINBTR)
#endif

#ifdef LINCR
    DEFINE(LINCR)
#else
    MISSING(LINCR)
#endif

#ifdef LINDAT
    DEFINE(LINDAT)
#else
    MISSING(LINDAT)
#endif

#ifdef LINDLR
    DEFINE(LINDLR)
#else
    MISSING(LINDLR)
#endif

#ifdef LINENIR
    DEFINE(LINENIR)
#else
    MISSING(LINENIR)
#endif

#ifdef LINERR
    DEFINE(LINERR)
#else
    MISSING(LINERR)
#endif

#ifdef LINIDR
    DEFINE(LINIDR)
#else
    MISSING(LINIDR)
#endif

#ifdef LINSEL
    DEFINE(LINSEL)
#else
    MISSING(LINSEL)
#endif

#ifdef LINSIR
    DEFINE(LINSIR)
#else
    MISSING(LINSIR)
#endif

#ifdef LLCR
    DEFINE(LLCR)
#else
    MISSING(LLCR)
#endif

#ifdef LLDRH
    DEFINE(LLDRH)
#else
    MISSING(LLDRH)
#endif

#ifdef LLDRL
    DEFINE(LLDRL)
#else
    MISSING(LLDRL)
#endif

#ifdef LOCKDET1
    DEFINE(LOCKDET1)
#else
    MISSING(LOCKDET1)
#endif

#ifdef LOCKDET2
    DEFINE(LOCKDET2)
#else
    MISSING(LOCKDET2)
#endif

#ifdef MAN_ID_0
    DEFINE(MAN_ID_0)
#else
    MISSING(MAN_ID_0)
#endif

#ifdef MAN_ID_1
    DEFINE(MAN_ID_1)
#else
    MISSING(MAN_ID_1)
#endif

#ifdef MCSR
    DEFINE(MCSR)
#else
    MISSING(MCSR)
#endif

#ifdef MCUCR
    DEFINE(MCUCR)
#else
    MISSING(MCUCR)
#endif

#ifdef MCUCS
    DEFINE(MCUCS)
#else
    MISSING(MCUCS)
#endif

#ifdef MCUCSR
    DEFINE(MCUCSR)
#else
    MISSING(MCUCSR)
#endif

#ifdef MCUR
    DEFINE(MCUR)
#else
    MISSING(MCUR)
#endif

#ifdef MCUSR
    DEFINE(MCUSR)
#else
    MISSING(MCUSR)
#endif

#ifdef MCU_ANAINIT
    DEFINE(MCU_ANAINIT)
#else
    MISSING(MCU_ANAINIT)
#endif

#ifdef MCU_AWEXLOCK
    DEFINE(MCU_AWEXLOCK)
#else
    MISSING(MCU_AWEXLOCK)
#endif

#ifdef MCU_DEVID0
    DEFINE(MCU_DEVID0)
#else
    MISSING(MCU_DEVID0)
#endif

#ifdef MCU_DEVID1
    DEFINE(MCU_DEVID1)
#else
    MISSING(MCU_DEVID1)
#endif

#ifdef MCU_DEVID2
    DEFINE(MCU_DEVID2)
#else
    MISSING(MCU_DEVID2)
#endif

#ifdef MCU_EVSYSLOCK
    DEFINE(MCU_EVSYSLOCK)
#else
    MISSING(MCU_EVSYSLOCK)
#endif

#ifdef MCU_JTAGUID
    DEFINE(MCU_JTAGUID)
#else
    MISSING(MCU_JTAGUID)
#endif

#ifdef MCU_MCUCR
    DEFINE(MCU_MCUCR)
#else
    MISSING(MCU_MCUCR)
#endif

#ifdef MCU_REVID
    DEFINE(MCU_REVID)
#else
    MISSING(MCU_REVID)
#endif

#ifdef MODCR
    DEFINE(MODCR)
#else
    MISSING(MODCR)
#endif

#ifdef MONDR
    DEFINE(MONDR)
#else
    MISSING(MONDR)
#endif

#ifdef MSELR
    DEFINE(MSELR)
#else
    MISSING(MSELR)
#endif

#ifdef MSMCR
    DEFINE(MSMCR)
#else
    MISSING(MSMCR)
#endif

#ifdef MSPCR
    DEFINE(MSPCR)
#else
    MISSING(MSPCR)
#endif

#ifdef MSPDR
    DEFINE(MSPDR)
#else
    MISSING(MSPDR)
#endif

#ifdef MSPSR
    DEFINE(MSPSR)
#else
    MISSING(MSPSR)
#endif

#ifdef MSVCAL
    DEFINE(MSVCAL)
#else
    MISSING(MSVCAL)
#endif

#ifdef MUBRR
    DEFINE(MUBRR)
#else
    MISSING(MUBRR)
#endif

#ifdef MUBRRH
    DEFINE(MUBRRH)
#else
    MISSING(MUBRRH)
#endif

#ifdef MUBRRL
    DEFINE(MUBRRL)
#else
    MISSING(MUBRRL)
#endif

#ifdef NEMCR
    DEFINE(NEMCR)
#else
    MISSING(NEMCR)
#endif

#ifdef NVMCMD
    DEFINE(NVMCMD)
#else
    MISSING(NVMCMD)
#endif

#ifdef NVMCSR
    DEFINE(NVMCSR)
#else
    MISSING(NVMCSR)
#endif

#ifdef NVM_ADDR0
    DEFINE(NVM_ADDR0)
#else
    MISSING(NVM_ADDR0)
#endif

#ifdef NVM_ADDR1
    DEFINE(NVM_ADDR1)
#else
    MISSING(NVM_ADDR1)
#endif

#ifdef NVM_ADDR2
    DEFINE(NVM_ADDR2)
#else
    MISSING(NVM_ADDR2)
#endif

#ifdef NVM_CMD
    DEFINE(NVM_CMD)
#else
    MISSING(NVM_CMD)
#endif

#ifdef NVM_CTRLA
    DEFINE(NVM_CTRLA)
#else
    MISSING(NVM_CTRLA)
#endif

#ifdef NVM_CTRLB
    DEFINE(NVM_CTRLB)
#else
    MISSING(NVM_CTRLB)
#endif

#ifdef NVM_DATA0
    DEFINE(NVM_DATA0)
#else
    MISSING(NVM_DATA0)
#endif

#ifdef NVM_DATA1
    DEFINE(NVM_DATA1)
#else
    MISSING(NVM_DATA1)
#endif

#ifdef NVM_DATA2
    DEFINE(NVM_DATA2)
#else
    MISSING(NVM_DATA2)
#endif

#ifdef NVM_INTCTRL
    DEFINE(NVM_INTCTRL)
#else
    MISSING(NVM_INTCTRL)
#endif

#ifdef NVM_LOCKBITS
    DEFINE(NVM_LOCKBITS)
#else
    MISSING(NVM_LOCKBITS)
#endif

#ifdef NVM_STATUS
    DEFINE(NVM_STATUS)
#else
    MISSING(NVM_STATUS)
#endif

#ifdef OCDR
    DEFINE(OCDR)
#else
    MISSING(OCDR)
#endif

#ifdef OCD_OCDR0
    DEFINE(OCD_OCDR0)
#else
    MISSING(OCD_OCDR0)
#endif

#ifdef OCD_OCDR1
    DEFINE(OCD_OCDR1)
#else
    MISSING(OCD_OCDR1)
#endif

#ifdef OCR0
    DEFINE(OCR0)
#else
    MISSING(OCR0)
#endif

#ifdef OCR0A
    DEFINE(OCR0A)
#else
    MISSING(OCR0A)
#endif

#ifdef OCR0AH
    DEFINE(OCR0AH)
#else
    MISSING(OCR0AH)
#endif

#ifdef OCR0AL
    DEFINE(OCR0AL)
#else
    MISSING(OCR0AL)
#endif

#ifdef OCR0B
    DEFINE(OCR0B)
#else
    MISSING(OCR0B)
#endif

#ifdef OCR0BH
    DEFINE(OCR0BH)
#else
    MISSING(OCR0BH)
#endif

#ifdef OCR0BL
    DEFINE(OCR0BL)
#else
    MISSING(OCR0BL)
#endif

#ifdef OCR0RA
    DEFINE(OCR0RA)
#else
    MISSING(OCR0RA)
#endif

#ifdef OCR0RAH
    DEFINE(OCR0RAH)
#else
    MISSING(OCR0RAH)
#endif

#ifdef OCR0RAL
    DEFINE(OCR0RAL)
#else
    MISSING(OCR0RAL)
#endif

#ifdef OCR0RB
    DEFINE(OCR0RB)
#else
    MISSING(OCR0RB)
#endif

#ifdef OCR0RBH
    DEFINE(OCR0RBH)
#else
    MISSING(OCR0RBH)
#endif

#ifdef OCR0RBL
    DEFINE(OCR0RBL)
#else
    MISSING(OCR0RBL)
#endif

#ifdef OCR0SA
    DEFINE(OCR0SA)
#else
    MISSING(OCR0SA)
#endif

#ifdef OCR0SAH
    DEFINE(OCR0SAH)
#else
    MISSING(OCR0SAH)
#endif

#ifdef OCR0SAL
    DEFINE(OCR0SAL)
#else
    MISSING(OCR0SAL)
#endif

#ifdef OCR0SB
    DEFINE(OCR0SB)
#else
    MISSING(OCR0SB)
#endif

#ifdef OCR0SBH
    DEFINE(OCR0SBH)
#else
    MISSING(OCR0SBH)
#endif

#ifdef OCR0SBL
    DEFINE(OCR0SBL)
#else
    MISSING(OCR0SBL)
#endif

#ifdef OCR1
    DEFINE(OCR1)
#else
    MISSING(OCR1)
#endif

#ifdef OCR1A
    DEFINE(OCR1A)
#else
    MISSING(OCR1A)
#endif

#ifdef OCR1AH
    DEFINE(OCR1AH)
#else
    MISSING(OCR1AH)
#endif

#ifdef OCR1AL
    DEFINE(OCR1AL)
#else
    MISSING(OCR1AL)
#endif

#ifdef OCR1B
    DEFINE(OCR1B)
#else
    MISSING(OCR1B)
#endif

#ifdef OCR1BH
    DEFINE(OCR1BH)
#else
    MISSING(OCR1BH)
#endif

#ifdef OCR1BL
    DEFINE(OCR1BL)
#else
    MISSING(OCR1BL)
#endif

#ifdef OCR1C
    DEFINE(OCR1C)
#else
    MISSING(OCR1C)
#endif

#ifdef OCR1CH
    DEFINE(OCR1CH)
#else
    MISSING(OCR1CH)
#endif

#ifdef OCR1CL
    DEFINE(OCR1CL)
#else
    MISSING(OCR1CL)
#endif

#ifdef OCR1D
    DEFINE(OCR1D)
#else
    MISSING(OCR1D)
#endif

#ifdef OCR1H
    DEFINE(OCR1H)
#else
    MISSING(OCR1H)
#endif

#ifdef OCR1L
    DEFINE(OCR1L)
#else
    MISSING(OCR1L)
#endif

#ifdef OCR1RA
    DEFINE(OCR1RA)
#else
    MISSING(OCR1RA)
#endif

#ifdef OCR1RAH
    DEFINE(OCR1RAH)
#else
    MISSING(OCR1RAH)
#endif

#ifdef OCR1RAL
    DEFINE(OCR1RAL)
#else
    MISSING(OCR1RAL)
#endif

#ifdef OCR1RB
    DEFINE(OCR1RB)
#else
    MISSING(OCR1RB)
#endif

#ifdef OCR1RBH
    DEFINE(OCR1RBH)
#else
    MISSING(OCR1RBH)
#endif

#ifdef OCR1RBL
    DEFINE(OCR1RBL)
#else
    MISSING(OCR1RBL)
#endif

#ifdef OCR1SA
    DEFINE(OCR1SA)
#else
    MISSING(OCR1SA)
#endif

#ifdef OCR1SAH
    DEFINE(OCR1SAH)
#else
    MISSING(OCR1SAH)
#endif

#ifdef OCR1SAL
    DEFINE(OCR1SAL)
#else
    MISSING(OCR1SAL)
#endif

#ifdef OCR1SB
    DEFINE(OCR1SB)
#else
    MISSING(OCR1SB)
#endif

#ifdef OCR1SBH
    DEFINE(OCR1SBH)
#else
    MISSING(OCR1SBH)
#endif

#ifdef OCR1SBL
    DEFINE(OCR1SBL)
#else
    MISSING(OCR1SBL)
#endif

#ifdef OCR2
    DEFINE(OCR2)
#else
    MISSING(OCR2)
#endif

#ifdef OCR2A
    DEFINE(OCR2A)
#else
    MISSING(OCR2A)
#endif

#ifdef OCR2B
    DEFINE(OCR2B)
#else
    MISSING(OCR2B)
#endif

#ifdef OCR2RA
    DEFINE(OCR2RA)
#else
    MISSING(OCR2RA)
#endif

#ifdef OCR2RAH
    DEFINE(OCR2RAH)
#else
    MISSING(OCR2RAH)
#endif

#ifdef OCR2RAL
    DEFINE(OCR2RAL)
#else
    MISSING(OCR2RAL)
#endif

#ifdef OCR2RB
    DEFINE(OCR2RB)
#else
    MISSING(OCR2RB)
#endif

#ifdef OCR2RBH
    DEFINE(OCR2RBH)
#else
    MISSING(OCR2RBH)
#endif

#ifdef OCR2RBL
    DEFINE(OCR2RBL)
#else
    MISSING(OCR2RBL)
#endif

#ifdef OCR2SA
    DEFINE(OCR2SA)
#else
    MISSING(OCR2SA)
#endif

#ifdef OCR2SAH
    DEFINE(OCR2SAH)
#else
    MISSING(OCR2SAH)
#endif

#ifdef OCR2SAL
    DEFINE(OCR2SAL)
#else
    MISSING(OCR2SAL)
#endif

#ifdef OCR2SB
    DEFINE(OCR2SB)
#else
    MISSING(OCR2SB)
#endif

#ifdef OCR2SBH
    DEFINE(OCR2SBH)
#else
    MISSING(OCR2SBH)
#endif

#ifdef OCR2SBL
    DEFINE(OCR2SBL)
#else
    MISSING(OCR2SBL)
#endif

#ifdef OCR3A
    DEFINE(OCR3A)
#else
    MISSING(OCR3A)
#endif

#ifdef OCR3AH
    DEFINE(OCR3AH)
#else
    MISSING(OCR3AH)
#endif

#ifdef OCR3AL
    DEFINE(OCR3AL)
#else
    MISSING(OCR3AL)
#endif

#ifdef OCR3B
    DEFINE(OCR3B)
#else
    MISSING(OCR3B)
#endif

#ifdef OCR3BH
    DEFINE(OCR3BH)
#else
    MISSING(OCR3BH)
#endif

#ifdef OCR3BL
    DEFINE(OCR3BL)
#else
    MISSING(OCR3BL)
#endif

#ifdef OCR3C
    DEFINE(OCR3C)
#else
    MISSING(OCR3C)
#endif

#ifdef OCR3CH
    DEFINE(OCR3CH)
#else
    MISSING(OCR3CH)
#endif

#ifdef OCR3CL
    DEFINE(OCR3CL)
#else
    MISSING(OCR3CL)
#endif

#ifdef OCR4A
    DEFINE(OCR4A)
#else
    MISSING(OCR4A)
#endif

#ifdef OCR4AH
    DEFINE(OCR4AH)
#else
    MISSING(OCR4AH)
#endif

#ifdef OCR4AL
    DEFINE(OCR4AL)
#else
    MISSING(OCR4AL)
#endif

#ifdef OCR4B
    DEFINE(OCR4B)
#else
    MISSING(OCR4B)
#endif

#ifdef OCR4BH
    DEFINE(OCR4BH)
#else
    MISSING(OCR4BH)
#endif

#ifdef OCR4BL
    DEFINE(OCR4BL)
#else
    MISSING(OCR4BL)
#endif

#ifdef OCR4C
    DEFINE(OCR4C)
#else
    MISSING(OCR4C)
#endif

#ifdef OCR4CH
    DEFINE(OCR4CH)
#else
    MISSING(OCR4CH)
#endif

#ifdef OCR4CL
    DEFINE(OCR4CL)
#else
    MISSING(OCR4CL)
#endif

#ifdef OCR4D
    DEFINE(OCR4D)
#else
    MISSING(OCR4D)
#endif

#ifdef OCR5A
    DEFINE(OCR5A)
#else
    MISSING(OCR5A)
#endif

#ifdef OCR5AH
    DEFINE(OCR5AH)
#else
    MISSING(OCR5AH)
#endif

#ifdef OCR5AL
    DEFINE(OCR5AL)
#else
    MISSING(OCR5AL)
#endif

#ifdef OCR5B
    DEFINE(OCR5B)
#else
    MISSING(OCR5B)
#endif

#ifdef OCR5BH
    DEFINE(OCR5BH)
#else
    MISSING(OCR5BH)
#endif

#ifdef OCR5BL
    DEFINE(OCR5BL)
#else
    MISSING(OCR5BL)
#endif

#ifdef OCR5C
    DEFINE(OCR5C)
#else
    MISSING(OCR5C)
#endif

#ifdef OCR5CH
    DEFINE(OCR5CH)
#else
    MISSING(OCR5CH)
#endif

#ifdef OCR5CL
    DEFINE(OCR5CL)
#else
    MISSING(OCR5CL)
#endif

#ifdef OCRA1
    DEFINE(OCRA1)
#else
    MISSING(OCRA1)
#endif

#ifdef OCRA1H
    DEFINE(OCRA1H)
#else
    MISSING(OCRA1H)
#endif

#ifdef OCRA1L
    DEFINE(OCRA1L)
#else
    MISSING(OCRA1L)
#endif

#ifdef OCRB1
    DEFINE(OCRB1)
#else
    MISSING(OCRB1)
#endif

#ifdef OCRB1H
    DEFINE(OCRB1H)
#else
    MISSING(OCRB1H)
#endif

#ifdef OCRB1L
    DEFINE(OCRB1L)
#else
    MISSING(OCRB1L)
#endif

#ifdef OSCCAL
    DEFINE(OSCCAL)
#else
    MISSING(OSCCAL)
#endif

#ifdef OSC_CTRL
    DEFINE(OSC_CTRL)
#else
    MISSING(OSC_CTRL)
#endif

#ifdef OSC_DFLLCTRL
    DEFINE(OSC_DFLLCTRL)
#else
    MISSING(OSC_DFLLCTRL)
#endif

#ifdef OSC_PLLCTRL
    DEFINE(OSC_PLLCTRL)
#else
    MISSING(OSC_PLLCTRL)
#endif

#ifdef OSC_RC32KCAL
    DEFINE(OSC_RC32KCAL)
#else
    MISSING(OSC_RC32KCAL)
#endif

#ifdef OSC_STATUS
    DEFINE(OSC_STATUS)
#else
    MISSING(OSC_STATUS)
#endif

#ifdef OSC_XOSCCTRL
    DEFINE(OSC_XOSCCTRL)
#else
    MISSING(OSC_XOSCCTRL)
#endif

#ifdef OSC_XOSCFAIL
    DEFINE(OSC_XOSCFAIL)
#else
    MISSING(OSC_XOSCFAIL)
#endif

#ifdef OSICSR
    DEFINE(OSICSR)
#else
    MISSING(OSICSR)
#endif

#ifdef OTGCON
    DEFINE(OTGCON)
#else
    MISSING(OTGCON)
#endif

#ifdef OTGIEN
    DEFINE(OTGIEN)
#else
    MISSING(OTGIEN)
#endif

#ifdef OTGINT
    DEFINE(OTGINT)
#else
    MISSING(OTGINT)
#endif

#ifdef OTGTCON
    DEFINE(OTGTCON)
#else
    MISSING(OTGTCON)
#endif

#ifdef PACR
    DEFINE(PACR)
#else
    MISSING(PACR)
#endif

#ifdef PAN_ID_0
    DEFINE(PAN_ID_0)
#else
    MISSING(PAN_ID_0)
#endif

#ifdef PAN_ID_1
    DEFINE(PAN_ID_1)
#else
    MISSING(PAN_ID_1)
#endif

#ifdef PART_NUM
    DEFINE(PART_NUM)
#else
    MISSING(PART_NUM)
#endif

#ifdef PASDLY2
    DEFINE(PASDLY2)
#else
    MISSING(PASDLY2)
#endif

#ifdef PBOV
    DEFINE(PBOV)
#else
    MISSING(PBOV)
#endif

#ifdef PCICR
    DEFINE(PCICR)
#else
    MISSING(PCICR)
#endif

#ifdef PCIFR
    DEFINE(PCIFR)
#else
    MISSING(PCIFR)
#endif

#ifdef PCMSK
    DEFINE(PCMSK)
#else
    MISSING(PCMSK)
#endif

#ifdef PCMSK0
    DEFINE(PCMSK0)
#else
    MISSING(PCMSK0)
#endif

#ifdef PCMSK1
    DEFINE(PCMSK1)
#else
    MISSING(PCMSK1)
#endif

#ifdef PCMSK2
    DEFINE(PCMSK2)
#else
    MISSING(PCMSK2)
#endif

#ifdef PCMSK3
    DEFINE(PCMSK3)
#else
    MISSING(PCMSK3)
#endif

#ifdef PCNF
    DEFINE(PCNF)
#else
    MISSING(PCNF)
#endif

#ifdef PCNF0
    DEFINE(PCNF0)
#else
    MISSING(PCNF0)
#endif

#ifdef PCNF1
    DEFINE(PCNF1)
#else
    MISSING(PCNF1)
#endif

#ifdef PCNF2
    DEFINE(PCNF2)
#else
    MISSING(PCNF2)
#endif

#ifdef PCNFE2
    DEFINE(PCNFE2)
#else
    MISSING(PCNFE2)
#endif

#ifdef PCTL
    DEFINE(PCTL)
#else
    MISSING(PCTL)
#endif

#ifdef PCTL0
    DEFINE(PCTL0)
#else
    MISSING(PCTL0)
#endif

#ifdef PCTL1
    DEFINE(PCTL1)
#else
    MISSING(PCTL1)
#endif

#ifdef PCTL2
    DEFINE(PCTL2)
#else
    MISSING(PCTL2)
#endif

#ifdef PERIPHEN
    DEFINE(PERIPHEN)
#else
    MISSING(PERIPHEN)
#endif

#ifdef PFRC0A
    DEFINE(PFRC0A)
#else
    MISSING(PFRC0A)
#endif

#ifdef PFRC0B
    DEFINE(PFRC0B)
#else
    MISSING(PFRC0B)
#endif

#ifdef PFRC1A
    DEFINE(PFRC1A)
#else
    MISSING(PFRC1A)
#endif

#ifdef PFRC1B
    DEFINE(PFRC1B)
#else
    MISSING(PFRC1B)
#endif

#ifdef PFRC2A
    DEFINE(PFRC2A)
#else
    MISSING(PFRC2A)
#endif

#ifdef PFRC2B
    DEFINE(PFRC2B)
#else
    MISSING(PFRC2B)
#endif

#ifdef PHY_CC_CCA
    DEFINE(PHY_CC_CCA)
#else
    MISSING(PHY_CC_CCA)
#endif

#ifdef PHY_ED_LEVEL
    DEFINE(PHY_ED_LEVEL)
#else
    MISSING(PHY_ED_LEVEL)
#endif

#ifdef PHY_RSSI
    DEFINE(PHY_RSSI)
#else
    MISSING(PHY_RSSI)
#endif

#ifdef PHY_TX_PWR
    DEFINE(PHY_TX_PWR)
#else
    MISSING(PHY_TX_PWR)
#endif

#ifdef PICR0
    DEFINE(PICR0)
#else
    MISSING(PICR0)
#endif

#ifdef PICR0H
    DEFINE(PICR0H)
#else
    MISSING(PICR0H)
#endif

#ifdef PICR0L
    DEFINE(PICR0L)
#else
    MISSING(PICR0L)
#endif

#ifdef PICR1
    DEFINE(PICR1)
#else
    MISSING(PICR1)
#endif

#ifdef PICR1H
    DEFINE(PICR1H)
#else
    MISSING(PICR1H)
#endif

#ifdef PICR1L
    DEFINE(PICR1L)
#else
    MISSING(PICR1L)
#endif

#ifdef PICR2
    DEFINE(PICR2)
#else
    MISSING(PICR2)
#endif

#ifdef PICR2H
    DEFINE(PICR2H)
#else
    MISSING(PICR2H)
#endif

#ifdef PICR2L
    DEFINE(PICR2L)
#else
    MISSING(PICR2L)
#endif

#ifdef PIFR
    DEFINE(PIFR)
#else
    MISSING(PIFR)
#endif

#ifdef PIFR0
    DEFINE(PIFR0)
#else
    MISSING(PIFR0)
#endif

#ifdef PIFR1
    DEFINE(PIFR1)
#else
    MISSING(PIFR1)
#endif

#ifdef PIFR2
    DEFINE(PIFR2)
#else
    MISSING(PIFR2)
#endif

#ifdef PIM
    DEFINE(PIM)
#else
    MISSING(PIM)
#endif

#ifdef PIM0
    DEFINE(PIM0)
#else
    MISSING(PIM0)
#endif

#ifdef PIM1
    DEFINE(PIM1)
#else
    MISSING(PIM1)
#endif

#ifdef PIM2
    DEFINE(PIM2)
#else
    MISSING(PIM2)
#endif

#ifdef PINA
    DEFINE(PINA)
#else
    MISSING(PINA)
#endif

#ifdef PINB
    DEFINE(PINB)
#else
    MISSING(PINB)
#endif

#ifdef PINC
    DEFINE(PINC)
#else
    MISSING(PINC)
#endif

#ifdef PIND
    DEFINE(PIND)
#else
    MISSING(PIND)
#endif

#ifdef PINE
    DEFINE(PINE)
#else
    MISSING(PINE)
#endif

#ifdef PINF
    DEFINE(PINF)
#else
    MISSING(PINF)
#endif

#ifdef PING
    DEFINE(PING)
#else
    MISSING(PING)
#endif

#ifdef PINH
    DEFINE(PINH)
#else
    MISSING(PINH)
#endif

#ifdef PINJ
    DEFINE(PINJ)
#else
    MISSING(PINJ)
#endif

#ifdef PINK
    DEFINE(PINK)
#else
    MISSING(PINK)
#endif

#ifdef PINL
    DEFINE(PINL)
#else
    MISSING(PINL)
#endif

#ifdef PLLCR
    DEFINE(PLLCR)
#else
    MISSING(PLLCR)
#endif

#ifdef PLLCSR
    DEFINE(PLLCSR)
#else
    MISSING(PLLCSR)
#endif

#ifdef PLLFRQ
    DEFINE(PLLFRQ)
#else
    MISSING(PLLFRQ)
#endif

#ifdef PLL_CF
    DEFINE(PLL_CF)
#else
    MISSING(PLL_CF)
#endif

#ifdef PLL_DCU
    DEFINE(PLL_DCU)
#else
    MISSING(PLL_DCU)
#endif

#ifdef PMIC0
    DEFINE(PMIC0)
#else
    MISSING(PMIC0)
#endif

#ifdef PMIC1
    DEFINE(PMIC1)
#else
    MISSING(PMIC1)
#endif

#ifdef PMIC2
    DEFINE(PMIC2)
#else
    MISSING(PMIC2)
#endif

#ifdef PMIC_CTRL
    DEFINE(PMIC_CTRL)
#else
    MISSING(PMIC_CTRL)
#endif

#ifdef PMIC_INTPRI
    DEFINE(PMIC_INTPRI)
#else
    MISSING(PMIC_INTPRI)
#endif

#ifdef PMIC_STATUS
    DEFINE(PMIC_STATUS)
#else
    MISSING(PMIC_STATUS)
#endif

#ifdef POC
    DEFINE(POC)
#else
    MISSING(POC)
#endif

#ifdef POCR0RA
    DEFINE(POCR0RA)
#else
    MISSING(POCR0RA)
#endif

#ifdef POCR0RAH
    DEFINE(POCR0RAH)
#else
    MISSING(POCR0RAH)
#endif

#ifdef POCR0RAL
    DEFINE(POCR0RAL)
#else
    MISSING(POCR0RAL)
#endif

#ifdef POCR0SA
    DEFINE(POCR0SA)
#else
    MISSING(POCR0SA)
#endif

#ifdef POCR0SAH
    DEFINE(POCR0SAH)
#else
    MISSING(POCR0SAH)
#endif

#ifdef POCR0SAL
    DEFINE(POCR0SAL)
#else
    MISSING(POCR0SAL)
#endif

#ifdef POCR0SB
    DEFINE(POCR0SB)
#else
    MISSING(POCR0SB)
#endif

#ifdef POCR0SBH
    DEFINE(POCR0SBH)
#else
    MISSING(POCR0SBH)
#endif

#ifdef POCR0SBL
    DEFINE(POCR0SBL)
#else
    MISSING(POCR0SBL)
#endif

#ifdef POCR1RA
    DEFINE(POCR1RA)
#else
    MISSING(POCR1RA)
#endif

#ifdef POCR1RAH
    DEFINE(POCR1RAH)
#else
    MISSING(POCR1RAH)
#endif

#ifdef POCR1RAL
    DEFINE(POCR1RAL)
#else
    MISSING(POCR1RAL)
#endif

#ifdef POCR1SA
    DEFINE(POCR1SA)
#else
    MISSING(POCR1SA)
#endif

#ifdef POCR1SAH
    DEFINE(POCR1SAH)
#else
    MISSING(POCR1SAH)
#endif

#ifdef POCR1SAL
    DEFINE(POCR1SAL)
#else
    MISSING(POCR1SAL)
#endif

#ifdef POCR1SB
    DEFINE(POCR1SB)
#else
    MISSING(POCR1SB)
#endif

#ifdef POCR1SBH
    DEFINE(POCR1SBH)
#else
    MISSING(POCR1SBH)
#endif

#ifdef POCR1SBL
    DEFINE(POCR1SBL)
#else
    MISSING(POCR1SBL)
#endif

#ifdef POCR2RA
    DEFINE(POCR2RA)
#else
    MISSING(POCR2RA)
#endif

#ifdef POCR2RAH
    DEFINE(POCR2RAH)
#else
    MISSING(POCR2RAH)
#endif

#ifdef POCR2RAL
    DEFINE(POCR2RAL)
#else
    MISSING(POCR2RAL)
#endif

#ifdef POCR2SA
    DEFINE(POCR2SA)
#else
    MISSING(POCR2SA)
#endif

#ifdef POCR2SAH
    DEFINE(POCR2SAH)
#else
    MISSING(POCR2SAH)
#endif

#ifdef POCR2SAL
    DEFINE(POCR2SAL)
#else
    MISSING(POCR2SAL)
#endif

#ifdef POCR2SB
    DEFINE(POCR2SB)
#else
    MISSING(POCR2SB)
#endif

#ifdef POCR2SBH
    DEFINE(POCR2SBH)
#else
    MISSING(POCR2SBH)
#endif

#ifdef POCR2SBL
    DEFINE(POCR2SBL)
#else
    MISSING(POCR2SBL)
#endif

#ifdef POCR_RB
    DEFINE(POCR_RB)
#else
    MISSING(POCR_RB)
#endif

#ifdef POCR_RBH
    DEFINE(POCR_RBH)
#else
    MISSING(POCR_RBH)
#endif

#ifdef POCR_RBL
    DEFINE(POCR_RBL)
#else
    MISSING(POCR_RBL)
#endif

#ifdef POCRxRB
    DEFINE(POCRxRB)
#else
    MISSING(POCRxRB)
#endif

#ifdef POCRxRBH
    DEFINE(POCRxRBH)
#else
    MISSING(POCRxRBH)
#endif

#ifdef POCRxRBL
    DEFINE(POCRxRBL)
#else
    MISSING(POCRxRBL)
#endif

#ifdef POM2
    DEFINE(POM2)
#else
    MISSING(POM2)
#endif

#ifdef PORTA
    DEFINE(PORTA)
#else
    MISSING(PORTA)
#endif

#ifdef PORTA_DIR
    DEFINE(PORTA_DIR)
#else
    MISSING(PORTA_DIR)
#endif

#ifdef PORTA_DIRCLR
    DEFINE(PORTA_DIRCLR)
#else
    MISSING(PORTA_DIRCLR)
#endif

#ifdef PORTA_DIRSET
    DEFINE(PORTA_DIRSET)
#else
    MISSING(PORTA_DIRSET)
#endif

#ifdef PORTA_DIRTGL
    DEFINE(PORTA_DIRTGL)
#else
    MISSING(PORTA_DIRTGL)
#endif

#ifdef PORTA_IN
    DEFINE(PORTA_IN)
#else
    MISSING(PORTA_IN)
#endif

#ifdef PORTA_INT0MASK
    DEFINE(PORTA_INT0MASK)
#else
    MISSING(PORTA_INT0MASK)
#endif

#ifdef PORTA_INT1MASK
    DEFINE(PORTA_INT1MASK)
#else
    MISSING(PORTA_INT1MASK)
#endif

#ifdef PORTA_INTCTRL
    DEFINE(PORTA_INTCTRL)
#else
    MISSING(PORTA_INTCTRL)
#endif

#ifdef PORTA_INTFLAGS
    DEFINE(PORTA_INTFLAGS)
#else
    MISSING(PORTA_INTFLAGS)
#endif

#ifdef PORTA_OUT
    DEFINE(PORTA_OUT)
#else
    MISSING(PORTA_OUT)
#endif

#ifdef PORTA_OUTCLR
    DEFINE(PORTA_OUTCLR)
#else
    MISSING(PORTA_OUTCLR)
#endif

#ifdef PORTA_OUTSET
    DEFINE(PORTA_OUTSET)
#else
    MISSING(PORTA_OUTSET)
#endif

#ifdef PORTA_OUTTGL
    DEFINE(PORTA_OUTTGL)
#else
    MISSING(PORTA_OUTTGL)
#endif

#ifdef PORTA_PIN0CTRL
    DEFINE(PORTA_PIN0CTRL)
#else
    MISSING(PORTA_PIN0CTRL)
#endif

#ifdef PORTA_PIN1CTRL
    DEFINE(PORTA_PIN1CTRL)
#else
    MISSING(PORTA_PIN1CTRL)
#endif

#ifdef PORTA_PIN2CTRL
    DEFINE(PORTA_PIN2CTRL)
#else
    MISSING(PORTA_PIN2CTRL)
#endif

#ifdef PORTA_PIN3CTRL
    DEFINE(PORTA_PIN3CTRL)
#else
    MISSING(PORTA_PIN3CTRL)
#endif

#ifdef PORTA_PIN4CTRL
    DEFINE(PORTA_PIN4CTRL)
#else
    MISSING(PORTA_PIN4CTRL)
#endif

#ifdef PORTA_PIN5CTRL
    DEFINE(PORTA_PIN5CTRL)
#else
    MISSING(PORTA_PIN5CTRL)
#endif

#ifdef PORTA_PIN6CTRL
    DEFINE(PORTA_PIN6CTRL)
#else
    MISSING(PORTA_PIN6CTRL)
#endif

#ifdef PORTA_PIN7CTRL
    DEFINE(PORTA_PIN7CTRL)
#else
    MISSING(PORTA_PIN7CTRL)
#endif

#ifdef PORTB
    DEFINE(PORTB)
#else
    MISSING(PORTB)
#endif

#ifdef PORTB_DIR
    DEFINE(PORTB_DIR)
#else
    MISSING(PORTB_DIR)
#endif

#ifdef PORTB_DIRCLR
    DEFINE(PORTB_DIRCLR)
#else
    MISSING(PORTB_DIRCLR)
#endif

#ifdef PORTB_DIRSET
    DEFINE(PORTB_DIRSET)
#else
    MISSING(PORTB_DIRSET)
#endif

#ifdef PORTB_DIRTGL
    DEFINE(PORTB_DIRTGL)
#else
    MISSING(PORTB_DIRTGL)
#endif

#ifdef PORTB_IN
    DEFINE(PORTB_IN)
#else
    MISSING(PORTB_IN)
#endif

#ifdef PORTB_INT0MASK
    DEFINE(PORTB_INT0MASK)
#else
    MISSING(PORTB_INT0MASK)
#endif

#ifdef PORTB_INT1MASK
    DEFINE(PORTB_INT1MASK)
#else
    MISSING(PORTB_INT1MASK)
#endif

#ifdef PORTB_INTCTRL
    DEFINE(PORTB_INTCTRL)
#else
    MISSING(PORTB_INTCTRL)
#endif

#ifdef PORTB_INTFLAGS
    DEFINE(PORTB_INTFLAGS)
#else
    MISSING(PORTB_INTFLAGS)
#endif

#ifdef PORTB_OUT
    DEFINE(PORTB_OUT)
#else
    MISSING(PORTB_OUT)
#endif

#ifdef PORTB_OUTCLR
    DEFINE(PORTB_OUTCLR)
#else
    MISSING(PORTB_OUTCLR)
#endif

#ifdef PORTB_OUTSET
    DEFINE(PORTB_OUTSET)
#else
    MISSING(PORTB_OUTSET)
#endif

#ifdef PORTB_OUTTGL
    DEFINE(PORTB_OUTTGL)
#else
    MISSING(PORTB_OUTTGL)
#endif

#ifdef PORTB_PIN0CTRL
    DEFINE(PORTB_PIN0CTRL)
#else
    MISSING(PORTB_PIN0CTRL)
#endif

#ifdef PORTB_PIN1CTRL
    DEFINE(PORTB_PIN1CTRL)
#else
    MISSING(PORTB_PIN1CTRL)
#endif

#ifdef PORTB_PIN2CTRL
    DEFINE(PORTB_PIN2CTRL)
#else
    MISSING(PORTB_PIN2CTRL)
#endif

#ifdef PORTB_PIN3CTRL
    DEFINE(PORTB_PIN3CTRL)
#else
    MISSING(PORTB_PIN3CTRL)
#endif

#ifdef PORTB_PIN4CTRL
    DEFINE(PORTB_PIN4CTRL)
#else
    MISSING(PORTB_PIN4CTRL)
#endif

#ifdef PORTB_PIN5CTRL
    DEFINE(PORTB_PIN5CTRL)
#else
    MISSING(PORTB_PIN5CTRL)
#endif

#ifdef PORTB_PIN6CTRL
    DEFINE(PORTB_PIN6CTRL)
#else
    MISSING(PORTB_PIN6CTRL)
#endif

#ifdef PORTB_PIN7CTRL
    DEFINE(PORTB_PIN7CTRL)
#else
    MISSING(PORTB_PIN7CTRL)
#endif

#ifdef PORTC
    DEFINE(PORTC)
#else
    MISSING(PORTC)
#endif

#ifdef PORTCFG_CLKEVOUT
    DEFINE(PORTCFG_CLKEVOUT)
#else
    MISSING(PORTCFG_CLKEVOUT)
#endif

#ifdef PORTCFG_MPCMASK
    DEFINE(PORTCFG_MPCMASK)
#else
    MISSING(PORTCFG_MPCMASK)
#endif

#ifdef PORTCFG_VPCTRLA
    DEFINE(PORTCFG_VPCTRLA)
#else
    MISSING(PORTCFG_VPCTRLA)
#endif

#ifdef PORTCFG_VPCTRLB
    DEFINE(PORTCFG_VPCTRLB)
#else
    MISSING(PORTCFG_VPCTRLB)
#endif

#ifdef PORTCR
    DEFINE(PORTCR)
#else
    MISSING(PORTCR)
#endif

#ifdef PORTC_DIR
    DEFINE(PORTC_DIR)
#else
    MISSING(PORTC_DIR)
#endif

#ifdef PORTC_DIRCLR
    DEFINE(PORTC_DIRCLR)
#else
    MISSING(PORTC_DIRCLR)
#endif

#ifdef PORTC_DIRSET
    DEFINE(PORTC_DIRSET)
#else
    MISSING(PORTC_DIRSET)
#endif

#ifdef PORTC_DIRTGL
    DEFINE(PORTC_DIRTGL)
#else
    MISSING(PORTC_DIRTGL)
#endif

#ifdef PORTC_IN
    DEFINE(PORTC_IN)
#else
    MISSING(PORTC_IN)
#endif

#ifdef PORTC_INT0MASK
    DEFINE(PORTC_INT0MASK)
#else
    MISSING(PORTC_INT0MASK)
#endif

#ifdef PORTC_INT1MASK
    DEFINE(PORTC_INT1MASK)
#else
    MISSING(PORTC_INT1MASK)
#endif

#ifdef PORTC_INTCTRL
    DEFINE(PORTC_INTCTRL)
#else
    MISSING(PORTC_INTCTRL)
#endif

#ifdef PORTC_INTFLAGS
    DEFINE(PORTC_INTFLAGS)
#else
    MISSING(PORTC_INTFLAGS)
#endif

#ifdef PORTC_OUT
    DEFINE(PORTC_OUT)
#else
    MISSING(PORTC_OUT)
#endif

#ifdef PORTC_OUTCLR
    DEFINE(PORTC_OUTCLR)
#else
    MISSING(PORTC_OUTCLR)
#endif

#ifdef PORTC_OUTSET
    DEFINE(PORTC_OUTSET)
#else
    MISSING(PORTC_OUTSET)
#endif

#ifdef PORTC_OUTTGL
    DEFINE(PORTC_OUTTGL)
#else
    MISSING(PORTC_OUTTGL)
#endif

#ifdef PORTC_PIN0CTRL
    DEFINE(PORTC_PIN0CTRL)
#else
    MISSING(PORTC_PIN0CTRL)
#endif

#ifdef PORTC_PIN1CTRL
    DEFINE(PORTC_PIN1CTRL)
#else
    MISSING(PORTC_PIN1CTRL)
#endif

#ifdef PORTC_PIN2CTRL
    DEFINE(PORTC_PIN2CTRL)
#else
    MISSING(PORTC_PIN2CTRL)
#endif

#ifdef PORTC_PIN3CTRL
    DEFINE(PORTC_PIN3CTRL)
#else
    MISSING(PORTC_PIN3CTRL)
#endif

#ifdef PORTC_PIN4CTRL
    DEFINE(PORTC_PIN4CTRL)
#else
    MISSING(PORTC_PIN4CTRL)
#endif

#ifdef PORTC_PIN5CTRL
    DEFINE(PORTC_PIN5CTRL)
#else
    MISSING(PORTC_PIN5CTRL)
#endif

#ifdef PORTC_PIN6CTRL
    DEFINE(PORTC_PIN6CTRL)
#else
    MISSING(PORTC_PIN6CTRL)
#endif

#ifdef PORTC_PIN7CTRL
    DEFINE(PORTC_PIN7CTRL)
#else
    MISSING(PORTC_PIN7CTRL)
#endif

#ifdef PORTD
    DEFINE(PORTD)
#else
    MISSING(PORTD)
#endif

#ifdef PORTD_DIR
    DEFINE(PORTD_DIR)
#else
    MISSING(PORTD_DIR)
#endif

#ifdef PORTD_DIRCLR
    DEFINE(PORTD_DIRCLR)
#else
    MISSING(PORTD_DIRCLR)
#endif

#ifdef PORTD_DIRSET
    DEFINE(PORTD_DIRSET)
#else
    MISSING(PORTD_DIRSET)
#endif

#ifdef PORTD_DIRTGL
    DEFINE(PORTD_DIRTGL)
#else
    MISSING(PORTD_DIRTGL)
#endif

#ifdef PORTD_IN
    DEFINE(PORTD_IN)
#else
    MISSING(PORTD_IN)
#endif

#ifdef PORTD_INT0MASK
    DEFINE(PORTD_INT0MASK)
#else
    MISSING(PORTD_INT0MASK)
#endif

#ifdef PORTD_INT1MASK
    DEFINE(PORTD_INT1MASK)
#else
    MISSING(PORTD_INT1MASK)
#endif

#ifdef PORTD_INTCTRL
    DEFINE(PORTD_INTCTRL)
#else
    MISSING(PORTD_INTCTRL)
#endif

#ifdef PORTD_INTFLAGS
    DEFINE(PORTD_INTFLAGS)
#else
    MISSING(PORTD_INTFLAGS)
#endif

#ifdef PORTD_OUT
    DEFINE(PORTD_OUT)
#else
    MISSING(PORTD_OUT)
#endif

#ifdef PORTD_OUTCLR
    DEFINE(PORTD_OUTCLR)
#else
    MISSING(PORTD_OUTCLR)
#endif

#ifdef PORTD_OUTSET
    DEFINE(PORTD_OUTSET)
#else
    MISSING(PORTD_OUTSET)
#endif

#ifdef PORTD_OUTTGL
    DEFINE(PORTD_OUTTGL)
#else
    MISSING(PORTD_OUTTGL)
#endif

#ifdef PORTD_PIN0CTRL
    DEFINE(PORTD_PIN0CTRL)
#else
    MISSING(PORTD_PIN0CTRL)
#endif

#ifdef PORTD_PIN1CTRL
    DEFINE(PORTD_PIN1CTRL)
#else
    MISSING(PORTD_PIN1CTRL)
#endif

#ifdef PORTD_PIN2CTRL
    DEFINE(PORTD_PIN2CTRL)
#else
    MISSING(PORTD_PIN2CTRL)
#endif

#ifdef PORTD_PIN3CTRL
    DEFINE(PORTD_PIN3CTRL)
#else
    MISSING(PORTD_PIN3CTRL)
#endif

#ifdef PORTD_PIN4CTRL
    DEFINE(PORTD_PIN4CTRL)
#else
    MISSING(PORTD_PIN4CTRL)
#endif

#ifdef PORTD_PIN5CTRL
    DEFINE(PORTD_PIN5CTRL)
#else
    MISSING(PORTD_PIN5CTRL)
#endif

#ifdef PORTD_PIN6CTRL
    DEFINE(PORTD_PIN6CTRL)
#else
    MISSING(PORTD_PIN6CTRL)
#endif

#ifdef PORTD_PIN7CTRL
    DEFINE(PORTD_PIN7CTRL)
#else
    MISSING(PORTD_PIN7CTRL)
#endif

#ifdef PORTE
    DEFINE(PORTE)
#else
    MISSING(PORTE)
#endif

#ifdef PORTE_DIR
    DEFINE(PORTE_DIR)
#else
    MISSING(PORTE_DIR)
#endif

#ifdef PORTE_DIRCLR
    DEFINE(PORTE_DIRCLR)
#else
    MISSING(PORTE_DIRCLR)
#endif

#ifdef PORTE_DIRSET
    DEFINE(PORTE_DIRSET)
#else
    MISSING(PORTE_DIRSET)
#endif

#ifdef PORTE_DIRTGL
    DEFINE(PORTE_DIRTGL)
#else
    MISSING(PORTE_DIRTGL)
#endif

#ifdef PORTE_IN
    DEFINE(PORTE_IN)
#else
    MISSING(PORTE_IN)
#endif

#ifdef PORTE_INT0MASK
    DEFINE(PORTE_INT0MASK)
#else
    MISSING(PORTE_INT0MASK)
#endif

#ifdef PORTE_INT1MASK
    DEFINE(PORTE_INT1MASK)
#else
    MISSING(PORTE_INT1MASK)
#endif

#ifdef PORTE_INTCTRL
    DEFINE(PORTE_INTCTRL)
#else
    MISSING(PORTE_INTCTRL)
#endif

#ifdef PORTE_INTFLAGS
    DEFINE(PORTE_INTFLAGS)
#else
    MISSING(PORTE_INTFLAGS)
#endif

#ifdef PORTE_OUT
    DEFINE(PORTE_OUT)
#else
    MISSING(PORTE_OUT)
#endif

#ifdef PORTE_OUTCLR
    DEFINE(PORTE_OUTCLR)
#else
    MISSING(PORTE_OUTCLR)
#endif

#ifdef PORTE_OUTSET
    DEFINE(PORTE_OUTSET)
#else
    MISSING(PORTE_OUTSET)
#endif

#ifdef PORTE_OUTTGL
    DEFINE(PORTE_OUTTGL)
#else
    MISSING(PORTE_OUTTGL)
#endif

#ifdef PORTE_PIN0CTRL
    DEFINE(PORTE_PIN0CTRL)
#else
    MISSING(PORTE_PIN0CTRL)
#endif

#ifdef PORTE_PIN1CTRL
    DEFINE(PORTE_PIN1CTRL)
#else
    MISSING(PORTE_PIN1CTRL)
#endif

#ifdef PORTE_PIN2CTRL
    DEFINE(PORTE_PIN2CTRL)
#else
    MISSING(PORTE_PIN2CTRL)
#endif

#ifdef PORTE_PIN3CTRL
    DEFINE(PORTE_PIN3CTRL)
#else
    MISSING(PORTE_PIN3CTRL)
#endif

#ifdef PORTE_PIN4CTRL
    DEFINE(PORTE_PIN4CTRL)
#else
    MISSING(PORTE_PIN4CTRL)
#endif

#ifdef PORTE_PIN5CTRL
    DEFINE(PORTE_PIN5CTRL)
#else
    MISSING(PORTE_PIN5CTRL)
#endif

#ifdef PORTE_PIN6CTRL
    DEFINE(PORTE_PIN6CTRL)
#else
    MISSING(PORTE_PIN6CTRL)
#endif

#ifdef PORTE_PIN7CTRL
    DEFINE(PORTE_PIN7CTRL)
#else
    MISSING(PORTE_PIN7CTRL)
#endif

#ifdef PORTF
    DEFINE(PORTF)
#else
    MISSING(PORTF)
#endif

#ifdef PORTF_DIR
    DEFINE(PORTF_DIR)
#else
    MISSING(PORTF_DIR)
#endif

#ifdef PORTF_DIRCLR
    DEFINE(PORTF_DIRCLR)
#else
    MISSING(PORTF_DIRCLR)
#endif

#ifdef PORTF_DIRSET
    DEFINE(PORTF_DIRSET)
#else
    MISSING(PORTF_DIRSET)
#endif

#ifdef PORTF_DIRTGL
    DEFINE(PORTF_DIRTGL)
#else
    MISSING(PORTF_DIRTGL)
#endif

#ifdef PORTF_IN
    DEFINE(PORTF_IN)
#else
    MISSING(PORTF_IN)
#endif

#ifdef PORTF_INT0MASK
    DEFINE(PORTF_INT0MASK)
#else
    MISSING(PORTF_INT0MASK)
#endif

#ifdef PORTF_INT1MASK
    DEFINE(PORTF_INT1MASK)
#else
    MISSING(PORTF_INT1MASK)
#endif

#ifdef PORTF_INTCTRL
    DEFINE(PORTF_INTCTRL)
#else
    MISSING(PORTF_INTCTRL)
#endif

#ifdef PORTF_INTFLAGS
    DEFINE(PORTF_INTFLAGS)
#else
    MISSING(PORTF_INTFLAGS)
#endif

#ifdef PORTF_OUT
    DEFINE(PORTF_OUT)
#else
    MISSING(PORTF_OUT)
#endif

#ifdef PORTF_OUTCLR
    DEFINE(PORTF_OUTCLR)
#else
    MISSING(PORTF_OUTCLR)
#endif

#ifdef PORTF_OUTSET
    DEFINE(PORTF_OUTSET)
#else
    MISSING(PORTF_OUTSET)
#endif

#ifdef PORTF_OUTTGL
    DEFINE(PORTF_OUTTGL)
#else
    MISSING(PORTF_OUTTGL)
#endif

#ifdef PORTF_PIN0CTRL
    DEFINE(PORTF_PIN0CTRL)
#else
    MISSING(PORTF_PIN0CTRL)
#endif

#ifdef PORTF_PIN1CTRL
    DEFINE(PORTF_PIN1CTRL)
#else
    MISSING(PORTF_PIN1CTRL)
#endif

#ifdef PORTF_PIN2CTRL
    DEFINE(PORTF_PIN2CTRL)
#else
    MISSING(PORTF_PIN2CTRL)
#endif

#ifdef PORTF_PIN3CTRL
    DEFINE(PORTF_PIN3CTRL)
#else
    MISSING(PORTF_PIN3CTRL)
#endif

#ifdef PORTF_PIN4CTRL
    DEFINE(PORTF_PIN4CTRL)
#else
    MISSING(PORTF_PIN4CTRL)
#endif

#ifdef PORTF_PIN5CTRL
    DEFINE(PORTF_PIN5CTRL)
#else
    MISSING(PORTF_PIN5CTRL)
#endif

#ifdef PORTF_PIN6CTRL
    DEFINE(PORTF_PIN6CTRL)
#else
    MISSING(PORTF_PIN6CTRL)
#endif

#ifdef PORTF_PIN7CTRL
    DEFINE(PORTF_PIN7CTRL)
#else
    MISSING(PORTF_PIN7CTRL)
#endif

#ifdef PORTG
    DEFINE(PORTG)
#else
    MISSING(PORTG)
#endif

#ifdef PORTH
    DEFINE(PORTH)
#else
    MISSING(PORTH)
#endif

#ifdef PORTH_DIR
    DEFINE(PORTH_DIR)
#else
    MISSING(PORTH_DIR)
#endif

#ifdef PORTH_DIRCLR
    DEFINE(PORTH_DIRCLR)
#else
    MISSING(PORTH_DIRCLR)
#endif

#ifdef PORTH_DIRSET
    DEFINE(PORTH_DIRSET)
#else
    MISSING(PORTH_DIRSET)
#endif

#ifdef PORTH_DIRTGL
    DEFINE(PORTH_DIRTGL)
#else
    MISSING(PORTH_DIRTGL)
#endif

#ifdef PORTH_IN
    DEFINE(PORTH_IN)
#else
    MISSING(PORTH_IN)
#endif

#ifdef PORTH_INT0MASK
    DEFINE(PORTH_INT0MASK)
#else
    MISSING(PORTH_INT0MASK)
#endif

#ifdef PORTH_INT1MASK
    DEFINE(PORTH_INT1MASK)
#else
    MISSING(PORTH_INT1MASK)
#endif

#ifdef PORTH_INTCTRL
    DEFINE(PORTH_INTCTRL)
#else
    MISSING(PORTH_INTCTRL)
#endif

#ifdef PORTH_INTFLAGS
    DEFINE(PORTH_INTFLAGS)
#else
    MISSING(PORTH_INTFLAGS)
#endif

#ifdef PORTH_OUT
    DEFINE(PORTH_OUT)
#else
    MISSING(PORTH_OUT)
#endif

#ifdef PORTH_OUTCLR
    DEFINE(PORTH_OUTCLR)
#else
    MISSING(PORTH_OUTCLR)
#endif

#ifdef PORTH_OUTSET
    DEFINE(PORTH_OUTSET)
#else
    MISSING(PORTH_OUTSET)
#endif

#ifdef PORTH_OUTTGL
    DEFINE(PORTH_OUTTGL)
#else
    MISSING(PORTH_OUTTGL)
#endif

#ifdef PORTH_PIN0CTRL
    DEFINE(PORTH_PIN0CTRL)
#else
    MISSING(PORTH_PIN0CTRL)
#endif

#ifdef PORTH_PIN1CTRL
    DEFINE(PORTH_PIN1CTRL)
#else
    MISSING(PORTH_PIN1CTRL)
#endif

#ifdef PORTH_PIN2CTRL
    DEFINE(PORTH_PIN2CTRL)
#else
    MISSING(PORTH_PIN2CTRL)
#endif

#ifdef PORTH_PIN3CTRL
    DEFINE(PORTH_PIN3CTRL)
#else
    MISSING(PORTH_PIN3CTRL)
#endif

#ifdef PORTH_PIN4CTRL
    DEFINE(PORTH_PIN4CTRL)
#else
    MISSING(PORTH_PIN4CTRL)
#endif

#ifdef PORTH_PIN5CTRL
    DEFINE(PORTH_PIN5CTRL)
#else
    MISSING(PORTH_PIN5CTRL)
#endif

#ifdef PORTH_PIN6CTRL
    DEFINE(PORTH_PIN6CTRL)
#else
    MISSING(PORTH_PIN6CTRL)
#endif

#ifdef PORTH_PIN7CTRL
    DEFINE(PORTH_PIN7CTRL)
#else
    MISSING(PORTH_PIN7CTRL)
#endif

#ifdef PORTJ
    DEFINE(PORTJ)
#else
    MISSING(PORTJ)
#endif

#ifdef PORTJ_DIR
    DEFINE(PORTJ_DIR)
#else
    MISSING(PORTJ_DIR)
#endif

#ifdef PORTJ_DIRCLR
    DEFINE(PORTJ_DIRCLR)
#else
    MISSING(PORTJ_DIRCLR)
#endif

#ifdef PORTJ_DIRSET
    DEFINE(PORTJ_DIRSET)
#else
    MISSING(PORTJ_DIRSET)
#endif

#ifdef PORTJ_DIRTGL
    DEFINE(PORTJ_DIRTGL)
#else
    MISSING(PORTJ_DIRTGL)
#endif

#ifdef PORTJ_IN
    DEFINE(PORTJ_IN)
#else
    MISSING(PORTJ_IN)
#endif

#ifdef PORTJ_INT0MASK
    DEFINE(PORTJ_INT0MASK)
#else
    MISSING(PORTJ_INT0MASK)
#endif

#ifdef PORTJ_INT1MASK
    DEFINE(PORTJ_INT1MASK)
#else
    MISSING(PORTJ_INT1MASK)
#endif

#ifdef PORTJ_INTCTRL
    DEFINE(PORTJ_INTCTRL)
#else
    MISSING(PORTJ_INTCTRL)
#endif

#ifdef PORTJ_INTFLAGS
    DEFINE(PORTJ_INTFLAGS)
#else
    MISSING(PORTJ_INTFLAGS)
#endif

#ifdef PORTJ_OUT
    DEFINE(PORTJ_OUT)
#else
    MISSING(PORTJ_OUT)
#endif

#ifdef PORTJ_OUTCLR
    DEFINE(PORTJ_OUTCLR)
#else
    MISSING(PORTJ_OUTCLR)
#endif

#ifdef PORTJ_OUTSET
    DEFINE(PORTJ_OUTSET)
#else
    MISSING(PORTJ_OUTSET)
#endif

#ifdef PORTJ_OUTTGL
    DEFINE(PORTJ_OUTTGL)
#else
    MISSING(PORTJ_OUTTGL)
#endif

#ifdef PORTJ_PIN0CTRL
    DEFINE(PORTJ_PIN0CTRL)
#else
    MISSING(PORTJ_PIN0CTRL)
#endif

#ifdef PORTJ_PIN1CTRL
    DEFINE(PORTJ_PIN1CTRL)
#else
    MISSING(PORTJ_PIN1CTRL)
#endif

#ifdef PORTJ_PIN2CTRL
    DEFINE(PORTJ_PIN2CTRL)
#else
    MISSING(PORTJ_PIN2CTRL)
#endif

#ifdef PORTJ_PIN3CTRL
    DEFINE(PORTJ_PIN3CTRL)
#else
    MISSING(PORTJ_PIN3CTRL)
#endif

#ifdef PORTJ_PIN4CTRL
    DEFINE(PORTJ_PIN4CTRL)
#else
    MISSING(PORTJ_PIN4CTRL)
#endif

#ifdef PORTJ_PIN5CTRL
    DEFINE(PORTJ_PIN5CTRL)
#else
    MISSING(PORTJ_PIN5CTRL)
#endif

#ifdef PORTJ_PIN6CTRL
    DEFINE(PORTJ_PIN6CTRL)
#else
    MISSING(PORTJ_PIN6CTRL)
#endif

#ifdef PORTJ_PIN7CTRL
    DEFINE(PORTJ_PIN7CTRL)
#else
    MISSING(PORTJ_PIN7CTRL)
#endif

#ifdef PORTK
    DEFINE(PORTK)
#else
    MISSING(PORTK)
#endif

#ifdef PORTK_DIR
    DEFINE(PORTK_DIR)
#else
    MISSING(PORTK_DIR)
#endif

#ifdef PORTK_DIRCLR
    DEFINE(PORTK_DIRCLR)
#else
    MISSING(PORTK_DIRCLR)
#endif

#ifdef PORTK_DIRSET
    DEFINE(PORTK_DIRSET)
#else
    MISSING(PORTK_DIRSET)
#endif

#ifdef PORTK_DIRTGL
    DEFINE(PORTK_DIRTGL)
#else
    MISSING(PORTK_DIRTGL)
#endif

#ifdef PORTK_IN
    DEFINE(PORTK_IN)
#else
    MISSING(PORTK_IN)
#endif

#ifdef PORTK_INT0MASK
    DEFINE(PORTK_INT0MASK)
#else
    MISSING(PORTK_INT0MASK)
#endif

#ifdef PORTK_INT1MASK
    DEFINE(PORTK_INT1MASK)
#else
    MISSING(PORTK_INT1MASK)
#endif

#ifdef PORTK_INTCTRL
    DEFINE(PORTK_INTCTRL)
#else
    MISSING(PORTK_INTCTRL)
#endif

#ifdef PORTK_INTFLAGS
    DEFINE(PORTK_INTFLAGS)
#else
    MISSING(PORTK_INTFLAGS)
#endif

#ifdef PORTK_OUT
    DEFINE(PORTK_OUT)
#else
    MISSING(PORTK_OUT)
#endif

#ifdef PORTK_OUTCLR
    DEFINE(PORTK_OUTCLR)
#else
    MISSING(PORTK_OUTCLR)
#endif

#ifdef PORTK_OUTSET
    DEFINE(PORTK_OUTSET)
#else
    MISSING(PORTK_OUTSET)
#endif

#ifdef PORTK_OUTTGL
    DEFINE(PORTK_OUTTGL)
#else
    MISSING(PORTK_OUTTGL)
#endif

#ifdef PORTK_PIN0CTRL
    DEFINE(PORTK_PIN0CTRL)
#else
    MISSING(PORTK_PIN0CTRL)
#endif

#ifdef PORTK_PIN1CTRL
    DEFINE(PORTK_PIN1CTRL)
#else
    MISSING(PORTK_PIN1CTRL)
#endif

#ifdef PORTK_PIN2CTRL
    DEFINE(PORTK_PIN2CTRL)
#else
    MISSING(PORTK_PIN2CTRL)
#endif

#ifdef PORTK_PIN3CTRL
    DEFINE(PORTK_PIN3CTRL)
#else
    MISSING(PORTK_PIN3CTRL)
#endif

#ifdef PORTK_PIN4CTRL
    DEFINE(PORTK_PIN4CTRL)
#else
    MISSING(PORTK_PIN4CTRL)
#endif

#ifdef PORTK_PIN5CTRL
    DEFINE(PORTK_PIN5CTRL)
#else
    MISSING(PORTK_PIN5CTRL)
#endif

#ifdef PORTK_PIN6CTRL
    DEFINE(PORTK_PIN6CTRL)
#else
    MISSING(PORTK_PIN6CTRL)
#endif

#ifdef PORTK_PIN7CTRL
    DEFINE(PORTK_PIN7CTRL)
#else
    MISSING(PORTK_PIN7CTRL)
#endif

#ifdef PORTL
    DEFINE(PORTL)
#else
    MISSING(PORTL)
#endif

#ifdef PORTQ_DIR
    DEFINE(PORTQ_DIR)
#else
    MISSING(PORTQ_DIR)
#endif

#ifdef PORTQ_DIRCLR
    DEFINE(PORTQ_DIRCLR)
#else
    MISSING(PORTQ_DIRCLR)
#endif

#ifdef PORTQ_DIRSET
    DEFINE(PORTQ_DIRSET)
#else
    MISSING(PORTQ_DIRSET)
#endif

#ifdef PORTQ_DIRTGL
    DEFINE(PORTQ_DIRTGL)
#else
    MISSING(PORTQ_DIRTGL)
#endif

#ifdef PORTQ_IN
    DEFINE(PORTQ_IN)
#else
    MISSING(PORTQ_IN)
#endif

#ifdef PORTQ_INT0MASK
    DEFINE(PORTQ_INT0MASK)
#else
    MISSING(PORTQ_INT0MASK)
#endif

#ifdef PORTQ_INT1MASK
    DEFINE(PORTQ_INT1MASK)
#else
    MISSING(PORTQ_INT1MASK)
#endif

#ifdef PORTQ_INTCTRL
    DEFINE(PORTQ_INTCTRL)
#else
    MISSING(PORTQ_INTCTRL)
#endif

#ifdef PORTQ_INTFLAGS
    DEFINE(PORTQ_INTFLAGS)
#else
    MISSING(PORTQ_INTFLAGS)
#endif

#ifdef PORTQ_OUT
    DEFINE(PORTQ_OUT)
#else
    MISSING(PORTQ_OUT)
#endif

#ifdef PORTQ_OUTCLR
    DEFINE(PORTQ_OUTCLR)
#else
    MISSING(PORTQ_OUTCLR)
#endif

#ifdef PORTQ_OUTSET
    DEFINE(PORTQ_OUTSET)
#else
    MISSING(PORTQ_OUTSET)
#endif

#ifdef PORTQ_OUTTGL
    DEFINE(PORTQ_OUTTGL)
#else
    MISSING(PORTQ_OUTTGL)
#endif

#ifdef PORTQ_PIN0CTRL
    DEFINE(PORTQ_PIN0CTRL)
#else
    MISSING(PORTQ_PIN0CTRL)
#endif

#ifdef PORTQ_PIN1CTRL
    DEFINE(PORTQ_PIN1CTRL)
#else
    MISSING(PORTQ_PIN1CTRL)
#endif

#ifdef PORTQ_PIN2CTRL
    DEFINE(PORTQ_PIN2CTRL)
#else
    MISSING(PORTQ_PIN2CTRL)
#endif

#ifdef PORTQ_PIN3CTRL
    DEFINE(PORTQ_PIN3CTRL)
#else
    MISSING(PORTQ_PIN3CTRL)
#endif

#ifdef PORTQ_PIN4CTRL
    DEFINE(PORTQ_PIN4CTRL)
#else
    MISSING(PORTQ_PIN4CTRL)
#endif

#ifdef PORTQ_PIN5CTRL
    DEFINE(PORTQ_PIN5CTRL)
#else
    MISSING(PORTQ_PIN5CTRL)
#endif

#ifdef PORTQ_PIN6CTRL
    DEFINE(PORTQ_PIN6CTRL)
#else
    MISSING(PORTQ_PIN6CTRL)
#endif

#ifdef PORTQ_PIN7CTRL
    DEFINE(PORTQ_PIN7CTRL)
#else
    MISSING(PORTQ_PIN7CTRL)
#endif

#ifdef PORTR_DIR
    DEFINE(PORTR_DIR)
#else
    MISSING(PORTR_DIR)
#endif

#ifdef PORTR_DIRCLR
    DEFINE(PORTR_DIRCLR)
#else
    MISSING(PORTR_DIRCLR)
#endif

#ifdef PORTR_DIRSET
    DEFINE(PORTR_DIRSET)
#else
    MISSING(PORTR_DIRSET)
#endif

#ifdef PORTR_DIRTGL
    DEFINE(PORTR_DIRTGL)
#else
    MISSING(PORTR_DIRTGL)
#endif

#ifdef PORTR_IN
    DEFINE(PORTR_IN)
#else
    MISSING(PORTR_IN)
#endif

#ifdef PORTR_INT0MASK
    DEFINE(PORTR_INT0MASK)
#else
    MISSING(PORTR_INT0MASK)
#endif

#ifdef PORTR_INT1MASK
    DEFINE(PORTR_INT1MASK)
#else
    MISSING(PORTR_INT1MASK)
#endif

#ifdef PORTR_INTCTRL
    DEFINE(PORTR_INTCTRL)
#else
    MISSING(PORTR_INTCTRL)
#endif

#ifdef PORTR_INTFLAGS
    DEFINE(PORTR_INTFLAGS)
#else
    MISSING(PORTR_INTFLAGS)
#endif

#ifdef PORTR_OUT
    DEFINE(PORTR_OUT)
#else
    MISSING(PORTR_OUT)
#endif

#ifdef PORTR_OUTCLR
    DEFINE(PORTR_OUTCLR)
#else
    MISSING(PORTR_OUTCLR)
#endif

#ifdef PORTR_OUTSET
    DEFINE(PORTR_OUTSET)
#else
    MISSING(PORTR_OUTSET)
#endif

#ifdef PORTR_OUTTGL
    DEFINE(PORTR_OUTTGL)
#else
    MISSING(PORTR_OUTTGL)
#endif

#ifdef PORTR_PIN0CTRL
    DEFINE(PORTR_PIN0CTRL)
#else
    MISSING(PORTR_PIN0CTRL)
#endif

#ifdef PORTR_PIN1CTRL
    DEFINE(PORTR_PIN1CTRL)
#else
    MISSING(PORTR_PIN1CTRL)
#endif

#ifdef PORTR_PIN2CTRL
    DEFINE(PORTR_PIN2CTRL)
#else
    MISSING(PORTR_PIN2CTRL)
#endif

#ifdef PORTR_PIN3CTRL
    DEFINE(PORTR_PIN3CTRL)
#else
    MISSING(PORTR_PIN3CTRL)
#endif

#ifdef PORTR_PIN4CTRL
    DEFINE(PORTR_PIN4CTRL)
#else
    MISSING(PORTR_PIN4CTRL)
#endif

#ifdef PORTR_PIN5CTRL
    DEFINE(PORTR_PIN5CTRL)
#else
    MISSING(PORTR_PIN5CTRL)
#endif

#ifdef PORTR_PIN6CTRL
    DEFINE(PORTR_PIN6CTRL)
#else
    MISSING(PORTR_PIN6CTRL)
#endif

#ifdef PORTR_PIN7CTRL
    DEFINE(PORTR_PIN7CTRL)
#else
    MISSING(PORTR_PIN7CTRL)
#endif

#ifdef PRELD
    DEFINE(PRELD)
#else
    MISSING(PRELD)
#endif

#ifdef PRR
    DEFINE(PRR)
#else
    MISSING(PRR)
#endif

#ifdef PRR0
    DEFINE(PRR0)
#else
    MISSING(PRR0)
#endif

#ifdef PRR1
    DEFINE(PRR1)
#else
    MISSING(PRR1)
#endif

#ifdef PRR2
    DEFINE(PRR2)
#else
    MISSING(PRR2)
#endif

#ifdef PR_PRGEN
    DEFINE(PR_PRGEN)
#else
    MISSING(PR_PRGEN)
#endif

#ifdef PR_PRPA
    DEFINE(PR_PRPA)
#else
    MISSING(PR_PRPA)
#endif

#ifdef PR_PRPB
    DEFINE(PR_PRPB)
#else
    MISSING(PR_PRPB)
#endif

#ifdef PR_PRPC
    DEFINE(PR_PRPC)
#else
    MISSING(PR_PRPC)
#endif

#ifdef PR_PRPD
    DEFINE(PR_PRPD)
#else
    MISSING(PR_PRPD)
#endif

#ifdef PR_PRPE
    DEFINE(PR_PRPE)
#else
    MISSING(PR_PRPE)
#endif

#ifdef PR_PRPF
    DEFINE(PR_PRPF)
#else
    MISSING(PR_PRPF)
#endif

#ifdef PS2CON
    DEFINE(PS2CON)
#else
    MISSING(PS2CON)
#endif

#ifdef PSOC0
    DEFINE(PSOC0)
#else
    MISSING(PSOC0)
#endif

#ifdef PSOC1
    DEFINE(PSOC1)
#else
    MISSING(PSOC1)
#endif

#ifdef PSOC2
    DEFINE(PSOC2)
#else
    MISSING(PSOC2)
#endif

#ifdef PSYNC
    DEFINE(PSYNC)
#else
    MISSING(PSYNC)
#endif

#ifdef PUEA
    DEFINE(PUEA)
#else
    MISSING(PUEA)
#endif

#ifdef PUEB
    DEFINE(PUEB)
#else
    MISSING(PUEB)
#endif

#ifdef PUEC
    DEFINE(PUEC)
#else
    MISSING(PUEC)
#endif

#ifdef PWMCTL
    DEFINE(PWMCTL)
#else
    MISSING(PWMCTL)
#endif

#ifdef PWMMSK
    DEFINE(PWMMSK)
#else
    MISSING(PWMMSK)
#endif

#ifdef PWMPER
    DEFINE(PWMPER)
#else
    MISSING(PWMPER)
#endif

#ifdef PWMSFRQ
    DEFINE(PWMSFRQ)
#else
    MISSING(PWMSFRQ)
#endif

#ifdef PWR_ATTEN
    DEFINE(PWR_ATTEN)
#else
    MISSING(PWR_ATTEN)
#endif

#ifdef QTCSR
    DEFINE(QTCSR)
#else
    MISSING(QTCSR)
#endif

#ifdef RAMAR
    DEFINE(RAMAR)
#else
    MISSING(RAMAR)
#endif

#ifdef RAMDR
    DEFINE(RAMDR)
#else
    MISSING(RAMDR)
#endif

#ifdef RAMPD
    DEFINE(RAMPD)
#else
    MISSING(RAMPD)
#endif

#ifdef RAMPX
    DEFINE(RAMPX)
#else
    MISSING(RAMPX)
#endif

#ifdef RAMPY
    DEFINE(RAMPY)
#else
    MISSING(RAMPY)
#endif

#ifdef RAMPZ
    DEFINE(RAMPZ)
#else
    MISSING(RAMPZ)
#endif

#ifdef RCCTRL
    DEFINE(RCCTRL)
#else
    MISSING(RCCTRL)
#endif

#ifdef RDWDR
    DEFINE(RDWDR)
#else
    MISSING(RDWDR)
#endif

#ifdef REGCR
    DEFINE(REGCR)
#else
    MISSING(REGCR)
#endif

#ifdef RNGCR
    DEFINE(RNGCR)
#else
    MISSING(RNGCR)
#endif

#ifdef ROCR
    DEFINE(ROCR)
#else
    MISSING(ROCR)
#endif

#ifdef RSTFLR
    DEFINE(RSTFLR)
#else
    MISSING(RSTFLR)
#endif

#ifdef RST_CTRL
    DEFINE(RST_CTRL)
#else
    MISSING(RST_CTRL)
#endif

#ifdef RST_STATUS
    DEFINE(RST_STATUS)
#else
    MISSING(RST_STATUS)
#endif

#ifdef RTC32_CTRL
    DEFINE(RTC32_CTRL)
#else
    MISSING(RTC32_CTRL)
#endif

#ifdef RTC32_INTCTRL
    DEFINE(RTC32_INTCTRL)
#else
    MISSING(RTC32_INTCTRL)
#endif

#ifdef RTC32_INTFLAGS
    DEFINE(RTC32_INTFLAGS)
#else
    MISSING(RTC32_INTFLAGS)
#endif

#ifdef RTC32_SYNCCTRL
    DEFINE(RTC32_SYNCCTRL)
#else
    MISSING(RTC32_SYNCCTRL)
#endif

#ifdef RTC_CNT
    DEFINE(RTC_CNT)
#else
    MISSING(RTC_CNT)
#endif

#ifdef RTC_COMP
    DEFINE(RTC_COMP)
#else
    MISSING(RTC_COMP)
#endif

#ifdef RTC_CTRL
    DEFINE(RTC_CTRL)
#else
    MISSING(RTC_CTRL)
#endif

#ifdef RTC_INTCTRL
    DEFINE(RTC_INTCTRL)
#else
    MISSING(RTC_INTCTRL)
#endif

#ifdef RTC_INTFLAGS
    DEFINE(RTC_INTFLAGS)
#else
    MISSING(RTC_INTFLAGS)
#endif

#ifdef RTC_PER
    DEFINE(RTC_PER)
#else
    MISSING(RTC_PER)
#endif

#ifdef RTC_STATUS
    DEFINE(RTC_STATUS)
#else
    MISSING(RTC_STATUS)
#endif

#ifdef RTC_TEMP
    DEFINE(RTC_TEMP)
#else
    MISSING(RTC_TEMP)
#endif

#ifdef RXB
    DEFINE(RXB)
#else
    MISSING(RXB)
#endif

#ifdef RX_CTRL
    DEFINE(RX_CTRL)
#else
    MISSING(RX_CTRL)
#endif

#ifdef RX_SYN
    DEFINE(RX_SYN)
#else
    MISSING(RX_SYN)
#endif

#ifdef SCBTSRHH
    DEFINE(SCBTSRHH)
#else
    MISSING(SCBTSRHH)
#endif

#ifdef SCBTSRHL
    DEFINE(SCBTSRHL)
#else
    MISSING(SCBTSRHL)
#endif

#ifdef SCBTSRLH
    DEFINE(SCBTSRLH)
#else
    MISSING(SCBTSRLH)
#endif

#ifdef SCBTSRLL
    DEFINE(SCBTSRLL)
#else
    MISSING(SCBTSRLL)
#endif

#ifdef SCCNTHH
    DEFINE(SCCNTHH)
#else
    MISSING(SCCNTHH)
#endif

#ifdef SCCNTHL
    DEFINE(SCCNTHL)
#else
    MISSING(SCCNTHL)
#endif

#ifdef SCCNTLH
    DEFINE(SCCNTLH)
#else
    MISSING(SCCNTLH)
#endif

#ifdef SCCNTLL
    DEFINE(SCCNTLL)
#else
    MISSING(SCCNTLL)
#endif

#ifdef SCCON
    DEFINE(SCCON)
#else
    MISSING(SCCON)
#endif

#ifdef SCCR
    DEFINE(SCCR)
#else
    MISSING(SCCR)
#endif

#ifdef SCCR0
    DEFINE(SCCR0)
#else
    MISSING(SCCR0)
#endif

#ifdef SCCR1
    DEFINE(SCCR1)
#else
    MISSING(SCCR1)
#endif

#ifdef SCETU
    DEFINE(SCETU)
#else
    MISSING(SCETU)
#endif

#ifdef SCETUH
    DEFINE(SCETUH)
#else
    MISSING(SCETUH)
#endif

#ifdef SCETUL
    DEFINE(SCETUL)
#else
    MISSING(SCETUL)
#endif

#ifdef SCGT
    DEFINE(SCGT)
#else
    MISSING(SCGT)
#endif

#ifdef SCGTH
    DEFINE(SCGTH)
#else
    MISSING(SCGTH)
#endif

#ifdef SCGTL
    DEFINE(SCGTL)
#else
    MISSING(SCGTL)
#endif

#ifdef SCIBUF
    DEFINE(SCIBUF)
#else
    MISSING(SCIBUF)
#endif

#ifdef SCICLK
    DEFINE(SCICLK)
#else
    MISSING(SCICLK)
#endif

#ifdef SCICR
    DEFINE(SCICR)
#else
    MISSING(SCICR)
#endif

#ifdef SCIER
    DEFINE(SCIER)
#else
    MISSING(SCIER)
#endif

#ifdef SCIIR
    DEFINE(SCIIR)
#else
    MISSING(SCIIR)
#endif

#ifdef SCIO
    DEFINE(SCIO)
#else
    MISSING(SCIO)
#endif

#ifdef SCIRQM
    DEFINE(SCIRQM)
#else
    MISSING(SCIRQM)
#endif

#ifdef SCIRQS
    DEFINE(SCIRQS)
#else
    MISSING(SCIRQS)
#endif

#ifdef SCISR
    DEFINE(SCISR)
#else
    MISSING(SCISR)
#endif

#ifdef SCOCR1HH
    DEFINE(SCOCR1HH)
#else
    MISSING(SCOCR1HH)
#endif

#ifdef SCOCR1HL
    DEFINE(SCOCR1HL)
#else
    MISSING(SCOCR1HL)
#endif

#ifdef SCOCR1LH
    DEFINE(SCOCR1LH)
#else
    MISSING(SCOCR1LH)
#endif

#ifdef SCOCR1LL
    DEFINE(SCOCR1LL)
#else
    MISSING(SCOCR1LL)
#endif

#ifdef SCOCR2HH
    DEFINE(SCOCR2HH)
#else
    MISSING(SCOCR2HH)
#endif

#ifdef SCOCR2HL
    DEFINE(SCOCR2HL)
#else
    MISSING(SCOCR2HL)
#endif

#ifdef SCOCR2LH
    DEFINE(SCOCR2LH)
#else
    MISSING(SCOCR2LH)
#endif

#ifdef SCOCR2LL
    DEFINE(SCOCR2LL)
#else
    MISSING(SCOCR2LL)
#endif

#ifdef SCOCR3HH
    DEFINE(SCOCR3HH)
#else
    MISSING(SCOCR3HH)
#endif

#ifdef SCOCR3HL
    DEFINE(SCOCR3HL)
#else
    MISSING(SCOCR3HL)
#endif

#ifdef SCOCR3LH
    DEFINE(SCOCR3LH)
#else
    MISSING(SCOCR3LH)
#endif

#ifdef SCOCR3LL
    DEFINE(SCOCR3LL)
#else
    MISSING(SCOCR3LL)
#endif

#ifdef SCR
    DEFINE(SCR)
#else
    MISSING(SCR)
#endif

#ifdef SCSR
    DEFINE(SCSR)
#else
    MISSING(SCSR)
#endif

#ifdef SCSW
    DEFINE(SCSW)
#else
    MISSING(SCSW)
#endif

#ifdef SCTSRHH
    DEFINE(SCTSRHH)
#else
    MISSING(SCTSRHH)
#endif

#ifdef SCTSRHL
    DEFINE(SCTSRHL)
#else
    MISSING(SCTSRHL)
#endif

#ifdef SCTSRLH
    DEFINE(SCTSRLH)
#else
    MISSING(SCTSRLH)
#endif

#ifdef SCTSRLL
    DEFINE(SCTSRLL)
#else
    MISSING(SCTSRLL)
#endif

#ifdef SCWT0
    DEFINE(SCWT0)
#else
    MISSING(SCWT0)
#endif

#ifdef SCWT1
    DEFINE(SCWT1)
#else
    MISSING(SCWT1)
#endif

#ifdef SCWT2
    DEFINE(SCWT2)
#else
    MISSING(SCWT2)
#endif

#ifdef SCWT3
    DEFINE(SCWT3)
#else
    MISSING(SCWT3)
#endif

#ifdef SFD_VALUE
    DEFINE(SFD_VALUE)
#else
    MISSING(SFD_VALUE)
#endif

#ifdef SFIOR
    DEFINE(SFIOR)
#else
    MISSING(SFIOR)
#endif

#ifdef SFTCR
    DEFINE(SFTCR)
#else
    MISSING(SFTCR)
#endif

#ifdef SHORT_ADDR_0
    DEFINE(SHORT_ADDR_0)
#else
    MISSING(SHORT_ADDR_0)
#endif

#ifdef SHORT_ADDR_1
    DEFINE(SHORT_ADDR_1)
#else
    MISSING(SHORT_ADDR_1)
#endif

#ifdef SIMSK
    DEFINE(SIMSK)
#else
    MISSING(SIMSK)
#endif

#ifdef SINDAC
    DEFINE(SINDAC)
#else
    MISSING(SINDAC)
#endif

#ifdef SINDACH
    DEFINE(SINDACH)
#else
    MISSING(SINDACH)
#endif

#ifdef SINDACL
    DEFINE(SINDACL)
#else
    MISSING(SINDACL)
#endif

#ifdef SLEEP_CTRL
    DEFINE(SLEEP_CTRL)
#else
    MISSING(SLEEP_CTRL)
#endif

#ifdef SMCR
    DEFINE(SMCR)
#else
    MISSING(SMCR)
#endif

#ifdef SMONCR
    DEFINE(SMONCR)
#else
    MISSING(SMONCR)
#endif

#ifdef SOSCCALA
    DEFINE(SOSCCALA)
#else
    MISSING(SOSCCALA)
#endif

#ifdef SOSCCALB
    DEFINE(SOSCCALB)
#else
    MISSING(SOSCCALB)
#endif

#ifdef SP
    DEFINE(SP)
#else
    MISSING(SP)
#endif

#ifdef SPCR
    DEFINE(SPCR)
#else
    MISSING(SPCR)
#endif

#ifdef SPCR0
    DEFINE(SPCR0)
#else
    MISSING(SPCR0)
#endif

#ifdef SPDR
    DEFINE(SPDR)
#else
    MISSING(SPDR)
#endif

#ifdef SPH
    DEFINE(SPH)
#else
    MISSING(SPH)
#endif

#ifdef SPIC_CTRL
    DEFINE(SPIC_CTRL)
#else
    MISSING(SPIC_CTRL)
#endif

#ifdef SPIC_DATA
    DEFINE(SPIC_DATA)
#else
    MISSING(SPIC_DATA)
#endif

#ifdef SPIC_INTCTRL
    DEFINE(SPIC_INTCTRL)
#else
    MISSING(SPIC_INTCTRL)
#endif

#ifdef SPIC_STATUS
    DEFINE(SPIC_STATUS)
#else
    MISSING(SPIC_STATUS)
#endif

#ifdef SPID_CTRL
    DEFINE(SPID_CTRL)
#else
    MISSING(SPID_CTRL)
#endif

#ifdef SPID_DATA
    DEFINE(SPID_DATA)
#else
    MISSING(SPID_DATA)
#endif

#ifdef SPID_INTCTRL
    DEFINE(SPID_INTCTRL)
#else
    MISSING(SPID_INTCTRL)
#endif

#ifdef SPID_STATUS
    DEFINE(SPID_STATUS)
#else
    MISSING(SPID_STATUS)
#endif

#ifdef SPIE_CTRL
    DEFINE(SPIE_CTRL)
#else
    MISSING(SPIE_CTRL)
#endif

#ifdef SPIE_DATA
    DEFINE(SPIE_DATA)
#else
    MISSING(SPIE_DATA)
#endif

#ifdef SPIE_INTCTRL
    DEFINE(SPIE_INTCTRL)
#else
    MISSING(SPIE_INTCTRL)
#endif

#ifdef SPIE_STATUS
    DEFINE(SPIE_STATUS)
#else
    MISSING(SPIE_STATUS)
#endif

#ifdef SPIF_CTRL
    DEFINE(SPIF_CTRL)
#else
    MISSING(SPIF_CTRL)
#endif

#ifdef SPIF_DATA
    DEFINE(SPIF_DATA)
#else
    MISSING(SPIF_DATA)
#endif

#ifdef SPIF_INTCTRL
    DEFINE(SPIF_INTCTRL)
#else
    MISSING(SPIF_INTCTRL)
#endif

#ifdef SPIF_STATUS
    DEFINE(SPIF_STATUS)
#else
    MISSING(SPIF_STATUS)
#endif

#ifdef SPL
    DEFINE(SPL)
#else
    MISSING(SPL)
#endif

#ifdef SPMCR
    DEFINE(SPMCR)
#else
    MISSING(SPMCR)
#endif

#ifdef SPMCSR
    DEFINE(SPMCSR)
#else
    MISSING(SPMCSR)
#endif

#ifdef SPSR
    DEFINE(SPSR)
#else
    MISSING(SPSR)
#endif

#ifdef SPSR0
    DEFINE(SPSR0)
#else
    MISSING(SPSR0)
#endif

#ifdef SPWMCTL
    DEFINE(SPWMCTL)
#else
    MISSING(SPWMCTL)
#endif

#ifdef SRCCAL
    DEFINE(SRCCAL)
#else
    MISSING(SRCCAL)
#endif

#ifdef SREG
    DEFINE(SREG)
#else
    MISSING(SREG)
#endif

#ifdef SSFR
    DEFINE(SSFR)
#else
    MISSING(SSFR)
#endif

#ifdef STAT
    DEFINE(STAT)
#else
    MISSING(STAT)
#endif

#ifdef SVCR
    DEFINE(SVCR)
#else
    MISSING(SVCR)
#endif

#ifdef T0CR
    DEFINE(T0CR)
#else
    MISSING(T0CR)
#endif

#ifdef T10IFR
    DEFINE(T10IFR)
#else
    MISSING(T10IFR)
#endif

#ifdef T1CR
    DEFINE(T1CR)
#else
    MISSING(T1CR)
#endif

#ifdef T2COR
    DEFINE(T2COR)
#else
    MISSING(T2COR)
#endif

#ifdef T2CORH
    DEFINE(T2CORH)
#else
    MISSING(T2CORH)
#endif

#ifdef T2CORL
    DEFINE(T2CORL)
#else
    MISSING(T2CORL)
#endif

#ifdef T2CRA
    DEFINE(T2CRA)
#else
    MISSING(T2CRA)
#endif

#ifdef T2CRB
    DEFINE(T2CRB)
#else
    MISSING(T2CRB)
#endif

#ifdef T2ICR
    DEFINE(T2ICR)
#else
    MISSING(T2ICR)
#endif

#ifdef T2ICRH
    DEFINE(T2ICRH)
#else
    MISSING(T2ICRH)
#endif

#ifdef T2ICRL
    DEFINE(T2ICRL)
#else
    MISSING(T2ICRL)
#endif

#ifdef T2IFR
    DEFINE(T2IFR)
#else
    MISSING(T2IFR)
#endif

#ifdef T2IMR
    DEFINE(T2IMR)
#else
    MISSING(T2IMR)
#endif

#ifdef T2MDR
    DEFINE(T2MDR)
#else
    MISSING(T2MDR)
#endif

#ifdef T2MRA
    DEFINE(T2MRA)
#else
    MISSING(T2MRA)
#endif

#ifdef T2MRB
    DEFINE(T2MRB)
#else
    MISSING(T2MRB)
#endif

#ifdef T3CORA
    DEFINE(T3CORA)
#else
    MISSING(T3CORA)
#endif

#ifdef T3CORAH
    DEFINE(T3CORAH)
#else
    MISSING(T3CORAH)
#endif

#ifdef T3CORAL
    DEFINE(T3CORAL)
#else
    MISSING(T3CORAL)
#endif

#ifdef T3CORB
    DEFINE(T3CORB)
#else
    MISSING(T3CORB)
#endif

#ifdef T3CORBH
    DEFINE(T3CORBH)
#else
    MISSING(T3CORBH)
#endif

#ifdef T3CORBL
    DEFINE(T3CORBL)
#else
    MISSING(T3CORBL)
#endif

#ifdef T3CRA
    DEFINE(T3CRA)
#else
    MISSING(T3CRA)
#endif

#ifdef T3CRB
    DEFINE(T3CRB)
#else
    MISSING(T3CRB)
#endif

#ifdef T3ICR
    DEFINE(T3ICR)
#else
    MISSING(T3ICR)
#endif

#ifdef T3ICRH
    DEFINE(T3ICRH)
#else
    MISSING(T3ICRH)
#endif

#ifdef T3ICRL
    DEFINE(T3ICRL)
#else
    MISSING(T3ICRL)
#endif

#ifdef T3IFR
    DEFINE(T3IFR)
#else
    MISSING(T3IFR)
#endif

#ifdef T3IMR
    DEFINE(T3IMR)
#else
    MISSING(T3IMR)
#endif

#ifdef T3MRA
    DEFINE(T3MRA)
#else
    MISSING(T3MRA)
#endif

#ifdef T3MRB
    DEFINE(T3MRB)
#else
    MISSING(T3MRB)
#endif

#ifdef TC1H
    DEFINE(TC1H)
#else
    MISSING(TC1H)
#endif

#ifdef TC4H
    DEFINE(TC4H)
#else
    MISSING(TC4H)
#endif

#ifdef TCC0_CCA
    DEFINE(TCC0_CCA)
#else
    MISSING(TCC0_CCA)
#endif

#ifdef TCC0_CCABUF
    DEFINE(TCC0_CCABUF)
#else
    MISSING(TCC0_CCABUF)
#endif

#ifdef TCC0_CCB
    DEFINE(TCC0_CCB)
#else
    MISSING(TCC0_CCB)
#endif

#ifdef TCC0_CCBBUF
    DEFINE(TCC0_CCBBUF)
#else
    MISSING(TCC0_CCBBUF)
#endif

#ifdef TCC0_CCC
    DEFINE(TCC0_CCC)
#else
    MISSING(TCC0_CCC)
#endif

#ifdef TCC0_CCCBUF
    DEFINE(TCC0_CCCBUF)
#else
    MISSING(TCC0_CCCBUF)
#endif

#ifdef TCC0_CCD
    DEFINE(TCC0_CCD)
#else
    MISSING(TCC0_CCD)
#endif

#ifdef TCC0_CCDBUF
    DEFINE(TCC0_CCDBUF)
#else
    MISSING(TCC0_CCDBUF)
#endif

#ifdef TCC0_CNT
    DEFINE(TCC0_CNT)
#else
    MISSING(TCC0_CNT)
#endif

#ifdef TCC0_CTRLA
    DEFINE(TCC0_CTRLA)
#else
    MISSING(TCC0_CTRLA)
#endif

#ifdef TCC0_CTRLB
    DEFINE(TCC0_CTRLB)
#else
    MISSING(TCC0_CTRLB)
#endif

#ifdef TCC0_CTRLC
    DEFINE(TCC0_CTRLC)
#else
    MISSING(TCC0_CTRLC)
#endif

#ifdef TCC0_CTRLD
    DEFINE(TCC0_CTRLD)
#else
    MISSING(TCC0_CTRLD)
#endif

#ifdef TCC0_CTRLE
    DEFINE(TCC0_CTRLE)
#else
    MISSING(TCC0_CTRLE)
#endif

#ifdef TCC0_CTRLFCLR
    DEFINE(TCC0_CTRLFCLR)
#else
    MISSING(TCC0_CTRLFCLR)
#endif

#ifdef TCC0_CTRLFSET
    DEFINE(TCC0_CTRLFSET)
#else
    MISSING(TCC0_CTRLFSET)
#endif

#ifdef TCC0_CTRLGCLR
    DEFINE(TCC0_CTRLGCLR)
#else
    MISSING(TCC0_CTRLGCLR)
#endif

#ifdef TCC0_CTRLGSET
    DEFINE(TCC0_CTRLGSET)
#else
    MISSING(TCC0_CTRLGSET)
#endif

#ifdef TCC0_INTCTRLA
    DEFINE(TCC0_INTCTRLA)
#else
    MISSING(TCC0_INTCTRLA)
#endif

#ifdef TCC0_INTCTRLB
    DEFINE(TCC0_INTCTRLB)
#else
    MISSING(TCC0_INTCTRLB)
#endif

#ifdef TCC0_INTFLAGS
    DEFINE(TCC0_INTFLAGS)
#else
    MISSING(TCC0_INTFLAGS)
#endif

#ifdef TCC0_PER
    DEFINE(TCC0_PER)
#else
    MISSING(TCC0_PER)
#endif

#ifdef TCC0_PERBUF
    DEFINE(TCC0_PERBUF)
#else
    MISSING(TCC0_PERBUF)
#endif

#ifdef TCC0_TEMP
    DEFINE(TCC0_TEMP)
#else
    MISSING(TCC0_TEMP)
#endif

#ifdef TCC1_CCA
    DEFINE(TCC1_CCA)
#else
    MISSING(TCC1_CCA)
#endif

#ifdef TCC1_CCABUF
    DEFINE(TCC1_CCABUF)
#else
    MISSING(TCC1_CCABUF)
#endif

#ifdef TCC1_CCB
    DEFINE(TCC1_CCB)
#else
    MISSING(TCC1_CCB)
#endif

#ifdef TCC1_CCBBUF
    DEFINE(TCC1_CCBBUF)
#else
    MISSING(TCC1_CCBBUF)
#endif

#ifdef TCC1_CNT
    DEFINE(TCC1_CNT)
#else
    MISSING(TCC1_CNT)
#endif

#ifdef TCC1_CTRLA
    DEFINE(TCC1_CTRLA)
#else
    MISSING(TCC1_CTRLA)
#endif

#ifdef TCC1_CTRLB
    DEFINE(TCC1_CTRLB)
#else
    MISSING(TCC1_CTRLB)
#endif

#ifdef TCC1_CTRLC
    DEFINE(TCC1_CTRLC)
#else
    MISSING(TCC1_CTRLC)
#endif

#ifdef TCC1_CTRLD
    DEFINE(TCC1_CTRLD)
#else
    MISSING(TCC1_CTRLD)
#endif

#ifdef TCC1_CTRLE
    DEFINE(TCC1_CTRLE)
#else
    MISSING(TCC1_CTRLE)
#endif

#ifdef TCC1_CTRLFCLR
    DEFINE(TCC1_CTRLFCLR)
#else
    MISSING(TCC1_CTRLFCLR)
#endif

#ifdef TCC1_CTRLFSET
    DEFINE(TCC1_CTRLFSET)
#else
    MISSING(TCC1_CTRLFSET)
#endif

#ifdef TCC1_CTRLGCLR
    DEFINE(TCC1_CTRLGCLR)
#else
    MISSING(TCC1_CTRLGCLR)
#endif

#ifdef TCC1_CTRLGSET
    DEFINE(TCC1_CTRLGSET)
#else
    MISSING(TCC1_CTRLGSET)
#endif

#ifdef TCC1_INTCTRLA
    DEFINE(TCC1_INTCTRLA)
#else
    MISSING(TCC1_INTCTRLA)
#endif

#ifdef TCC1_INTCTRLB
    DEFINE(TCC1_INTCTRLB)
#else
    MISSING(TCC1_INTCTRLB)
#endif

#ifdef TCC1_INTFLAGS
    DEFINE(TCC1_INTFLAGS)
#else
    MISSING(TCC1_INTFLAGS)
#endif

#ifdef TCC1_PER
    DEFINE(TCC1_PER)
#else
    MISSING(TCC1_PER)
#endif

#ifdef TCC1_PERBUF
    DEFINE(TCC1_PERBUF)
#else
    MISSING(TCC1_PERBUF)
#endif

#ifdef TCC1_TEMP
    DEFINE(TCC1_TEMP)
#else
    MISSING(TCC1_TEMP)
#endif

#ifdef TCCR0
    DEFINE(TCCR0)
#else
    MISSING(TCCR0)
#endif

#ifdef TCCR0A
    DEFINE(TCCR0A)
#else
    MISSING(TCCR0A)
#endif

#ifdef TCCR0B
    DEFINE(TCCR0B)
#else
    MISSING(TCCR0B)
#endif

#ifdef TCCR0C
    DEFINE(TCCR0C)
#else
    MISSING(TCCR0C)
#endif

#ifdef TCCR1
    DEFINE(TCCR1)
#else
    MISSING(TCCR1)
#endif

#ifdef TCCR1A
    DEFINE(TCCR1A)
#else
    MISSING(TCCR1A)
#endif

#ifdef TCCR1B
    DEFINE(TCCR1B)
#else
    MISSING(TCCR1B)
#endif

#ifdef TCCR1C
    DEFINE(TCCR1C)
#else
    MISSING(TCCR1C)
#endif

#ifdef TCCR1D
    DEFINE(TCCR1D)
#else
    MISSING(TCCR1D)
#endif

#ifdef TCCR1E
    DEFINE(TCCR1E)
#else
    MISSING(TCCR1E)
#endif

#ifdef TCCR2
    DEFINE(TCCR2)
#else
    MISSING(TCCR2)
#endif

#ifdef TCCR2A
    DEFINE(TCCR2A)
#else
    MISSING(TCCR2A)
#endif

#ifdef TCCR2B
    DEFINE(TCCR2B)
#else
    MISSING(TCCR2B)
#endif

#ifdef TCCR3A
    DEFINE(TCCR3A)
#else
    MISSING(TCCR3A)
#endif

#ifdef TCCR3B
    DEFINE(TCCR3B)
#else
    MISSING(TCCR3B)
#endif

#ifdef TCCR3C
    DEFINE(TCCR3C)
#else
    MISSING(TCCR3C)
#endif

#ifdef TCCR4A
    DEFINE(TCCR4A)
#else
    MISSING(TCCR4A)
#endif

#ifdef TCCR4B
    DEFINE(TCCR4B)
#else
    MISSING(TCCR4B)
#endif

#ifdef TCCR4C
    DEFINE(TCCR4C)
#else
    MISSING(TCCR4C)
#endif

#ifdef TCCR4D
    DEFINE(TCCR4D)
#else
    MISSING(TCCR4D)
#endif

#ifdef TCCR4E
    DEFINE(TCCR4E)
#else
    MISSING(TCCR4E)
#endif

#ifdef TCCR5A
    DEFINE(TCCR5A)
#else
    MISSING(TCCR5A)
#endif

#ifdef TCCR5B
    DEFINE(TCCR5B)
#else
    MISSING(TCCR5B)
#endif

#ifdef TCCR5C
    DEFINE(TCCR5C)
#else
    MISSING(TCCR5C)
#endif

#ifdef TCD0_CCA
    DEFINE(TCD0_CCA)
#else
    MISSING(TCD0_CCA)
#endif

#ifdef TCD0_CCABUF
    DEFINE(TCD0_CCABUF)
#else
    MISSING(TCD0_CCABUF)
#endif

#ifdef TCD0_CCB
    DEFINE(TCD0_CCB)
#else
    MISSING(TCD0_CCB)
#endif

#ifdef TCD0_CCBBUF
    DEFINE(TCD0_CCBBUF)
#else
    MISSING(TCD0_CCBBUF)
#endif

#ifdef TCD0_CCC
    DEFINE(TCD0_CCC)
#else
    MISSING(TCD0_CCC)
#endif

#ifdef TCD0_CCCBUF
    DEFINE(TCD0_CCCBUF)
#else
    MISSING(TCD0_CCCBUF)
#endif

#ifdef TCD0_CCD
    DEFINE(TCD0_CCD)
#else
    MISSING(TCD0_CCD)
#endif

#ifdef TCD0_CCDBUF
    DEFINE(TCD0_CCDBUF)
#else
    MISSING(TCD0_CCDBUF)
#endif

#ifdef TCD0_CNT
    DEFINE(TCD0_CNT)
#else
    MISSING(TCD0_CNT)
#endif

#ifdef TCD0_CTRLA
    DEFINE(TCD0_CTRLA)
#else
    MISSING(TCD0_CTRLA)
#endif

#ifdef TCD0_CTRLB
    DEFINE(TCD0_CTRLB)
#else
    MISSING(TCD0_CTRLB)
#endif

#ifdef TCD0_CTRLC
    DEFINE(TCD0_CTRLC)
#else
    MISSING(TCD0_CTRLC)
#endif

#ifdef TCD0_CTRLD
    DEFINE(TCD0_CTRLD)
#else
    MISSING(TCD0_CTRLD)
#endif

#ifdef TCD0_CTRLE
    DEFINE(TCD0_CTRLE)
#else
    MISSING(TCD0_CTRLE)
#endif

#ifdef TCD0_CTRLFCLR
    DEFINE(TCD0_CTRLFCLR)
#else
    MISSING(TCD0_CTRLFCLR)
#endif

#ifdef TCD0_CTRLFSET
    DEFINE(TCD0_CTRLFSET)
#else
    MISSING(TCD0_CTRLFSET)
#endif

#ifdef TCD0_CTRLGCLR
    DEFINE(TCD0_CTRLGCLR)
#else
    MISSING(TCD0_CTRLGCLR)
#endif

#ifdef TCD0_CTRLGSET
    DEFINE(TCD0_CTRLGSET)
#else
    MISSING(TCD0_CTRLGSET)
#endif

#ifdef TCD0_INTCTRLA
    DEFINE(TCD0_INTCTRLA)
#else
    MISSING(TCD0_INTCTRLA)
#endif

#ifdef TCD0_INTCTRLB
    DEFINE(TCD0_INTCTRLB)
#else
    MISSING(TCD0_INTCTRLB)
#endif

#ifdef TCD0_INTFLAGS
    DEFINE(TCD0_INTFLAGS)
#else
    MISSING(TCD0_INTFLAGS)
#endif

#ifdef TCD0_PER
    DEFINE(TCD0_PER)
#else
    MISSING(TCD0_PER)
#endif

#ifdef TCD0_PERBUF
    DEFINE(TCD0_PERBUF)
#else
    MISSING(TCD0_PERBUF)
#endif

#ifdef TCD0_TEMP
    DEFINE(TCD0_TEMP)
#else
    MISSING(TCD0_TEMP)
#endif

#ifdef TCD1_CCA
    DEFINE(TCD1_CCA)
#else
    MISSING(TCD1_CCA)
#endif

#ifdef TCD1_CCABUF
    DEFINE(TCD1_CCABUF)
#else
    MISSING(TCD1_CCABUF)
#endif

#ifdef TCD1_CCB
    DEFINE(TCD1_CCB)
#else
    MISSING(TCD1_CCB)
#endif

#ifdef TCD1_CCBBUF
    DEFINE(TCD1_CCBBUF)
#else
    MISSING(TCD1_CCBBUF)
#endif

#ifdef TCD1_CNT
    DEFINE(TCD1_CNT)
#else
    MISSING(TCD1_CNT)
#endif

#ifdef TCD1_CTRLA
    DEFINE(TCD1_CTRLA)
#else
    MISSING(TCD1_CTRLA)
#endif

#ifdef TCD1_CTRLB
    DEFINE(TCD1_CTRLB)
#else
    MISSING(TCD1_CTRLB)
#endif

#ifdef TCD1_CTRLC
    DEFINE(TCD1_CTRLC)
#else
    MISSING(TCD1_CTRLC)
#endif

#ifdef TCD1_CTRLD
    DEFINE(TCD1_CTRLD)
#else
    MISSING(TCD1_CTRLD)
#endif

#ifdef TCD1_CTRLE
    DEFINE(TCD1_CTRLE)
#else
    MISSING(TCD1_CTRLE)
#endif

#ifdef TCD1_CTRLFCLR
    DEFINE(TCD1_CTRLFCLR)
#else
    MISSING(TCD1_CTRLFCLR)
#endif

#ifdef TCD1_CTRLFSET
    DEFINE(TCD1_CTRLFSET)
#else
    MISSING(TCD1_CTRLFSET)
#endif

#ifdef TCD1_CTRLGCLR
    DEFINE(TCD1_CTRLGCLR)
#else
    MISSING(TCD1_CTRLGCLR)
#endif

#ifdef TCD1_CTRLGSET
    DEFINE(TCD1_CTRLGSET)
#else
    MISSING(TCD1_CTRLGSET)
#endif

#ifdef TCD1_INTCTRLA
    DEFINE(TCD1_INTCTRLA)
#else
    MISSING(TCD1_INTCTRLA)
#endif

#ifdef TCD1_INTCTRLB
    DEFINE(TCD1_INTCTRLB)
#else
    MISSING(TCD1_INTCTRLB)
#endif

#ifdef TCD1_INTFLAGS
    DEFINE(TCD1_INTFLAGS)
#else
    MISSING(TCD1_INTFLAGS)
#endif

#ifdef TCD1_PER
    DEFINE(TCD1_PER)
#else
    MISSING(TCD1_PER)
#endif

#ifdef TCD1_PERBUF
    DEFINE(TCD1_PERBUF)
#else
    MISSING(TCD1_PERBUF)
#endif

#ifdef TCD1_TEMP
    DEFINE(TCD1_TEMP)
#else
    MISSING(TCD1_TEMP)
#endif

#ifdef TCE0_CCA
    DEFINE(TCE0_CCA)
#else
    MISSING(TCE0_CCA)
#endif

#ifdef TCE0_CCABUF
    DEFINE(TCE0_CCABUF)
#else
    MISSING(TCE0_CCABUF)
#endif

#ifdef TCE0_CCB
    DEFINE(TCE0_CCB)
#else
    MISSING(TCE0_CCB)
#endif

#ifdef TCE0_CCBBUF
    DEFINE(TCE0_CCBBUF)
#else
    MISSING(TCE0_CCBBUF)
#endif

#ifdef TCE0_CCC
    DEFINE(TCE0_CCC)
#else
    MISSING(TCE0_CCC)
#endif

#ifdef TCE0_CCCBUF
    DEFINE(TCE0_CCCBUF)
#else
    MISSING(TCE0_CCCBUF)
#endif

#ifdef TCE0_CCD
    DEFINE(TCE0_CCD)
#else
    MISSING(TCE0_CCD)
#endif

#ifdef TCE0_CCDBUF
    DEFINE(TCE0_CCDBUF)
#else
    MISSING(TCE0_CCDBUF)
#endif

#ifdef TCE0_CNT
    DEFINE(TCE0_CNT)
#else
    MISSING(TCE0_CNT)
#endif

#ifdef TCE0_CTRLA
    DEFINE(TCE0_CTRLA)
#else
    MISSING(TCE0_CTRLA)
#endif

#ifdef TCE0_CTRLB
    DEFINE(TCE0_CTRLB)
#else
    MISSING(TCE0_CTRLB)
#endif

#ifdef TCE0_CTRLC
    DEFINE(TCE0_CTRLC)
#else
    MISSING(TCE0_CTRLC)
#endif

#ifdef TCE0_CTRLD
    DEFINE(TCE0_CTRLD)
#else
    MISSING(TCE0_CTRLD)
#endif

#ifdef TCE0_CTRLE
    DEFINE(TCE0_CTRLE)
#else
    MISSING(TCE0_CTRLE)
#endif

#ifdef TCE0_CTRLFCLR
    DEFINE(TCE0_CTRLFCLR)
#else
    MISSING(TCE0_CTRLFCLR)
#endif

#ifdef TCE0_CTRLFSET
    DEFINE(TCE0_CTRLFSET)
#else
    MISSING(TCE0_CTRLFSET)
#endif

#ifdef TCE0_CTRLGCLR
    DEFINE(TCE0_CTRLGCLR)
#else
    MISSING(TCE0_CTRLGCLR)
#endif

#ifdef TCE0_CTRLGSET
    DEFINE(TCE0_CTRLGSET)
#else
    MISSING(TCE0_CTRLGSET)
#endif

#ifdef TCE0_INTCTRLA
    DEFINE(TCE0_INTCTRLA)
#else
    MISSING(TCE0_INTCTRLA)
#endif

#ifdef TCE0_INTCTRLB
    DEFINE(TCE0_INTCTRLB)
#else
    MISSING(TCE0_INTCTRLB)
#endif

#ifdef TCE0_INTFLAGS
    DEFINE(TCE0_INTFLAGS)
#else
    MISSING(TCE0_INTFLAGS)
#endif

#ifdef TCE0_PER
    DEFINE(TCE0_PER)
#else
    MISSING(TCE0_PER)
#endif

#ifdef TCE0_PERBUF
    DEFINE(TCE0_PERBUF)
#else
    MISSING(TCE0_PERBUF)
#endif

#ifdef TCE0_TEMP
    DEFINE(TCE0_TEMP)
#else
    MISSING(TCE0_TEMP)
#endif

#ifdef TCE1_CCA
    DEFINE(TCE1_CCA)
#else
    MISSING(TCE1_CCA)
#endif

#ifdef TCE1_CCABUF
    DEFINE(TCE1_CCABUF)
#else
    MISSING(TCE1_CCABUF)
#endif

#ifdef TCE1_CCB
    DEFINE(TCE1_CCB)
#else
    MISSING(TCE1_CCB)
#endif

#ifdef TCE1_CCBBUF
    DEFINE(TCE1_CCBBUF)
#else
    MISSING(TCE1_CCBBUF)
#endif

#ifdef TCE1_CNT
    DEFINE(TCE1_CNT)
#else
    MISSING(TCE1_CNT)
#endif

#ifdef TCE1_CTRLA
    DEFINE(TCE1_CTRLA)
#else
    MISSING(TCE1_CTRLA)
#endif

#ifdef TCE1_CTRLB
    DEFINE(TCE1_CTRLB)
#else
    MISSING(TCE1_CTRLB)
#endif

#ifdef TCE1_CTRLC
    DEFINE(TCE1_CTRLC)
#else
    MISSING(TCE1_CTRLC)
#endif

#ifdef TCE1_CTRLD
    DEFINE(TCE1_CTRLD)
#else
    MISSING(TCE1_CTRLD)
#endif

#ifdef TCE1_CTRLE
    DEFINE(TCE1_CTRLE)
#else
    MISSING(TCE1_CTRLE)
#endif

#ifdef TCE1_CTRLFCLR
    DEFINE(TCE1_CTRLFCLR)
#else
    MISSING(TCE1_CTRLFCLR)
#endif

#ifdef TCE1_CTRLFSET
    DEFINE(TCE1_CTRLFSET)
#else
    MISSING(TCE1_CTRLFSET)
#endif

#ifdef TCE1_CTRLGCLR
    DEFINE(TCE1_CTRLGCLR)
#else
    MISSING(TCE1_CTRLGCLR)
#endif

#ifdef TCE1_CTRLGSET
    DEFINE(TCE1_CTRLGSET)
#else
    MISSING(TCE1_CTRLGSET)
#endif

#ifdef TCE1_INTCTRLA
    DEFINE(TCE1_INTCTRLA)
#else
    MISSING(TCE1_INTCTRLA)
#endif

#ifdef TCE1_INTCTRLB
    DEFINE(TCE1_INTCTRLB)
#else
    MISSING(TCE1_INTCTRLB)
#endif

#ifdef TCE1_INTFLAGS
    DEFINE(TCE1_INTFLAGS)
#else
    MISSING(TCE1_INTFLAGS)
#endif

#ifdef TCE1_PER
    DEFINE(TCE1_PER)
#else
    MISSING(TCE1_PER)
#endif

#ifdef TCE1_PERBUF
    DEFINE(TCE1_PERBUF)
#else
    MISSING(TCE1_PERBUF)
#endif

#ifdef TCE1_TEMP
    DEFINE(TCE1_TEMP)
#else
    MISSING(TCE1_TEMP)
#endif

#ifdef TCF0_CCA
    DEFINE(TCF0_CCA)
#else
    MISSING(TCF0_CCA)
#endif

#ifdef TCF0_CCABUF
    DEFINE(TCF0_CCABUF)
#else
    MISSING(TCF0_CCABUF)
#endif

#ifdef TCF0_CCB
    DEFINE(TCF0_CCB)
#else
    MISSING(TCF0_CCB)
#endif

#ifdef TCF0_CCBBUF
    DEFINE(TCF0_CCBBUF)
#else
    MISSING(TCF0_CCBBUF)
#endif

#ifdef TCF0_CCC
    DEFINE(TCF0_CCC)
#else
    MISSING(TCF0_CCC)
#endif

#ifdef TCF0_CCCBUF
    DEFINE(TCF0_CCCBUF)
#else
    MISSING(TCF0_CCCBUF)
#endif

#ifdef TCF0_CCD
    DEFINE(TCF0_CCD)
#else
    MISSING(TCF0_CCD)
#endif

#ifdef TCF0_CCDBUF
    DEFINE(TCF0_CCDBUF)
#else
    MISSING(TCF0_CCDBUF)
#endif

#ifdef TCF0_CNT
    DEFINE(TCF0_CNT)
#else
    MISSING(TCF0_CNT)
#endif

#ifdef TCF0_CTRLA
    DEFINE(TCF0_CTRLA)
#else
    MISSING(TCF0_CTRLA)
#endif

#ifdef TCF0_CTRLB
    DEFINE(TCF0_CTRLB)
#else
    MISSING(TCF0_CTRLB)
#endif

#ifdef TCF0_CTRLC
    DEFINE(TCF0_CTRLC)
#else
    MISSING(TCF0_CTRLC)
#endif

#ifdef TCF0_CTRLD
    DEFINE(TCF0_CTRLD)
#else
    MISSING(TCF0_CTRLD)
#endif

#ifdef TCF0_CTRLE
    DEFINE(TCF0_CTRLE)
#else
    MISSING(TCF0_CTRLE)
#endif

#ifdef TCF0_CTRLFCLR
    DEFINE(TCF0_CTRLFCLR)
#else
    MISSING(TCF0_CTRLFCLR)
#endif

#ifdef TCF0_CTRLFSET
    DEFINE(TCF0_CTRLFSET)
#else
    MISSING(TCF0_CTRLFSET)
#endif

#ifdef TCF0_CTRLGCLR
    DEFINE(TCF0_CTRLGCLR)
#else
    MISSING(TCF0_CTRLGCLR)
#endif

#ifdef TCF0_CTRLGSET
    DEFINE(TCF0_CTRLGSET)
#else
    MISSING(TCF0_CTRLGSET)
#endif

#ifdef TCF0_INTCTRLA
    DEFINE(TCF0_INTCTRLA)
#else
    MISSING(TCF0_INTCTRLA)
#endif

#ifdef TCF0_INTCTRLB
    DEFINE(TCF0_INTCTRLB)
#else
    MISSING(TCF0_INTCTRLB)
#endif

#ifdef TCF0_INTFLAGS
    DEFINE(TCF0_INTFLAGS)
#else
    MISSING(TCF0_INTFLAGS)
#endif

#ifdef TCF0_PER
    DEFINE(TCF0_PER)
#else
    MISSING(TCF0_PER)
#endif

#ifdef TCF0_PERBUF
    DEFINE(TCF0_PERBUF)
#else
    MISSING(TCF0_PERBUF)
#endif

#ifdef TCF0_TEMP
    DEFINE(TCF0_TEMP)
#else
    MISSING(TCF0_TEMP)
#endif

#ifdef TCF1_CCA
    DEFINE(TCF1_CCA)
#else
    MISSING(TCF1_CCA)
#endif

#ifdef TCF1_CCABUF
    DEFINE(TCF1_CCABUF)
#else
    MISSING(TCF1_CCABUF)
#endif

#ifdef TCF1_CCB
    DEFINE(TCF1_CCB)
#else
    MISSING(TCF1_CCB)
#endif

#ifdef TCF1_CCBBUF
    DEFINE(TCF1_CCBBUF)
#else
    MISSING(TCF1_CCBBUF)
#endif

#ifdef TCF1_CNT
    DEFINE(TCF1_CNT)
#else
    MISSING(TCF1_CNT)
#endif

#ifdef TCF1_CTRLA
    DEFINE(TCF1_CTRLA)
#else
    MISSING(TCF1_CTRLA)
#endif

#ifdef TCF1_CTRLB
    DEFINE(TCF1_CTRLB)
#else
    MISSING(TCF1_CTRLB)
#endif

#ifdef TCF1_CTRLC
    DEFINE(TCF1_CTRLC)
#else
    MISSING(TCF1_CTRLC)
#endif

#ifdef TCF1_CTRLD
    DEFINE(TCF1_CTRLD)
#else
    MISSING(TCF1_CTRLD)
#endif

#ifdef TCF1_CTRLE
    DEFINE(TCF1_CTRLE)
#else
    MISSING(TCF1_CTRLE)
#endif

#ifdef TCF1_CTRLFCLR
    DEFINE(TCF1_CTRLFCLR)
#else
    MISSING(TCF1_CTRLFCLR)
#endif

#ifdef TCF1_CTRLFSET
    DEFINE(TCF1_CTRLFSET)
#else
    MISSING(TCF1_CTRLFSET)
#endif

#ifdef TCF1_CTRLGCLR
    DEFINE(TCF1_CTRLGCLR)
#else
    MISSING(TCF1_CTRLGCLR)
#endif

#ifdef TCF1_CTRLGSET
    DEFINE(TCF1_CTRLGSET)
#else
    MISSING(TCF1_CTRLGSET)
#endif

#ifdef TCF1_INTCTRLA
    DEFINE(TCF1_INTCTRLA)
#else
    MISSING(TCF1_INTCTRLA)
#endif

#ifdef TCF1_INTCTRLB
    DEFINE(TCF1_INTCTRLB)
#else
    MISSING(TCF1_INTCTRLB)
#endif

#ifdef TCF1_INTFLAGS
    DEFINE(TCF1_INTFLAGS)
#else
    MISSING(TCF1_INTFLAGS)
#endif

#ifdef TCF1_PER
    DEFINE(TCF1_PER)
#else
    MISSING(TCF1_PER)
#endif

#ifdef TCF1_PERBUF
    DEFINE(TCF1_PERBUF)
#else
    MISSING(TCF1_PERBUF)
#endif

#ifdef TCF1_TEMP
    DEFINE(TCF1_TEMP)
#else
    MISSING(TCF1_TEMP)
#endif

#ifdef TCNT0
    DEFINE(TCNT0)
#else
    MISSING(TCNT0)
#endif

#ifdef TCNT0H
    DEFINE(TCNT0H)
#else
    MISSING(TCNT0H)
#endif

#ifdef TCNT0L
    DEFINE(TCNT0L)
#else
    MISSING(TCNT0L)
#endif

#ifdef TCNT1
    DEFINE(TCNT1)
#else
    MISSING(TCNT1)
#endif

#ifdef TCNT1H
    DEFINE(TCNT1H)
#else
    MISSING(TCNT1H)
#endif

#ifdef TCNT1L
    DEFINE(TCNT1L)
#else
    MISSING(TCNT1L)
#endif

#ifdef TCNT2
    DEFINE(TCNT2)
#else
    MISSING(TCNT2)
#endif

#ifdef TCNT3
    DEFINE(TCNT3)
#else
    MISSING(TCNT3)
#endif

#ifdef TCNT3H
    DEFINE(TCNT3H)
#else
    MISSING(TCNT3H)
#endif

#ifdef TCNT3L
    DEFINE(TCNT3L)
#else
    MISSING(TCNT3L)
#endif

#ifdef TCNT4
    DEFINE(TCNT4)
#else
    MISSING(TCNT4)
#endif

#ifdef TCNT4H
    DEFINE(TCNT4H)
#else
    MISSING(TCNT4H)
#endif

#ifdef TCNT4L
    DEFINE(TCNT4L)
#else
    MISSING(TCNT4L)
#endif

#ifdef TCNT5
    DEFINE(TCNT5)
#else
    MISSING(TCNT5)
#endif

#ifdef TCNT5H
    DEFINE(TCNT5H)
#else
    MISSING(TCNT5H)
#endif

#ifdef TCNT5L
    DEFINE(TCNT5L)
#else
    MISSING(TCNT5L)
#endif

#ifdef TIFR
    DEFINE(TIFR)
#else
    MISSING(TIFR)
#endif

#ifdef TIFR0
    DEFINE(TIFR0)
#else
    MISSING(TIFR0)
#endif

#ifdef TIFR1
    DEFINE(TIFR1)
#else
    MISSING(TIFR1)
#endif

#ifdef TIFR2
    DEFINE(TIFR2)
#else
    MISSING(TIFR2)
#endif

#ifdef TIFR3
    DEFINE(TIFR3)
#else
    MISSING(TIFR3)
#endif

#ifdef TIFR4
    DEFINE(TIFR4)
#else
    MISSING(TIFR4)
#endif

#ifdef TIFR5
    DEFINE(TIFR5)
#else
    MISSING(TIFR5)
#endif

#ifdef TIMSK
    DEFINE(TIMSK)
#else
    MISSING(TIMSK)
#endif

#ifdef TIMSK0
    DEFINE(TIMSK0)
#else
    MISSING(TIMSK0)
#endif

#ifdef TIMSK1
    DEFINE(TIMSK1)
#else
    MISSING(TIMSK1)
#endif

#ifdef TIMSK2
    DEFINE(TIMSK2)
#else
    MISSING(TIMSK2)
#endif

#ifdef TIMSK3
    DEFINE(TIMSK3)
#else
    MISSING(TIMSK3)
#endif

#ifdef TIMSK4
    DEFINE(TIMSK4)
#else
    MISSING(TIMSK4)
#endif

#ifdef TIMSK5
    DEFINE(TIMSK5)
#else
    MISSING(TIMSK5)
#endif

#ifdef TRXFBEND
    DEFINE(TRXFBEND)
#else
    MISSING(TRXFBEND)
#endif

#ifdef TRXFBST
    DEFINE(TRXFBST)
#else
    MISSING(TRXFBST)
#endif

#ifdef TRXPR
    DEFINE(TRXPR)
#else
    MISSING(TRXPR)
#endif

#ifdef TRX_CTRL_0
    DEFINE(TRX_CTRL_0)
#else
    MISSING(TRX_CTRL_0)
#endif

#ifdef TRX_CTRL_1
    DEFINE(TRX_CTRL_1)
#else
    MISSING(TRX_CTRL_1)
#endif

#ifdef TRX_CTRL_2
    DEFINE(TRX_CTRL_2)
#else
    MISSING(TRX_CTRL_2)
#endif

#ifdef TRX_STATE
    DEFINE(TRX_STATE)
#else
    MISSING(TRX_STATE)
#endif

#ifdef TRX_STATUS
    DEFINE(TRX_STATUS)
#else
    MISSING(TRX_STATUS)
#endif

#ifdef TSCR
    DEFINE(TSCR)
#else
    MISSING(TSCR)
#endif

#ifdef TST_CTRL_DIGI
    DEFINE(TST_CTRL_DIGI)
#else
    MISSING(TST_CTRL_DIGI)
#endif

#ifdef TST_RX_LENGTH
    DEFINE(TST_RX_LENGTH)
#else
    MISSING(TST_RX_LENGTH)
#endif

#ifdef TWAMR
    DEFINE(TWAMR)
#else
    MISSING(TWAMR)
#endif

#ifdef TWAR
    DEFINE(TWAR)
#else
    MISSING(TWAR)
#endif

#ifdef TWBCSR
    DEFINE(TWBCSR)
#else
    MISSING(TWBCSR)
#endif

#ifdef TWBR
    DEFINE(TWBR)
#else
    MISSING(TWBR)
#endif

#ifdef TWCR
    DEFINE(TWCR)
#else
    MISSING(TWCR)
#endif

#ifdef TWDR
    DEFINE(TWDR)
#else
    MISSING(TWDR)
#endif

#ifdef TWHSR
    DEFINE(TWHSR)
#else
    MISSING(TWHSR)
#endif

#ifdef TWIC_CTRL
    DEFINE(TWIC_CTRL)
#else
    MISSING(TWIC_CTRL)
#endif

#ifdef TWIC_MASTER_ADDR
    DEFINE(TWIC_MASTER_ADDR)
#else
    MISSING(TWIC_MASTER_ADDR)
#endif

#ifdef TWIC_MASTER_BAUD
    DEFINE(TWIC_MASTER_BAUD)
#else
    MISSING(TWIC_MASTER_BAUD)
#endif

#ifdef TWIC_MASTER_CTRLA
    DEFINE(TWIC_MASTER_CTRLA)
#else
    MISSING(TWIC_MASTER_CTRLA)
#endif

#ifdef TWIC_MASTER_CTRLB
    DEFINE(TWIC_MASTER_CTRLB)
#else
    MISSING(TWIC_MASTER_CTRLB)
#endif

#ifdef TWIC_MASTER_CTRLC
    DEFINE(TWIC_MASTER_CTRLC)
#else
    MISSING(TWIC_MASTER_CTRLC)
#endif

#ifdef TWIC_MASTER_DATA
    DEFINE(TWIC_MASTER_DATA)
#else
    MISSING(TWIC_MASTER_DATA)
#endif

#ifdef TWIC_MASTER_STATUS
    DEFINE(TWIC_MASTER_STATUS)
#else
    MISSING(TWIC_MASTER_STATUS)
#endif

#ifdef TWIC_SLAVE_ADDR
    DEFINE(TWIC_SLAVE_ADDR)
#else
    MISSING(TWIC_SLAVE_ADDR)
#endif

#ifdef TWIC_SLAVE_ADDRMASK
    DEFINE(TWIC_SLAVE_ADDRMASK)
#else
    MISSING(TWIC_SLAVE_ADDRMASK)
#endif

#ifdef TWIC_SLAVE_CTRLA
    DEFINE(TWIC_SLAVE_CTRLA)
#else
    MISSING(TWIC_SLAVE_CTRLA)
#endif

#ifdef TWIC_SLAVE_CTRLB
    DEFINE(TWIC_SLAVE_CTRLB)
#else
    MISSING(TWIC_SLAVE_CTRLB)
#endif

#ifdef TWIC_SLAVE_DATA
    DEFINE(TWIC_SLAVE_DATA)
#else
    MISSING(TWIC_SLAVE_DATA)
#endif

#ifdef TWIC_SLAVE_STATUS
    DEFINE(TWIC_SLAVE_STATUS)
#else
    MISSING(TWIC_SLAVE_STATUS)
#endif

#ifdef TWID_CTRL
    DEFINE(TWID_CTRL)
#else
    MISSING(TWID_CTRL)
#endif

#ifdef TWID_MASTER_ADDR
    DEFINE(TWID_MASTER_ADDR)
#else
    MISSING(TWID_MASTER_ADDR)
#endif

#ifdef TWID_MASTER_BAUD
    DEFINE(TWID_MASTER_BAUD)
#else
    MISSING(TWID_MASTER_BAUD)
#endif

#ifdef TWID_MASTER_CTRLA
    DEFINE(TWID_MASTER_CTRLA)
#else
    MISSING(TWID_MASTER_CTRLA)
#endif

#ifdef TWID_MASTER_CTRLB
    DEFINE(TWID_MASTER_CTRLB)
#else
    MISSING(TWID_MASTER_CTRLB)
#endif

#ifdef TWID_MASTER_CTRLC
    DEFINE(TWID_MASTER_CTRLC)
#else
    MISSING(TWID_MASTER_CTRLC)
#endif

#ifdef TWID_MASTER_DATA
    DEFINE(TWID_MASTER_DATA)
#else
    MISSING(TWID_MASTER_DATA)
#endif

#ifdef TWID_MASTER_STATUS
    DEFINE(TWID_MASTER_STATUS)
#else
    MISSING(TWID_MASTER_STATUS)
#endif

#ifdef TWID_SLAVE_ADDR
    DEFINE(TWID_SLAVE_ADDR)
#else
    MISSING(TWID_SLAVE_ADDR)
#endif

#ifdef TWID_SLAVE_ADDRMASK
    DEFINE(TWID_SLAVE_ADDRMASK)
#else
    MISSING(TWID_SLAVE_ADDRMASK)
#endif

#ifdef TWID_SLAVE_CTRLA
    DEFINE(TWID_SLAVE_CTRLA)
#else
    MISSING(TWID_SLAVE_CTRLA)
#endif

#ifdef TWID_SLAVE_CTRLB
    DEFINE(TWID_SLAVE_CTRLB)
#else
    MISSING(TWID_SLAVE_CTRLB)
#endif

#ifdef TWID_SLAVE_DATA
    DEFINE(TWID_SLAVE_DATA)
#else
    MISSING(TWID_SLAVE_DATA)
#endif

#ifdef TWID_SLAVE_STATUS
    DEFINE(TWID_SLAVE_STATUS)
#else
    MISSING(TWID_SLAVE_STATUS)
#endif

#ifdef TWIE_CTRL
    DEFINE(TWIE_CTRL)
#else
    MISSING(TWIE_CTRL)
#endif

#ifdef TWIE_MASTER_ADDR
    DEFINE(TWIE_MASTER_ADDR)
#else
    MISSING(TWIE_MASTER_ADDR)
#endif

#ifdef TWIE_MASTER_BAUD
    DEFINE(TWIE_MASTER_BAUD)
#else
    MISSING(TWIE_MASTER_BAUD)
#endif

#ifdef TWIE_MASTER_CTRLA
    DEFINE(TWIE_MASTER_CTRLA)
#else
    MISSING(TWIE_MASTER_CTRLA)
#endif

#ifdef TWIE_MASTER_CTRLB
    DEFINE(TWIE_MASTER_CTRLB)
#else
    MISSING(TWIE_MASTER_CTRLB)
#endif

#ifdef TWIE_MASTER_CTRLC
    DEFINE(TWIE_MASTER_CTRLC)
#else
    MISSING(TWIE_MASTER_CTRLC)
#endif

#ifdef TWIE_MASTER_DATA
    DEFINE(TWIE_MASTER_DATA)
#else
    MISSING(TWIE_MASTER_DATA)
#endif

#ifdef TWIE_MASTER_STATUS
    DEFINE(TWIE_MASTER_STATUS)
#else
    MISSING(TWIE_MASTER_STATUS)
#endif

#ifdef TWIE_SLAVE_ADDR
    DEFINE(TWIE_SLAVE_ADDR)
#else
    MISSING(TWIE_SLAVE_ADDR)
#endif

#ifdef TWIE_SLAVE_ADDRMASK
    DEFINE(TWIE_SLAVE_ADDRMASK)
#else
    MISSING(TWIE_SLAVE_ADDRMASK)
#endif

#ifdef TWIE_SLAVE_CTRLA
    DEFINE(TWIE_SLAVE_CTRLA)
#else
    MISSING(TWIE_SLAVE_CTRLA)
#endif

#ifdef TWIE_SLAVE_CTRLB
    DEFINE(TWIE_SLAVE_CTRLB)
#else
    MISSING(TWIE_SLAVE_CTRLB)
#endif

#ifdef TWIE_SLAVE_DATA
    DEFINE(TWIE_SLAVE_DATA)
#else
    MISSING(TWIE_SLAVE_DATA)
#endif

#ifdef TWIE_SLAVE_STATUS
    DEFINE(TWIE_SLAVE_STATUS)
#else
    MISSING(TWIE_SLAVE_STATUS)
#endif

#ifdef TWIF_CTRL
    DEFINE(TWIF_CTRL)
#else
    MISSING(TWIF_CTRL)
#endif

#ifdef TWIF_MASTER_ADDR
    DEFINE(TWIF_MASTER_ADDR)
#else
    MISSING(TWIF_MASTER_ADDR)
#endif

#ifdef TWIF_MASTER_BAUD
    DEFINE(TWIF_MASTER_BAUD)
#else
    MISSING(TWIF_MASTER_BAUD)
#endif

#ifdef TWIF_MASTER_CTRLA
    DEFINE(TWIF_MASTER_CTRLA)
#else
    MISSING(TWIF_MASTER_CTRLA)
#endif

#ifdef TWIF_MASTER_CTRLB
    DEFINE(TWIF_MASTER_CTRLB)
#else
    MISSING(TWIF_MASTER_CTRLB)
#endif

#ifdef TWIF_MASTER_CTRLC
    DEFINE(TWIF_MASTER_CTRLC)
#else
    MISSING(TWIF_MASTER_CTRLC)
#endif

#ifdef TWIF_MASTER_DATA
    DEFINE(TWIF_MASTER_DATA)
#else
    MISSING(TWIF_MASTER_DATA)
#endif

#ifdef TWIF_MASTER_STATUS
    DEFINE(TWIF_MASTER_STATUS)
#else
    MISSING(TWIF_MASTER_STATUS)
#endif

#ifdef TWIF_SLAVE_ADDR
    DEFINE(TWIF_SLAVE_ADDR)
#else
    MISSING(TWIF_SLAVE_ADDR)
#endif

#ifdef TWIF_SLAVE_ADDRMASK
    DEFINE(TWIF_SLAVE_ADDRMASK)
#else
    MISSING(TWIF_SLAVE_ADDRMASK)
#endif

#ifdef TWIF_SLAVE_CTRLA
    DEFINE(TWIF_SLAVE_CTRLA)
#else
    MISSING(TWIF_SLAVE_CTRLA)
#endif

#ifdef TWIF_SLAVE_CTRLB
    DEFINE(TWIF_SLAVE_CTRLB)
#else
    MISSING(TWIF_SLAVE_CTRLB)
#endif

#ifdef TWIF_SLAVE_DATA
    DEFINE(TWIF_SLAVE_DATA)
#else
    MISSING(TWIF_SLAVE_DATA)
#endif

#ifdef TWIF_SLAVE_STATUS
    DEFINE(TWIF_SLAVE_STATUS)
#else
    MISSING(TWIF_SLAVE_STATUS)
#endif

#ifdef TWIHSR
    DEFINE(TWIHSR)
#else
    MISSING(TWIHSR)
#endif

#ifdef TWSA
    DEFINE(TWSA)
#else
    MISSING(TWSA)
#endif

#ifdef TWSAM
    DEFINE(TWSAM)
#else
    MISSING(TWSAM)
#endif

#ifdef TWSCRA
    DEFINE(TWSCRA)
#else
    MISSING(TWSCRA)
#endif

#ifdef TWSCRB
    DEFINE(TWSCRB)
#else
    MISSING(TWSCRB)
#endif

#ifdef TWSD
    DEFINE(TWSD)
#else
    MISSING(TWSD)
#endif

#ifdef TWSR
    DEFINE(TWSR)
#else
    MISSING(TWSR)
#endif

#ifdef TWSSRA
    DEFINE(TWSSRA)
#else
    MISSING(TWSSRA)
#endif

#ifdef TXB
    DEFINE(TXB)
#else
    MISSING(TXB)
#endif

#ifdef TX_CNTL
    DEFINE(TX_CNTL)
#else
    MISSING(TX_CNTL)
#endif

#ifdef UBRR
    DEFINE(UBRR)
#else
    MISSING(UBRR)
#endif

#ifdef UBRR0
    DEFINE(UBRR0)
#else
    MISSING(UBRR0)
#endif

#ifdef UBRR0H
    DEFINE(UBRR0H)
#else
    MISSING(UBRR0H)
#endif

#ifdef UBRR0L
    DEFINE(UBRR0L)
#else
    MISSING(UBRR0L)
#endif

#ifdef UBRR1
    DEFINE(UBRR1)
#else
    MISSING(UBRR1)
#endif

#ifdef UBRR1H
    DEFINE(UBRR1H)
#else
    MISSING(UBRR1H)
#endif

#ifdef UBRR1L
    DEFINE(UBRR1L)
#else
    MISSING(UBRR1L)
#endif

#ifdef UBRR2
    DEFINE(UBRR2)
#else
    MISSING(UBRR2)
#endif

#ifdef UBRR2H
    DEFINE(UBRR2H)
#else
    MISSING(UBRR2H)
#endif

#ifdef UBRR2L
    DEFINE(UBRR2L)
#else
    MISSING(UBRR2L)
#endif

#ifdef UBRR3
    DEFINE(UBRR3)
#else
    MISSING(UBRR3)
#endif

#ifdef UBRR3H
    DEFINE(UBRR3H)
#else
    MISSING(UBRR3H)
#endif

#ifdef UBRR3L
    DEFINE(UBRR3L)
#else
    MISSING(UBRR3L)
#endif

#ifdef UBRRH
    DEFINE(UBRRH)
#else
    MISSING(UBRRH)
#endif

#ifdef UBRRHI
    DEFINE(UBRRHI)
#else
    MISSING(UBRRHI)
#endif

#ifdef UBRRL
    DEFINE(UBRRL)
#else
    MISSING(UBRRL)
#endif

#ifdef UBRRLO
    DEFINE(UBRRLO)
#else
    MISSING(UBRRLO)
#endif

#ifdef UCR
    DEFINE(UCR)
#else
    MISSING(UCR)
#endif

#ifdef UCRA
    DEFINE(UCRA)
#else
    MISSING(UCRA)
#endif

#ifdef UCRB
    DEFINE(UCRB)
#else
    MISSING(UCRB)
#endif

#ifdef UCSR0A
    DEFINE(UCSR0A)
#else
    MISSING(UCSR0A)
#endif

#ifdef UCSR0B
    DEFINE(UCSR0B)
#else
    MISSING(UCSR0B)
#endif

#ifdef UCSR0C
    DEFINE(UCSR0C)
#else
    MISSING(UCSR0C)
#endif

#ifdef UCSR1A
    DEFINE(UCSR1A)
#else
    MISSING(UCSR1A)
#endif

#ifdef UCSR1B
    DEFINE(UCSR1B)
#else
    MISSING(UCSR1B)
#endif

#ifdef UCSR1C
    DEFINE(UCSR1C)
#else
    MISSING(UCSR1C)
#endif

#ifdef UCSR1D
    DEFINE(UCSR1D)
#else
    MISSING(UCSR1D)
#endif

#ifdef UCSR2A
    DEFINE(UCSR2A)
#else
    MISSING(UCSR2A)
#endif

#ifdef UCSR2B
    DEFINE(UCSR2B)
#else
    MISSING(UCSR2B)
#endif

#ifdef UCSR2C
    DEFINE(UCSR2C)
#else
    MISSING(UCSR2C)
#endif

#ifdef UCSR3A
    DEFINE(UCSR3A)
#else
    MISSING(UCSR3A)
#endif

#ifdef UCSR3B
    DEFINE(UCSR3B)
#else
    MISSING(UCSR3B)
#endif

#ifdef UCSR3C
    DEFINE(UCSR3C)
#else
    MISSING(UCSR3C)
#endif

#ifdef UCSRA
    DEFINE(UCSRA)
#else
    MISSING(UCSRA)
#endif

#ifdef UCSRB
    DEFINE(UCSRB)
#else
    MISSING(UCSRB)
#endif

#ifdef UCSRC
    DEFINE(UCSRC)
#else
    MISSING(UCSRC)
#endif

#ifdef UDADDR
    DEFINE(UDADDR)
#else
    MISSING(UDADDR)
#endif

#ifdef UDCON
    DEFINE(UDCON)
#else
    MISSING(UDCON)
#endif

#ifdef UDFNUM
    DEFINE(UDFNUM)
#else
    MISSING(UDFNUM)
#endif

#ifdef UDFNUMH
    DEFINE(UDFNUMH)
#else
    MISSING(UDFNUMH)
#endif

#ifdef UDFNUML
    DEFINE(UDFNUML)
#else
    MISSING(UDFNUML)
#endif

#ifdef UDIEN
    DEFINE(UDIEN)
#else
    MISSING(UDIEN)
#endif

#ifdef UDINT
    DEFINE(UDINT)
#else
    MISSING(UDINT)
#endif

#ifdef UDMFN
    DEFINE(UDMFN)
#else
    MISSING(UDMFN)
#endif

#ifdef UDPADD
    DEFINE(UDPADD)
#else
    MISSING(UDPADD)
#endif

#ifdef UDPADDH
    DEFINE(UDPADDH)
#else
    MISSING(UDPADDH)
#endif

#ifdef UDPADDL
    DEFINE(UDPADDL)
#else
    MISSING(UDPADDL)
#endif

#ifdef UDR
    DEFINE(UDR)
#else
    MISSING(UDR)
#endif

#ifdef UDR0
    DEFINE(UDR0)
#else
    MISSING(UDR0)
#endif

#ifdef UDR1
    DEFINE(UDR1)
#else
    MISSING(UDR1)
#endif

#ifdef UDR2
    DEFINE(UDR2)
#else
    MISSING(UDR2)
#endif

#ifdef UDR3
    DEFINE(UDR3)
#else
    MISSING(UDR3)
#endif

#ifdef UDTST
    DEFINE(UDTST)
#else
    MISSING(UDTST)
#endif

#ifdef UEBCHX
    DEFINE(UEBCHX)
#else
    MISSING(UEBCHX)
#endif

#ifdef UEBCLX
    DEFINE(UEBCLX)
#else
    MISSING(UEBCLX)
#endif

#ifdef UEBCX
    DEFINE(UEBCX)
#else
    MISSING(UEBCX)
#endif

#ifdef UECFG0X
    DEFINE(UECFG0X)
#else
    MISSING(UECFG0X)
#endif

#ifdef UECFG1X
    DEFINE(UECFG1X)
#else
    MISSING(UECFG1X)
#endif

#ifdef UECONX
    DEFINE(UECONX)
#else
    MISSING(UECONX)
#endif

#ifdef UEDATX
    DEFINE(UEDATX)
#else
    MISSING(UEDATX)
#endif

#ifdef UEIENX
    DEFINE(UEIENX)
#else
    MISSING(UEIENX)
#endif

#ifdef UEINT
    DEFINE(UEINT)
#else
    MISSING(UEINT)
#endif

#ifdef UEINTX
    DEFINE(UEINTX)
#else
    MISSING(UEINTX)
#endif

#ifdef UENUM
    DEFINE(UENUM)
#else
    MISSING(UENUM)
#endif

#ifdef UERST
    DEFINE(UERST)
#else
    MISSING(UERST)
#endif

#ifdef UESTA0X
    DEFINE(UESTA0X)
#else
    MISSING(UESTA0X)
#endif

#ifdef UESTA1X
    DEFINE(UESTA1X)
#else
    MISSING(UESTA1X)
#endif

#ifdef UHADDR
    DEFINE(UHADDR)
#else
    MISSING(UHADDR)
#endif

#ifdef UHCON
    DEFINE(UHCON)
#else
    MISSING(UHCON)
#endif

#ifdef UHCR
    DEFINE(UHCR)
#else
    MISSING(UHCR)
#endif

#ifdef UHFLEN
    DEFINE(UHFLEN)
#else
    MISSING(UHFLEN)
#endif

#ifdef UHFNUM
    DEFINE(UHFNUM)
#else
    MISSING(UHFNUM)
#endif

#ifdef UHFNUMH
    DEFINE(UHFNUMH)
#else
    MISSING(UHFNUMH)
#endif

#ifdef UHFNUML
    DEFINE(UHFNUML)
#else
    MISSING(UHFNUML)
#endif

#ifdef UHIEN
    DEFINE(UHIEN)
#else
    MISSING(UHIEN)
#endif

#ifdef UHINT
    DEFINE(UHINT)
#else
    MISSING(UHINT)
#endif

#ifdef UHSR
    DEFINE(UHSR)
#else
    MISSING(UHSR)
#endif

#ifdef UHWCON
    DEFINE(UHWCON)
#else
    MISSING(UHWCON)
#endif

#ifdef UPBCHX
    DEFINE(UPBCHX)
#else
    MISSING(UPBCHX)
#endif

#ifdef UPBCLX
    DEFINE(UPBCLX)
#else
    MISSING(UPBCLX)
#endif

#ifdef UPBCX
    DEFINE(UPBCX)
#else
    MISSING(UPBCX)
#endif

#ifdef UPBCXH
    DEFINE(UPBCXH)
#else
    MISSING(UPBCXH)
#endif

#ifdef UPBCXL
    DEFINE(UPBCXL)
#else
    MISSING(UPBCXL)
#endif

#ifdef UPCFG0X
    DEFINE(UPCFG0X)
#else
    MISSING(UPCFG0X)
#endif

#ifdef UPCFG1X
    DEFINE(UPCFG1X)
#else
    MISSING(UPCFG1X)
#endif

#ifdef UPCFG2X
    DEFINE(UPCFG2X)
#else
    MISSING(UPCFG2X)
#endif

#ifdef UPCONX
    DEFINE(UPCONX)
#else
    MISSING(UPCONX)
#endif

#ifdef UPCRX
    DEFINE(UPCRX)
#else
    MISSING(UPCRX)
#endif

#ifdef UPDATX
    DEFINE(UPDATX)
#else
    MISSING(UPDATX)
#endif

#ifdef UPERRX
    DEFINE(UPERRX)
#else
    MISSING(UPERRX)
#endif

#ifdef UPIENX
    DEFINE(UPIENX)
#else
    MISSING(UPIENX)
#endif

#ifdef UPINRQX
    DEFINE(UPINRQX)
#else
    MISSING(UPINRQX)
#endif

#ifdef UPINT
    DEFINE(UPINT)
#else
    MISSING(UPINT)
#endif

#ifdef UPINTX
    DEFINE(UPINTX)
#else
    MISSING(UPINTX)
#endif

#ifdef UPNUM
    DEFINE(UPNUM)
#else
    MISSING(UPNUM)
#endif

#ifdef UPOE
    DEFINE(UPOE)
#else
    MISSING(UPOE)
#endif

#ifdef UPRST
    DEFINE(UPRST)
#else
    MISSING(UPRST)
#endif

#ifdef UPSTAX
    DEFINE(UPSTAX)
#else
    MISSING(UPSTAX)
#endif

#ifdef USARTC0_BAUDCTRLA
    DEFINE(USARTC0_BAUDCTRLA)
#else
    MISSING(USARTC0_BAUDCTRLA)
#endif

#ifdef USARTC0_BAUDCTRLB
    DEFINE(USARTC0_BAUDCTRLB)
#else
    MISSING(USARTC0_BAUDCTRLB)
#endif

#ifdef USARTC0_CTRLA
    DEFINE(USARTC0_CTRLA)
#else
    MISSING(USARTC0_CTRLA)
#endif

#ifdef USARTC0_CTRLB
    DEFINE(USARTC0_CTRLB)
#else
    MISSING(USARTC0_CTRLB)
#endif

#ifdef USARTC0_CTRLC
    DEFINE(USARTC0_CTRLC)
#else
    MISSING(USARTC0_CTRLC)
#endif

#ifdef USARTC0_DATA
    DEFINE(USARTC0_DATA)
#else
    MISSING(USARTC0_DATA)
#endif

#ifdef USARTC0_STATUS
    DEFINE(USARTC0_STATUS)
#else
    MISSING(USARTC0_STATUS)
#endif

#ifdef USARTC1_BAUDCTRLA
    DEFINE(USARTC1_BAUDCTRLA)
#else
    MISSING(USARTC1_BAUDCTRLA)
#endif

#ifdef USARTC1_BAUDCTRLB
    DEFINE(USARTC1_BAUDCTRLB)
#else
    MISSING(USARTC1_BAUDCTRLB)
#endif

#ifdef USARTC1_CTRLA
    DEFINE(USARTC1_CTRLA)
#else
    MISSING(USARTC1_CTRLA)
#endif

#ifdef USARTC1_CTRLB
    DEFINE(USARTC1_CTRLB)
#else
    MISSING(USARTC1_CTRLB)
#endif

#ifdef USARTC1_CTRLC
    DEFINE(USARTC1_CTRLC)
#else
    MISSING(USARTC1_CTRLC)
#endif

#ifdef USARTC1_DATA
    DEFINE(USARTC1_DATA)
#else
    MISSING(USARTC1_DATA)
#endif

#ifdef USARTC1_STATUS
    DEFINE(USARTC1_STATUS)
#else
    MISSING(USARTC1_STATUS)
#endif

#ifdef USARTD0_BAUDCTRLA
    DEFINE(USARTD0_BAUDCTRLA)
#else
    MISSING(USARTD0_BAUDCTRLA)
#endif

#ifdef USARTD0_BAUDCTRLB
    DEFINE(USARTD0_BAUDCTRLB)
#else
    MISSING(USARTD0_BAUDCTRLB)
#endif

#ifdef USARTD0_CTRLA
    DEFINE(USARTD0_CTRLA)
#else
    MISSING(USARTD0_CTRLA)
#endif

#ifdef USARTD0_CTRLB
    DEFINE(USARTD0_CTRLB)
#else
    MISSING(USARTD0_CTRLB)
#endif

#ifdef USARTD0_CTRLC
    DEFINE(USARTD0_CTRLC)
#else
    MISSING(USARTD0_CTRLC)
#endif

#ifdef USARTD0_DATA
    DEFINE(USARTD0_DATA)
#else
    MISSING(USARTD0_DATA)
#endif

#ifdef USARTD0_STATUS
    DEFINE(USARTD0_STATUS)
#else
    MISSING(USARTD0_STATUS)
#endif

#ifdef USARTD1_BAUDCTRLA
    DEFINE(USARTD1_BAUDCTRLA)
#else
    MISSING(USARTD1_BAUDCTRLA)
#endif

#ifdef USARTD1_BAUDCTRLB
    DEFINE(USARTD1_BAUDCTRLB)
#else
    MISSING(USARTD1_BAUDCTRLB)
#endif

#ifdef USARTD1_CTRLA
    DEFINE(USARTD1_CTRLA)
#else
    MISSING(USARTD1_CTRLA)
#endif

#ifdef USARTD1_CTRLB
    DEFINE(USARTD1_CTRLB)
#else
    MISSING(USARTD1_CTRLB)
#endif

#ifdef USARTD1_CTRLC
    DEFINE(USARTD1_CTRLC)
#else
    MISSING(USARTD1_CTRLC)
#endif

#ifdef USARTD1_DATA
    DEFINE(USARTD1_DATA)
#else
    MISSING(USARTD1_DATA)
#endif

#ifdef USARTD1_STATUS
    DEFINE(USARTD1_STATUS)
#else
    MISSING(USARTD1_STATUS)
#endif

#ifdef USARTE0_BAUDCTRLA
    DEFINE(USARTE0_BAUDCTRLA)
#else
    MISSING(USARTE0_BAUDCTRLA)
#endif

#ifdef USARTE0_BAUDCTRLB
    DEFINE(USARTE0_BAUDCTRLB)
#else
    MISSING(USARTE0_BAUDCTRLB)
#endif

#ifdef USARTE0_CTRLA
    DEFINE(USARTE0_CTRLA)
#else
    MISSING(USARTE0_CTRLA)
#endif

#ifdef USARTE0_CTRLB
    DEFINE(USARTE0_CTRLB)
#else
    MISSING(USARTE0_CTRLB)
#endif

#ifdef USARTE0_CTRLC
    DEFINE(USARTE0_CTRLC)
#else
    MISSING(USARTE0_CTRLC)
#endif

#ifdef USARTE0_DATA
    DEFINE(USARTE0_DATA)
#else
    MISSING(USARTE0_DATA)
#endif

#ifdef USARTE0_STATUS
    DEFINE(USARTE0_STATUS)
#else
    MISSING(USARTE0_STATUS)
#endif

#ifdef USARTE1_BAUDCTRLA
    DEFINE(USARTE1_BAUDCTRLA)
#else
    MISSING(USARTE1_BAUDCTRLA)
#endif

#ifdef USARTE1_BAUDCTRLB
    DEFINE(USARTE1_BAUDCTRLB)
#else
    MISSING(USARTE1_BAUDCTRLB)
#endif

#ifdef USARTE1_CTRLA
    DEFINE(USARTE1_CTRLA)
#else
    MISSING(USARTE1_CTRLA)
#endif

#ifdef USARTE1_CTRLB
    DEFINE(USARTE1_CTRLB)
#else
    MISSING(USARTE1_CTRLB)
#endif

#ifdef USARTE1_CTRLC
    DEFINE(USARTE1_CTRLC)
#else
    MISSING(USARTE1_CTRLC)
#endif

#ifdef USARTE1_DATA
    DEFINE(USARTE1_DATA)
#else
    MISSING(USARTE1_DATA)
#endif

#ifdef USARTE1_STATUS
    DEFINE(USARTE1_STATUS)
#else
    MISSING(USARTE1_STATUS)
#endif

#ifdef USARTF0_BAUDCTRLA
    DEFINE(USARTF0_BAUDCTRLA)
#else
    MISSING(USARTF0_BAUDCTRLA)
#endif

#ifdef USARTF0_BAUDCTRLB
    DEFINE(USARTF0_BAUDCTRLB)
#else
    MISSING(USARTF0_BAUDCTRLB)
#endif

#ifdef USARTF0_CTRLA
    DEFINE(USARTF0_CTRLA)
#else
    MISSING(USARTF0_CTRLA)
#endif

#ifdef USARTF0_CTRLB
    DEFINE(USARTF0_CTRLB)
#else
    MISSING(USARTF0_CTRLB)
#endif

#ifdef USARTF0_CTRLC
    DEFINE(USARTF0_CTRLC)
#else
    MISSING(USARTF0_CTRLC)
#endif

#ifdef USARTF0_DATA
    DEFINE(USARTF0_DATA)
#else
    MISSING(USARTF0_DATA)
#endif

#ifdef USARTF0_STATUS
    DEFINE(USARTF0_STATUS)
#else
    MISSING(USARTF0_STATUS)
#endif

#ifdef USARTF1_BAUDCTRLA
    DEFINE(USARTF1_BAUDCTRLA)
#else
    MISSING(USARTF1_BAUDCTRLA)
#endif

#ifdef USARTF1_BAUDCTRLB
    DEFINE(USARTF1_BAUDCTRLB)
#else
    MISSING(USARTF1_BAUDCTRLB)
#endif

#ifdef USARTF1_CTRLA
    DEFINE(USARTF1_CTRLA)
#else
    MISSING(USARTF1_CTRLA)
#endif

#ifdef USARTF1_CTRLB
    DEFINE(USARTF1_CTRLB)
#else
    MISSING(USARTF1_CTRLB)
#endif

#ifdef USARTF1_CTRLC
    DEFINE(USARTF1_CTRLC)
#else
    MISSING(USARTF1_CTRLC)
#endif

#ifdef USARTF1_DATA
    DEFINE(USARTF1_DATA)
#else
    MISSING(USARTF1_DATA)
#endif

#ifdef USARTF1_STATUS
    DEFINE(USARTF1_STATUS)
#else
    MISSING(USARTF1_STATUS)
#endif

#ifdef USBCON
    DEFINE(USBCON)
#else
    MISSING(USBCON)
#endif

#ifdef USBCR
    DEFINE(USBCR)
#else
    MISSING(USBCR)
#endif

#ifdef USBCSEX
    DEFINE(USBCSEX)
#else
    MISSING(USBCSEX)
#endif

#ifdef USBDBCEX
    DEFINE(USBDBCEX)
#else
    MISSING(USBDBCEX)
#endif

#ifdef USBDMAB
    DEFINE(USBDMAB)
#else
    MISSING(USBDMAB)
#endif

#ifdef USBDMACS
    DEFINE(USBDMACS)
#else
    MISSING(USBDMACS)
#endif

#ifdef USBDMAD
    DEFINE(USBDMAD)
#else
    MISSING(USBDMAD)
#endif

#ifdef USBDMADH
    DEFINE(USBDMADH)
#else
    MISSING(USBDMADH)
#endif

#ifdef USBDMADL
    DEFINE(USBDMADL)
#else
    MISSING(USBDMADL)
#endif

#ifdef USBEI
    DEFINE(USBEI)
#else
    MISSING(USBEI)
#endif

#ifdef USBEIM
    DEFINE(USBEIM)
#else
    MISSING(USBEIM)
#endif

#ifdef USBENUM
    DEFINE(USBENUM)
#else
    MISSING(USBENUM)
#endif

#ifdef USBFA
    DEFINE(USBFA)
#else
    MISSING(USBFA)
#endif

#ifdef USBFCEX
    DEFINE(USBFCEX)
#else
    MISSING(USBFCEX)
#endif

#ifdef USBFN
    DEFINE(USBFN)
#else
    MISSING(USBFN)
#endif

#ifdef USBFNH
    DEFINE(USBFNH)
#else
    MISSING(USBFNH)
#endif

#ifdef USBFNL
    DEFINE(USBFNL)
#else
    MISSING(USBFNL)
#endif

#ifdef USBGS
    DEFINE(USBGS)
#else
    MISSING(USBGS)
#endif

#ifdef USBINT
    DEFINE(USBINT)
#else
    MISSING(USBINT)
#endif

#ifdef USBPI
    DEFINE(USBPI)
#else
    MISSING(USBPI)
#endif

#ifdef USBPIM
    DEFINE(USBPIM)
#else
    MISSING(USBPIM)
#endif

#ifdef USBRSTE
    DEFINE(USBRSTE)
#else
    MISSING(USBRSTE)
#endif

#ifdef USBSTA
    DEFINE(USBSTA)
#else
    MISSING(USBSTA)
#endif

#ifdef USB_ADDR
    DEFINE(USB_ADDR)
#else
    MISSING(USB_ADDR)
#endif

#ifdef USB_CAL0
    DEFINE(USB_CAL0)
#else
    MISSING(USB_CAL0)
#endif

#ifdef USB_CAL1
    DEFINE(USB_CAL1)
#else
    MISSING(USB_CAL1)
#endif

#ifdef USB_CTRLA
    DEFINE(USB_CTRLA)
#else
    MISSING(USB_CTRLA)
#endif

#ifdef USB_CTRLB
    DEFINE(USB_CTRLB)
#else
    MISSING(USB_CTRLB)
#endif

#ifdef USB_EPPTR
    DEFINE(USB_EPPTR)
#else
    MISSING(USB_EPPTR)
#endif

#ifdef USB_EP_TABLE_EP0IN_AUXDATAH
    DEFINE(USB_EP_TABLE_EP0IN_AUXDATAH)
#else
    MISSING(USB_EP_TABLE_EP0IN_AUXDATAH)
#endif

#ifdef USB_EP_TABLE_EP0IN_AUXDATAL
    DEFINE(USB_EP_TABLE_EP0IN_AUXDATAL)
#else
    MISSING(USB_EP_TABLE_EP0IN_AUXDATAL)
#endif

#ifdef USB_EP_TABLE_EP0IN_CNTH
    DEFINE(USB_EP_TABLE_EP0IN_CNTH)
#else
    MISSING(USB_EP_TABLE_EP0IN_CNTH)
#endif

#ifdef USB_EP_TABLE_EP0IN_CNTL
    DEFINE(USB_EP_TABLE_EP0IN_CNTL)
#else
    MISSING(USB_EP_TABLE_EP0IN_CNTL)
#endif

#ifdef USB_EP_TABLE_EP0IN_CTRL
    DEFINE(USB_EP_TABLE_EP0IN_CTRL)
#else
    MISSING(USB_EP_TABLE_EP0IN_CTRL)
#endif

#ifdef USB_EP_TABLE_EP0IN_DATAPTRH
    DEFINE(USB_EP_TABLE_EP0IN_DATAPTRH)
#else
    MISSING(USB_EP_TABLE_EP0IN_DATAPTRH)
#endif

#ifdef USB_EP_TABLE_EP0IN_DATAPTRL
    DEFINE(USB_EP_TABLE_EP0IN_DATAPTRL)
#else
    MISSING(USB_EP_TABLE_EP0IN_DATAPTRL)
#endif

#ifdef USB_EP_TABLE_EP0IN_STATUS
    DEFINE(USB_EP_TABLE_EP0IN_STATUS)
#else
    MISSING(USB_EP_TABLE_EP0IN_STATUS)
#endif

#ifdef USB_EP_TABLE_EP0OUT_AUXDATAH
    DEFINE(USB_EP_TABLE_EP0OUT_AUXDATAH)
#else
    MISSING(USB_EP_TABLE_EP0OUT_AUXDATAH)
#endif

#ifdef USB_EP_TABLE_EP0OUT_AUXDATAL
    DEFINE(USB_EP_TABLE_EP0OUT_AUXDATAL)
#else
    MISSING(USB_EP_TABLE_EP0OUT_AUXDATAL)
#endif

#ifdef USB_EP_TABLE_EP0OUT_CNTH
    DEFINE(USB_EP_TABLE_EP0OUT_CNTH)
#else
    MISSING(USB_EP_TABLE_EP0OUT_CNTH)
#endif

#ifdef USB_EP_TABLE_EP0OUT_CNTL
    DEFINE(USB_EP_TABLE_EP0OUT_CNTL)
#else
    MISSING(USB_EP_TABLE_EP0OUT_CNTL)
#endif

#ifdef USB_EP_TABLE_EP0OUT_CTRL
    DEFINE(USB_EP_TABLE_EP0OUT_CTRL)
#else
    MISSING(USB_EP_TABLE_EP0OUT_CTRL)
#endif

#ifdef USB_EP_TABLE_EP0OUT_DATAPTRH
    DEFINE(USB_EP_TABLE_EP0OUT_DATAPTRH)
#else
    MISSING(USB_EP_TABLE_EP0OUT_DATAPTRH)
#endif

#ifdef USB_EP_TABLE_EP0OUT_DATAPTRL
    DEFINE(USB_EP_TABLE_EP0OUT_DATAPTRL)
#else
    MISSING(USB_EP_TABLE_EP0OUT_DATAPTRL)
#endif

#ifdef USB_EP_TABLE_EP0OUT_STATUS
    DEFINE(USB_EP_TABLE_EP0OUT_STATUS)
#else
    MISSING(USB_EP_TABLE_EP0OUT_STATUS)
#endif

#ifdef USB_EP_TABLE_EP10IN_AUXDATAH
    DEFINE(USB_EP_TABLE_EP10IN_AUXDATAH)
#else
    MISSING(USB_EP_TABLE_EP10IN_AUXDATAH)
#endif

#ifdef USB_EP_TABLE_EP10IN_AUXDATAL
    DEFINE(USB_EP_TABLE_EP10IN_AUXDATAL)
#else
    MISSING(USB_EP_TABLE_EP10IN_AUXDATAL)
#endif

#ifdef USB_EP_TABLE_EP10IN_CNTH
    DEFINE(USB_EP_TABLE_EP10IN_CNTH)
#else
    MISSING(USB_EP_TABLE_EP10IN_CNTH)
#endif

#ifdef USB_EP_TABLE_EP10IN_CNTL
    DEFINE(USB_EP_TABLE_EP10IN_CNTL)
#else
    MISSING(USB_EP_TABLE_EP10IN_CNTL)
#endif

#ifdef USB_EP_TABLE_EP10IN_CTRL
    DEFINE(USB_EP_TABLE_EP10IN_CTRL)
#else
    MISSING(USB_EP_TABLE_EP10IN_CTRL)
#endif

#ifdef USB_EP_TABLE_EP10IN_DATAPTRH
    DEFINE(USB_EP_TABLE_EP10IN_DATAPTRH)
#else
    MISSING(USB_EP_TABLE_EP10IN_DATAPTRH)
#endif

#ifdef USB_EP_TABLE_EP10IN_DATAPTRL
    DEFINE(USB_EP_TABLE_EP10IN_DATAPTRL)
#else
    MISSING(USB_EP_TABLE_EP10IN_DATAPTRL)
#endif

#ifdef USB_EP_TABLE_EP10IN_STATUS
    DEFINE(USB_EP_TABLE_EP10IN_STATUS)
#else
    MISSING(USB_EP_TABLE_EP10IN_STATUS)
#endif

#ifdef USB_EP_TABLE_EP10OUT_AUXDATAH
    DEFINE(USB_EP_TABLE_EP10OUT_AUXDATAH)
#else
    MISSING(USB_EP_TABLE_EP10OUT_AUXDATAH)
#endif

#ifdef USB_EP_TABLE_EP10OUT_AUXDATAL
    DEFINE(USB_EP_TABLE_EP10OUT_AUXDATAL)
#else
    MISSING(USB_EP_TABLE_EP10OUT_AUXDATAL)
#endif

#ifdef USB_EP_TABLE_EP10OUT_CNTH
    DEFINE(USB_EP_TABLE_EP10OUT_CNTH)
#else
    MISSING(USB_EP_TABLE_EP10OUT_CNTH)
#endif

#ifdef USB_EP_TABLE_EP10OUT_CNTL
    DEFINE(USB_EP_TABLE_EP10OUT_CNTL)
#else
    MISSING(USB_EP_TABLE_EP10OUT_CNTL)
#endif

#ifdef USB_EP_TABLE_EP10OUT_CTRL
    DEFINE(USB_EP_TABLE_EP10OUT_CTRL)
#else
    MISSING(USB_EP_TABLE_EP10OUT_CTRL)
#endif

#ifdef USB_EP_TABLE_EP10OUT_DATAPTRH
    DEFINE(USB_EP_TABLE_EP10OUT_DATAPTRH)
#else
    MISSING(USB_EP_TABLE_EP10OUT_DATAPTRH)
#endif

#ifdef USB_EP_TABLE_EP10OUT_DATAPTRL
    DEFINE(USB_EP_TABLE_EP10OUT_DATAPTRL)
#else
    MISSING(USB_EP_TABLE_EP10OUT_DATAPTRL)
#endif

#ifdef USB_EP_TABLE_EP10OUT_STATUS
    DEFINE(USB_EP_TABLE_EP10OUT_STATUS)
#else
    MISSING(USB_EP_TABLE_EP10OUT_STATUS)
#endif

#ifdef USB_EP_TABLE_EP11IN_AUXDATAH
    DEFINE(USB_EP_TABLE_EP11IN_AUXDATAH)
#else
    MISSING(USB_EP_TABLE_EP11IN_AUXDATAH)
#endif

#ifdef USB_EP_TABLE_EP11IN_AUXDATAL
    DEFINE(USB_EP_TABLE_EP11IN_AUXDATAL)
#else
    MISSING(USB_EP_TABLE_EP11IN_AUXDATAL)
#endif

#ifdef USB_EP_TABLE_EP11IN_CNTH
    DEFINE(USB_EP_TABLE_EP11IN_CNTH)
#else
    MISSING(USB_EP_TABLE_EP11IN_CNTH)
#endif

#ifdef USB_EP_TABLE_EP11IN_CNTL
    DEFINE(USB_EP_TABLE_EP11IN_CNTL)
#else
    MISSING(USB_EP_TABLE_EP11IN_CNTL)
#endif

#ifdef USB_EP_TABLE_EP11IN_CTRL
    DEFINE(USB_EP_TABLE_EP11IN_CTRL)
#else
    MISSING(USB_EP_TABLE_EP11IN_CTRL)
#endif

#ifdef USB_EP_TABLE_EP11IN_DATAPTRH
    DEFINE(USB_EP_TABLE_EP11IN_DATAPTRH)
#else
    MISSING(USB_EP_TABLE_EP11IN_DATAPTRH)
#endif

#ifdef USB_EP_TABLE_EP11IN_DATAPTRL
    DEFINE(USB_EP_TABLE_EP11IN_DATAPTRL)
#else
    MISSING(USB_EP_TABLE_EP11IN_DATAPTRL)
#endif

#ifdef USB_EP_TABLE_EP11IN_STATUS
    DEFINE(USB_EP_TABLE_EP11IN_STATUS)
#else
    MISSING(USB_EP_TABLE_EP11IN_STATUS)
#endif

#ifdef USB_EP_TABLE_EP11OUT_AUXDATAH
    DEFINE(USB_EP_TABLE_EP11OUT_AUXDATAH)
#else
    MISSING(USB_EP_TABLE_EP11OUT_AUXDATAH)
#endif

#ifdef USB_EP_TABLE_EP11OUT_AUXDATAL
    DEFINE(USB_EP_TABLE_EP11OUT_AUXDATAL)
#else
    MISSING(USB_EP_TABLE_EP11OUT_AUXDATAL)
#endif

#ifdef USB_EP_TABLE_EP11OUT_CNTH
    DEFINE(USB_EP_TABLE_EP11OUT_CNTH)
#else
    MISSING(USB_EP_TABLE_EP11OUT_CNTH)
#endif

#ifdef USB_EP_TABLE_EP11OUT_CNTL
    DEFINE(USB_EP_TABLE_EP11OUT_CNTL)
#else
    MISSING(USB_EP_TABLE_EP11OUT_CNTL)
#endif

#ifdef USB_EP_TABLE_EP11OUT_CTRL
    DEFINE(USB_EP_TABLE_EP11OUT_CTRL)
#else
    MISSING(USB_EP_TABLE_EP11OUT_CTRL)
#endif

#ifdef USB_EP_TABLE_EP11OUT_DATAPTRH
    DEFINE(USB_EP_TABLE_EP11OUT_DATAPTRH)
#else
    MISSING(USB_EP_TABLE_EP11OUT_DATAPTRH)
#endif

#ifdef USB_EP_TABLE_EP11OUT_DATAPTRL
    DEFINE(USB_EP_TABLE_EP11OUT_DATAPTRL)
#else
    MISSING(USB_EP_TABLE_EP11OUT_DATAPTRL)
#endif

#ifdef USB_EP_TABLE_EP11OUT_STATUS
    DEFINE(USB_EP_TABLE_EP11OUT_STATUS)
#else
    MISSING(USB_EP_TABLE_EP11OUT_STATUS)
#endif

#ifdef USB_EP_TABLE_EP12IN_AUXDATAH
    DEFINE(USB_EP_TABLE_EP12IN_AUXDATAH)
#else
    MISSING(USB_EP_TABLE_EP12IN_AUXDATAH)
#endif

#ifdef USB_EP_TABLE_EP12IN_AUXDATAL
    DEFINE(USB_EP_TABLE_EP12IN_AUXDATAL)
#else
    MISSING(USB_EP_TABLE_EP12IN_AUXDATAL)
#endif

#ifdef USB_EP_TABLE_EP12IN_CNTH
    DEFINE(USB_EP_TABLE_EP12IN_CNTH)
#else
    MISSING(USB_EP_TABLE_EP12IN_CNTH)
#endif

#ifdef USB_EP_TABLE_EP12IN_CNTL
    DEFINE(USB_EP_TABLE_EP12IN_CNTL)
#else
    MISSING(USB_EP_TABLE_EP12IN_CNTL)
#endif

#ifdef USB_EP_TABLE_EP12IN_CTRL
    DEFINE(USB_EP_TABLE_EP12IN_CTRL)
#else
    MISSING(USB_EP_TABLE_EP12IN_CTRL)
#endif

#ifdef USB_EP_TABLE_EP12IN_DATAPTRH
    DEFINE(USB_EP_TABLE_EP12IN_DATAPTRH)
#else
    MISSING(USB_EP_TABLE_EP12IN_DATAPTRH)
#endif

#ifdef USB_EP_TABLE_EP12IN_DATAPTRL
    DEFINE(USB_EP_TABLE_EP12IN_DATAPTRL)
#else
    MISSING(USB_EP_TABLE_EP12IN_DATAPTRL)
#endif

#ifdef USB_EP_TABLE_EP12IN_STATUS
    DEFINE(USB_EP_TABLE_EP12IN_STATUS)
#else
    MISSING(USB_EP_TABLE_EP12IN_STATUS)
#endif

#ifdef USB_EP_TABLE_EP12OUT_AUXDATAH
    DEFINE(USB_EP_TABLE_EP12OUT_AUXDATAH)
#else
    MISSING(USB_EP_TABLE_EP12OUT_AUXDATAH)
#endif

#ifdef USB_EP_TABLE_EP12OUT_AUXDATAL
    DEFINE(USB_EP_TABLE_EP12OUT_AUXDATAL)
#else
    MISSING(USB_EP_TABLE_EP12OUT_AUXDATAL)
#endif

#ifdef USB_EP_TABLE_EP12OUT_CNTH
    DEFINE(USB_EP_TABLE_EP12OUT_CNTH)
#else
    MISSING(USB_EP_TABLE_EP12OUT_CNTH)
#endif

#ifdef USB_EP_TABLE_EP12OUT_CNTL
    DEFINE(USB_EP_TABLE_EP12OUT_CNTL)
#else
    MISSING(USB_EP_TABLE_EP12OUT_CNTL)
#endif

#ifdef USB_EP_TABLE_EP12OUT_CTRL
    DEFINE(USB_EP_TABLE_EP12OUT_CTRL)
#else
    MISSING(USB_EP_TABLE_EP12OUT_CTRL)
#endif

#ifdef USB_EP_TABLE_EP12OUT_DATAPTRH
    DEFINE(USB_EP_TABLE_EP12OUT_DATAPTRH)
#else
    MISSING(USB_EP_TABLE_EP12OUT_DATAPTRH)
#endif

#ifdef USB_EP_TABLE_EP12OUT_DATAPTRL
    DEFINE(USB_EP_TABLE_EP12OUT_DATAPTRL)
#else
    MISSING(USB_EP_TABLE_EP12OUT_DATAPTRL)
#endif

#ifdef USB_EP_TABLE_EP12OUT_STATUS
    DEFINE(USB_EP_TABLE_EP12OUT_STATUS)
#else
    MISSING(USB_EP_TABLE_EP12OUT_STATUS)
#endif

#ifdef USB_EP_TABLE_EP13IN_AUXDATAH
    DEFINE(USB_EP_TABLE_EP13IN_AUXDATAH)
#else
    MISSING(USB_EP_TABLE_EP13IN_AUXDATAH)
#endif

#ifdef USB_EP_TABLE_EP13IN_AUXDATAL
    DEFINE(USB_EP_TABLE_EP13IN_AUXDATAL)
#else
    MISSING(USB_EP_TABLE_EP13IN_AUXDATAL)
#endif

#ifdef USB_EP_TABLE_EP13IN_CNTH
    DEFINE(USB_EP_TABLE_EP13IN_CNTH)
#else
    MISSING(USB_EP_TABLE_EP13IN_CNTH)
#endif

#ifdef USB_EP_TABLE_EP13IN_CNTL
    DEFINE(USB_EP_TABLE_EP13IN_CNTL)
#else
    MISSING(USB_EP_TABLE_EP13IN_CNTL)
#endif

#ifdef USB_EP_TABLE_EP13IN_CTRL
    DEFINE(USB_EP_TABLE_EP13IN_CTRL)
#else
    MISSING(USB_EP_TABLE_EP13IN_CTRL)
#endif

#ifdef USB_EP_TABLE_EP13IN_DATAPTRH
    DEFINE(USB_EP_TABLE_EP13IN_DATAPTRH)
#else
    MISSING(USB_EP_TABLE_EP13IN_DATAPTRH)
#endif

#ifdef USB_EP_TABLE_EP13IN_DATAPTRL
    DEFINE(USB_EP_TABLE_EP13IN_DATAPTRL)
#else
    MISSING(USB_EP_TABLE_EP13IN_DATAPTRL)
#endif

#ifdef USB_EP_TABLE_EP13IN_STATUS
    DEFINE(USB_EP_TABLE_EP13IN_STATUS)
#else
    MISSING(USB_EP_TABLE_EP13IN_STATUS)
#endif

#ifdef USB_EP_TABLE_EP13OUT_AUXDATAH
    DEFINE(USB_EP_TABLE_EP13OUT_AUXDATAH)
#else
    MISSING(USB_EP_TABLE_EP13OUT_AUXDATAH)
#endif

#ifdef USB_EP_TABLE_EP13OUT_AUXDATAL
    DEFINE(USB_EP_TABLE_EP13OUT_AUXDATAL)
#else
    MISSING(USB_EP_TABLE_EP13OUT_AUXDATAL)
#endif

#ifdef USB_EP_TABLE_EP13OUT_CNTH
    DEFINE(USB_EP_TABLE_EP13OUT_CNTH)
#else
    MISSING(USB_EP_TABLE_EP13OUT_CNTH)
#endif

#ifdef USB_EP_TABLE_EP13OUT_CNTL
    DEFINE(USB_EP_TABLE_EP13OUT_CNTL)
#else
    MISSING(USB_EP_TABLE_EP13OUT_CNTL)
#endif

#ifdef USB_EP_TABLE_EP13OUT_CTRL
    DEFINE(USB_EP_TABLE_EP13OUT_CTRL)
#else
    MISSING(USB_EP_TABLE_EP13OUT_CTRL)
#endif

#ifdef USB_EP_TABLE_EP13OUT_DATAPTRH
    DEFINE(USB_EP_TABLE_EP13OUT_DATAPTRH)
#else
    MISSING(USB_EP_TABLE_EP13OUT_DATAPTRH)
#endif

#ifdef USB_EP_TABLE_EP13OUT_DATAPTRL
    DEFINE(USB_EP_TABLE_EP13OUT_DATAPTRL)
#else
    MISSING(USB_EP_TABLE_EP13OUT_DATAPTRL)
#endif

#ifdef USB_EP_TABLE_EP13OUT_STATUS
    DEFINE(USB_EP_TABLE_EP13OUT_STATUS)
#else
    MISSING(USB_EP_TABLE_EP13OUT_STATUS)
#endif

#ifdef USB_EP_TABLE_EP14IN_AUXDATAH
    DEFINE(USB_EP_TABLE_EP14IN_AUXDATAH)
#else
    MISSING(USB_EP_TABLE_EP14IN_AUXDATAH)
#endif

#ifdef USB_EP_TABLE_EP14IN_AUXDATAL
    DEFINE(USB_EP_TABLE_EP14IN_AUXDATAL)
#else
    MISSING(USB_EP_TABLE_EP14IN_AUXDATAL)
#endif

#ifdef USB_EP_TABLE_EP14IN_CNTH
    DEFINE(USB_EP_TABLE_EP14IN_CNTH)
#else
    MISSING(USB_EP_TABLE_EP14IN_CNTH)
#endif

#ifdef USB_EP_TABLE_EP14IN_CNTL
    DEFINE(USB_EP_TABLE_EP14IN_CNTL)
#else
    MISSING(USB_EP_TABLE_EP14IN_CNTL)
#endif

#ifdef USB_EP_TABLE_EP14IN_CTRL
    DEFINE(USB_EP_TABLE_EP14IN_CTRL)
#else
    MISSING(USB_EP_TABLE_EP14IN_CTRL)
#endif

#ifdef USB_EP_TABLE_EP14IN_DATAPTRH
    DEFINE(USB_EP_TABLE_EP14IN_DATAPTRH)
#else
    MISSING(USB_EP_TABLE_EP14IN_DATAPTRH)
#endif

#ifdef USB_EP_TABLE_EP14IN_DATAPTRL
    DEFINE(USB_EP_TABLE_EP14IN_DATAPTRL)
#else
    MISSING(USB_EP_TABLE_EP14IN_DATAPTRL)
#endif

#ifdef USB_EP_TABLE_EP14IN_STATUS
    DEFINE(USB_EP_TABLE_EP14IN_STATUS)
#else
    MISSING(USB_EP_TABLE_EP14IN_STATUS)
#endif

#ifdef USB_EP_TABLE_EP14OUT_AUXDATAH
    DEFINE(USB_EP_TABLE_EP14OUT_AUXDATAH)
#else
    MISSING(USB_EP_TABLE_EP14OUT_AUXDATAH)
#endif

#ifdef USB_EP_TABLE_EP14OUT_AUXDATAL
    DEFINE(USB_EP_TABLE_EP14OUT_AUXDATAL)
#else
    MISSING(USB_EP_TABLE_EP14OUT_AUXDATAL)
#endif

#ifdef USB_EP_TABLE_EP14OUT_CNTH
    DEFINE(USB_EP_TABLE_EP14OUT_CNTH)
#else
    MISSING(USB_EP_TABLE_EP14OUT_CNTH)
#endif

#ifdef USB_EP_TABLE_EP14OUT_CNTL
    DEFINE(USB_EP_TABLE_EP14OUT_CNTL)
#else
    MISSING(USB_EP_TABLE_EP14OUT_CNTL)
#endif

#ifdef USB_EP_TABLE_EP14OUT_CTRL
    DEFINE(USB_EP_TABLE_EP14OUT_CTRL)
#else
    MISSING(USB_EP_TABLE_EP14OUT_CTRL)
#endif

#ifdef USB_EP_TABLE_EP14OUT_DATAPTRH
    DEFINE(USB_EP_TABLE_EP14OUT_DATAPTRH)
#else
    MISSING(USB_EP_TABLE_EP14OUT_DATAPTRH)
#endif

#ifdef USB_EP_TABLE_EP14OUT_DATAPTRL
    DEFINE(USB_EP_TABLE_EP14OUT_DATAPTRL)
#else
    MISSING(USB_EP_TABLE_EP14OUT_DATAPTRL)
#endif

#ifdef USB_EP_TABLE_EP14OUT_STATUS
    DEFINE(USB_EP_TABLE_EP14OUT_STATUS)
#else
    MISSING(USB_EP_TABLE_EP14OUT_STATUS)
#endif

#ifdef USB_EP_TABLE_EP15IN_AUXDATAH
    DEFINE(USB_EP_TABLE_EP15IN_AUXDATAH)
#else
    MISSING(USB_EP_TABLE_EP15IN_AUXDATAH)
#endif

#ifdef USB_EP_TABLE_EP15IN_AUXDATAL
    DEFINE(USB_EP_TABLE_EP15IN_AUXDATAL)
#else
    MISSING(USB_EP_TABLE_EP15IN_AUXDATAL)
#endif

#ifdef USB_EP_TABLE_EP15IN_CNTH
    DEFINE(USB_EP_TABLE_EP15IN_CNTH)
#else
    MISSING(USB_EP_TABLE_EP15IN_CNTH)
#endif

#ifdef USB_EP_TABLE_EP15IN_CNTL
    DEFINE(USB_EP_TABLE_EP15IN_CNTL)
#else
    MISSING(USB_EP_TABLE_EP15IN_CNTL)
#endif

#ifdef USB_EP_TABLE_EP15IN_CTRL
    DEFINE(USB_EP_TABLE_EP15IN_CTRL)
#else
    MISSING(USB_EP_TABLE_EP15IN_CTRL)
#endif

#ifdef USB_EP_TABLE_EP15IN_DATAPTRH
    DEFINE(USB_EP_TABLE_EP15IN_DATAPTRH)
#else
    MISSING(USB_EP_TABLE_EP15IN_DATAPTRH)
#endif

#ifdef USB_EP_TABLE_EP15IN_DATAPTRL
    DEFINE(USB_EP_TABLE_EP15IN_DATAPTRL)
#else
    MISSING(USB_EP_TABLE_EP15IN_DATAPTRL)
#endif

#ifdef USB_EP_TABLE_EP15IN_STATUS
    DEFINE(USB_EP_TABLE_EP15IN_STATUS)
#else
    MISSING(USB_EP_TABLE_EP15IN_STATUS)
#endif

#ifdef USB_EP_TABLE_EP15OUT_AUXDATAH
    DEFINE(USB_EP_TABLE_EP15OUT_AUXDATAH)
#else
    MISSING(USB_EP_TABLE_EP15OUT_AUXDATAH)
#endif

#ifdef USB_EP_TABLE_EP15OUT_AUXDATAL
    DEFINE(USB_EP_TABLE_EP15OUT_AUXDATAL)
#else
    MISSING(USB_EP_TABLE_EP15OUT_AUXDATAL)
#endif

#ifdef USB_EP_TABLE_EP15OUT_CNTH
    DEFINE(USB_EP_TABLE_EP15OUT_CNTH)
#else
    MISSING(USB_EP_TABLE_EP15OUT_CNTH)
#endif

#ifdef USB_EP_TABLE_EP15OUT_CNTL
    DEFINE(USB_EP_TABLE_EP15OUT_CNTL)
#else
    MISSING(USB_EP_TABLE_EP15OUT_CNTL)
#endif

#ifdef USB_EP_TABLE_EP15OUT_CTRL
    DEFINE(USB_EP_TABLE_EP15OUT_CTRL)
#else
    MISSING(USB_EP_TABLE_EP15OUT_CTRL)
#endif

#ifdef USB_EP_TABLE_EP15OUT_DATAPTRH
    DEFINE(USB_EP_TABLE_EP15OUT_DATAPTRH)
#else
    MISSING(USB_EP_TABLE_EP15OUT_DATAPTRH)
#endif

#ifdef USB_EP_TABLE_EP15OUT_DATAPTRL
    DEFINE(USB_EP_TABLE_EP15OUT_DATAPTRL)
#else
    MISSING(USB_EP_TABLE_EP15OUT_DATAPTRL)
#endif

#ifdef USB_EP_TABLE_EP15OUT_STATUS
    DEFINE(USB_EP_TABLE_EP15OUT_STATUS)
#else
    MISSING(USB_EP_TABLE_EP15OUT_STATUS)
#endif

#ifdef USB_EP_TABLE_EP1IN_AUXDATAH
    DEFINE(USB_EP_TABLE_EP1IN_AUXDATAH)
#else
    MISSING(USB_EP_TABLE_EP1IN_AUXDATAH)
#endif

#ifdef USB_EP_TABLE_EP1IN_AUXDATAL
    DEFINE(USB_EP_TABLE_EP1IN_AUXDATAL)
#else
    MISSING(USB_EP_TABLE_EP1IN_AUXDATAL)
#endif

#ifdef USB_EP_TABLE_EP1IN_CNTH
    DEFINE(USB_EP_TABLE_EP1IN_CNTH)
#else
    MISSING(USB_EP_TABLE_EP1IN_CNTH)
#endif

#ifdef USB_EP_TABLE_EP1IN_CNTL
    DEFINE(USB_EP_TABLE_EP1IN_CNTL)
#else
    MISSING(USB_EP_TABLE_EP1IN_CNTL)
#endif

#ifdef USB_EP_TABLE_EP1IN_CTRL
    DEFINE(USB_EP_TABLE_EP1IN_CTRL)
#else
    MISSING(USB_EP_TABLE_EP1IN_CTRL)
#endif

#ifdef USB_EP_TABLE_EP1IN_DATAPTRH
    DEFINE(USB_EP_TABLE_EP1IN_DATAPTRH)
#else
    MISSING(USB_EP_TABLE_EP1IN_DATAPTRH)
#endif

#ifdef USB_EP_TABLE_EP1IN_DATAPTRL
    DEFINE(USB_EP_TABLE_EP1IN_DATAPTRL)
#else
    MISSING(USB_EP_TABLE_EP1IN_DATAPTRL)
#endif

#ifdef USB_EP_TABLE_EP1IN_STATUS
    DEFINE(USB_EP_TABLE_EP1IN_STATUS)
#else
    MISSING(USB_EP_TABLE_EP1IN_STATUS)
#endif

#ifdef USB_EP_TABLE_EP1OUT_AUXDATAH
    DEFINE(USB_EP_TABLE_EP1OUT_AUXDATAH)
#else
    MISSING(USB_EP_TABLE_EP1OUT_AUXDATAH)
#endif

#ifdef USB_EP_TABLE_EP1OUT_AUXDATAL
    DEFINE(USB_EP_TABLE_EP1OUT_AUXDATAL)
#else
    MISSING(USB_EP_TABLE_EP1OUT_AUXDATAL)
#endif

#ifdef USB_EP_TABLE_EP1OUT_CNTH
    DEFINE(USB_EP_TABLE_EP1OUT_CNTH)
#else
    MISSING(USB_EP_TABLE_EP1OUT_CNTH)
#endif

#ifdef USB_EP_TABLE_EP1OUT_CNTL
    DEFINE(USB_EP_TABLE_EP1OUT_CNTL)
#else
    MISSING(USB_EP_TABLE_EP1OUT_CNTL)
#endif

#ifdef USB_EP_TABLE_EP1OUT_CTRL
    DEFINE(USB_EP_TABLE_EP1OUT_CTRL)
#else
    MISSING(USB_EP_TABLE_EP1OUT_CTRL)
#endif

#ifdef USB_EP_TABLE_EP1OUT_DATAPTRH
    DEFINE(USB_EP_TABLE_EP1OUT_DATAPTRH)
#else
    MISSING(USB_EP_TABLE_EP1OUT_DATAPTRH)
#endif

#ifdef USB_EP_TABLE_EP1OUT_DATAPTRL
    DEFINE(USB_EP_TABLE_EP1OUT_DATAPTRL)
#else
    MISSING(USB_EP_TABLE_EP1OUT_DATAPTRL)
#endif

#ifdef USB_EP_TABLE_EP1OUT_STATUS
    DEFINE(USB_EP_TABLE_EP1OUT_STATUS)
#else
    MISSING(USB_EP_TABLE_EP1OUT_STATUS)
#endif

#ifdef USB_EP_TABLE_EP2IN_AUXDATAH
    DEFINE(USB_EP_TABLE_EP2IN_AUXDATAH)
#else
    MISSING(USB_EP_TABLE_EP2IN_AUXDATAH)
#endif

#ifdef USB_EP_TABLE_EP2IN_AUXDATAL
    DEFINE(USB_EP_TABLE_EP2IN_AUXDATAL)
#else
    MISSING(USB_EP_TABLE_EP2IN_AUXDATAL)
#endif

#ifdef USB_EP_TABLE_EP2IN_CNTH
    DEFINE(USB_EP_TABLE_EP2IN_CNTH)
#else
    MISSING(USB_EP_TABLE_EP2IN_CNTH)
#endif

#ifdef USB_EP_TABLE_EP2IN_CNTL
    DEFINE(USB_EP_TABLE_EP2IN_CNTL)
#else
    MISSING(USB_EP_TABLE_EP2IN_CNTL)
#endif

#ifdef USB_EP_TABLE_EP2IN_CTRL
    DEFINE(USB_EP_TABLE_EP2IN_CTRL)
#else
    MISSING(USB_EP_TABLE_EP2IN_CTRL)
#endif

#ifdef USB_EP_TABLE_EP2IN_DATAPTRH
    DEFINE(USB_EP_TABLE_EP2IN_DATAPTRH)
#else
    MISSING(USB_EP_TABLE_EP2IN_DATAPTRH)
#endif

#ifdef USB_EP_TABLE_EP2IN_DATAPTRL
    DEFINE(USB_EP_TABLE_EP2IN_DATAPTRL)
#else
    MISSING(USB_EP_TABLE_EP2IN_DATAPTRL)
#endif

#ifdef USB_EP_TABLE_EP2IN_STATUS
    DEFINE(USB_EP_TABLE_EP2IN_STATUS)
#else
    MISSING(USB_EP_TABLE_EP2IN_STATUS)
#endif

#ifdef USB_EP_TABLE_EP2OUT_AUXDATAH
    DEFINE(USB_EP_TABLE_EP2OUT_AUXDATAH)
#else
    MISSING(USB_EP_TABLE_EP2OUT_AUXDATAH)
#endif

#ifdef USB_EP_TABLE_EP2OUT_AUXDATAL
    DEFINE(USB_EP_TABLE_EP2OUT_AUXDATAL)
#else
    MISSING(USB_EP_TABLE_EP2OUT_AUXDATAL)
#endif

#ifdef USB_EP_TABLE_EP2OUT_CNTH
    DEFINE(USB_EP_TABLE_EP2OUT_CNTH)
#else
    MISSING(USB_EP_TABLE_EP2OUT_CNTH)
#endif

#ifdef USB_EP_TABLE_EP2OUT_CNTL
    DEFINE(USB_EP_TABLE_EP2OUT_CNTL)
#else
    MISSING(USB_EP_TABLE_EP2OUT_CNTL)
#endif

#ifdef USB_EP_TABLE_EP2OUT_CTRL
    DEFINE(USB_EP_TABLE_EP2OUT_CTRL)
#else
    MISSING(USB_EP_TABLE_EP2OUT_CTRL)
#endif

#ifdef USB_EP_TABLE_EP2OUT_DATAPTRH
    DEFINE(USB_EP_TABLE_EP2OUT_DATAPTRH)
#else
    MISSING(USB_EP_TABLE_EP2OUT_DATAPTRH)
#endif

#ifdef USB_EP_TABLE_EP2OUT_DATAPTRL
    DEFINE(USB_EP_TABLE_EP2OUT_DATAPTRL)
#else
    MISSING(USB_EP_TABLE_EP2OUT_DATAPTRL)
#endif

#ifdef USB_EP_TABLE_EP2OUT_STATUS
    DEFINE(USB_EP_TABLE_EP2OUT_STATUS)
#else
    MISSING(USB_EP_TABLE_EP2OUT_STATUS)
#endif

#ifdef USB_EP_TABLE_EP3IN_AUXDATAH
    DEFINE(USB_EP_TABLE_EP3IN_AUXDATAH)
#else
    MISSING(USB_EP_TABLE_EP3IN_AUXDATAH)
#endif

#ifdef USB_EP_TABLE_EP3IN_AUXDATAL
    DEFINE(USB_EP_TABLE_EP3IN_AUXDATAL)
#else
    MISSING(USB_EP_TABLE_EP3IN_AUXDATAL)
#endif

#ifdef USB_EP_TABLE_EP3IN_CNTH
    DEFINE(USB_EP_TABLE_EP3IN_CNTH)
#else
    MISSING(USB_EP_TABLE_EP3IN_CNTH)
#endif

#ifdef USB_EP_TABLE_EP3IN_CNTL
    DEFINE(USB_EP_TABLE_EP3IN_CNTL)
#else
    MISSING(USB_EP_TABLE_EP3IN_CNTL)
#endif

#ifdef USB_EP_TABLE_EP3IN_CTRL
    DEFINE(USB_EP_TABLE_EP3IN_CTRL)
#else
    MISSING(USB_EP_TABLE_EP3IN_CTRL)
#endif

#ifdef USB_EP_TABLE_EP3IN_DATAPTRH
    DEFINE(USB_EP_TABLE_EP3IN_DATAPTRH)
#else
    MISSING(USB_EP_TABLE_EP3IN_DATAPTRH)
#endif

#ifdef USB_EP_TABLE_EP3IN_DATAPTRL
    DEFINE(USB_EP_TABLE_EP3IN_DATAPTRL)
#else
    MISSING(USB_EP_TABLE_EP3IN_DATAPTRL)
#endif

#ifdef USB_EP_TABLE_EP3IN_STATUS
    DEFINE(USB_EP_TABLE_EP3IN_STATUS)
#else
    MISSING(USB_EP_TABLE_EP3IN_STATUS)
#endif

#ifdef USB_EP_TABLE_EP3OUT_AUXDATAH
    DEFINE(USB_EP_TABLE_EP3OUT_AUXDATAH)
#else
    MISSING(USB_EP_TABLE_EP3OUT_AUXDATAH)
#endif

#ifdef USB_EP_TABLE_EP3OUT_AUXDATAL
    DEFINE(USB_EP_TABLE_EP3OUT_AUXDATAL)
#else
    MISSING(USB_EP_TABLE_EP3OUT_AUXDATAL)
#endif

#ifdef USB_EP_TABLE_EP3OUT_CNTH
    DEFINE(USB_EP_TABLE_EP3OUT_CNTH)
#else
    MISSING(USB_EP_TABLE_EP3OUT_CNTH)
#endif

#ifdef USB_EP_TABLE_EP3OUT_CNTL
    DEFINE(USB_EP_TABLE_EP3OUT_CNTL)
#else
    MISSING(USB_EP_TABLE_EP3OUT_CNTL)
#endif

#ifdef USB_EP_TABLE_EP3OUT_CTRL
    DEFINE(USB_EP_TABLE_EP3OUT_CTRL)
#else
    MISSING(USB_EP_TABLE_EP3OUT_CTRL)
#endif

#ifdef USB_EP_TABLE_EP3OUT_DATAPTRH
    DEFINE(USB_EP_TABLE_EP3OUT_DATAPTRH)
#else
    MISSING(USB_EP_TABLE_EP3OUT_DATAPTRH)
#endif

#ifdef USB_EP_TABLE_EP3OUT_DATAPTRL
    DEFINE(USB_EP_TABLE_EP3OUT_DATAPTRL)
#else
    MISSING(USB_EP_TABLE_EP3OUT_DATAPTRL)
#endif

#ifdef USB_EP_TABLE_EP3OUT_STATUS
    DEFINE(USB_EP_TABLE_EP3OUT_STATUS)
#else
    MISSING(USB_EP_TABLE_EP3OUT_STATUS)
#endif

#ifdef USB_EP_TABLE_EP4IN_AUXDATAH
    DEFINE(USB_EP_TABLE_EP4IN_AUXDATAH)
#else
    MISSING(USB_EP_TABLE_EP4IN_AUXDATAH)
#endif

#ifdef USB_EP_TABLE_EP4IN_AUXDATAL
    DEFINE(USB_EP_TABLE_EP4IN_AUXDATAL)
#else
    MISSING(USB_EP_TABLE_EP4IN_AUXDATAL)
#endif

#ifdef USB_EP_TABLE_EP4IN_CNTH
    DEFINE(USB_EP_TABLE_EP4IN_CNTH)
#else
    MISSING(USB_EP_TABLE_EP4IN_CNTH)
#endif

#ifdef USB_EP_TABLE_EP4IN_CNTL
    DEFINE(USB_EP_TABLE_EP4IN_CNTL)
#else
    MISSING(USB_EP_TABLE_EP4IN_CNTL)
#endif

#ifdef USB_EP_TABLE_EP4IN_CTRL
    DEFINE(USB_EP_TABLE_EP4IN_CTRL)
#else
    MISSING(USB_EP_TABLE_EP4IN_CTRL)
#endif

#ifdef USB_EP_TABLE_EP4IN_DATAPTRH
    DEFINE(USB_EP_TABLE_EP4IN_DATAPTRH)
#else
    MISSING(USB_EP_TABLE_EP4IN_DATAPTRH)
#endif

#ifdef USB_EP_TABLE_EP4IN_DATAPTRL
    DEFINE(USB_EP_TABLE_EP4IN_DATAPTRL)
#else
    MISSING(USB_EP_TABLE_EP4IN_DATAPTRL)
#endif

#ifdef USB_EP_TABLE_EP4IN_STATUS
    DEFINE(USB_EP_TABLE_EP4IN_STATUS)
#else
    MISSING(USB_EP_TABLE_EP4IN_STATUS)
#endif

#ifdef USB_EP_TABLE_EP4OUT_AUXDATAH
    DEFINE(USB_EP_TABLE_EP4OUT_AUXDATAH)
#else
    MISSING(USB_EP_TABLE_EP4OUT_AUXDATAH)
#endif

#ifdef USB_EP_TABLE_EP4OUT_AUXDATAL
    DEFINE(USB_EP_TABLE_EP4OUT_AUXDATAL)
#else
    MISSING(USB_EP_TABLE_EP4OUT_AUXDATAL)
#endif

#ifdef USB_EP_TABLE_EP4OUT_CNTH
    DEFINE(USB_EP_TABLE_EP4OUT_CNTH)
#else
    MISSING(USB_EP_TABLE_EP4OUT_CNTH)
#endif

#ifdef USB_EP_TABLE_EP4OUT_CNTL
    DEFINE(USB_EP_TABLE_EP4OUT_CNTL)
#else
    MISSING(USB_EP_TABLE_EP4OUT_CNTL)
#endif

#ifdef USB_EP_TABLE_EP4OUT_CTRL
    DEFINE(USB_EP_TABLE_EP4OUT_CTRL)
#else
    MISSING(USB_EP_TABLE_EP4OUT_CTRL)
#endif

#ifdef USB_EP_TABLE_EP4OUT_DATAPTRH
    DEFINE(USB_EP_TABLE_EP4OUT_DATAPTRH)
#else
    MISSING(USB_EP_TABLE_EP4OUT_DATAPTRH)
#endif

#ifdef USB_EP_TABLE_EP4OUT_DATAPTRL
    DEFINE(USB_EP_TABLE_EP4OUT_DATAPTRL)
#else
    MISSING(USB_EP_TABLE_EP4OUT_DATAPTRL)
#endif

#ifdef USB_EP_TABLE_EP4OUT_STATUS
    DEFINE(USB_EP_TABLE_EP4OUT_STATUS)
#else
    MISSING(USB_EP_TABLE_EP4OUT_STATUS)
#endif

#ifdef USB_EP_TABLE_EP5IN_AUXDATAH
    DEFINE(USB_EP_TABLE_EP5IN_AUXDATAH)
#else
    MISSING(USB_EP_TABLE_EP5IN_AUXDATAH)
#endif

#ifdef USB_EP_TABLE_EP5IN_AUXDATAL
    DEFINE(USB_EP_TABLE_EP5IN_AUXDATAL)
#else
    MISSING(USB_EP_TABLE_EP5IN_AUXDATAL)
#endif

#ifdef USB_EP_TABLE_EP5IN_CNTH
    DEFINE(USB_EP_TABLE_EP5IN_CNTH)
#else
    MISSING(USB_EP_TABLE_EP5IN_CNTH)
#endif

#ifdef USB_EP_TABLE_EP5IN_CNTL
    DEFINE(USB_EP_TABLE_EP5IN_CNTL)
#else
    MISSING(USB_EP_TABLE_EP5IN_CNTL)
#endif

#ifdef USB_EP_TABLE_EP5IN_CTRL
    DEFINE(USB_EP_TABLE_EP5IN_CTRL)
#else
    MISSING(USB_EP_TABLE_EP5IN_CTRL)
#endif

#ifdef USB_EP_TABLE_EP5IN_DATAPTRH
    DEFINE(USB_EP_TABLE_EP5IN_DATAPTRH)
#else
    MISSING(USB_EP_TABLE_EP5IN_DATAPTRH)
#endif

#ifdef USB_EP_TABLE_EP5IN_DATAPTRL
    DEFINE(USB_EP_TABLE_EP5IN_DATAPTRL)
#else
    MISSING(USB_EP_TABLE_EP5IN_DATAPTRL)
#endif

#ifdef USB_EP_TABLE_EP5IN_STATUS
    DEFINE(USB_EP_TABLE_EP5IN_STATUS)
#else
    MISSING(USB_EP_TABLE_EP5IN_STATUS)
#endif

#ifdef USB_EP_TABLE_EP5OUT_AUXDATAH
    DEFINE(USB_EP_TABLE_EP5OUT_AUXDATAH)
#else
    MISSING(USB_EP_TABLE_EP5OUT_AUXDATAH)
#endif

#ifdef USB_EP_TABLE_EP5OUT_AUXDATAL
    DEFINE(USB_EP_TABLE_EP5OUT_AUXDATAL)
#else
    MISSING(USB_EP_TABLE_EP5OUT_AUXDATAL)
#endif

#ifdef USB_EP_TABLE_EP5OUT_CNTH
    DEFINE(USB_EP_TABLE_EP5OUT_CNTH)
#else
    MISSING(USB_EP_TABLE_EP5OUT_CNTH)
#endif

#ifdef USB_EP_TABLE_EP5OUT_CNTL
    DEFINE(USB_EP_TABLE_EP5OUT_CNTL)
#else
    MISSING(USB_EP_TABLE_EP5OUT_CNTL)
#endif

#ifdef USB_EP_TABLE_EP5OUT_CTRL
    DEFINE(USB_EP_TABLE_EP5OUT_CTRL)
#else
    MISSING(USB_EP_TABLE_EP5OUT_CTRL)
#endif

#ifdef USB_EP_TABLE_EP5OUT_DATAPTRH
    DEFINE(USB_EP_TABLE_EP5OUT_DATAPTRH)
#else
    MISSING(USB_EP_TABLE_EP5OUT_DATAPTRH)
#endif

#ifdef USB_EP_TABLE_EP5OUT_DATAPTRL
    DEFINE(USB_EP_TABLE_EP5OUT_DATAPTRL)
#else
    MISSING(USB_EP_TABLE_EP5OUT_DATAPTRL)
#endif

#ifdef USB_EP_TABLE_EP5OUT_STATUS
    DEFINE(USB_EP_TABLE_EP5OUT_STATUS)
#else
    MISSING(USB_EP_TABLE_EP5OUT_STATUS)
#endif

#ifdef USB_EP_TABLE_EP6IN_AUXDATAH
    DEFINE(USB_EP_TABLE_EP6IN_AUXDATAH)
#else
    MISSING(USB_EP_TABLE_EP6IN_AUXDATAH)
#endif

#ifdef USB_EP_TABLE_EP6IN_AUXDATAL
    DEFINE(USB_EP_TABLE_EP6IN_AUXDATAL)
#else
    MISSING(USB_EP_TABLE_EP6IN_AUXDATAL)
#endif

#ifdef USB_EP_TABLE_EP6IN_CNTH
    DEFINE(USB_EP_TABLE_EP6IN_CNTH)
#else
    MISSING(USB_EP_TABLE_EP6IN_CNTH)
#endif

#ifdef USB_EP_TABLE_EP6IN_CNTL
    DEFINE(USB_EP_TABLE_EP6IN_CNTL)
#else
    MISSING(USB_EP_TABLE_EP6IN_CNTL)
#endif

#ifdef USB_EP_TABLE_EP6IN_CTRL
    DEFINE(USB_EP_TABLE_EP6IN_CTRL)
#else
    MISSING(USB_EP_TABLE_EP6IN_CTRL)
#endif

#ifdef USB_EP_TABLE_EP6IN_DATAPTRH
    DEFINE(USB_EP_TABLE_EP6IN_DATAPTRH)
#else
    MISSING(USB_EP_TABLE_EP6IN_DATAPTRH)
#endif

#ifdef USB_EP_TABLE_EP6IN_DATAPTRL
    DEFINE(USB_EP_TABLE_EP6IN_DATAPTRL)
#else
    MISSING(USB_EP_TABLE_EP6IN_DATAPTRL)
#endif

#ifdef USB_EP_TABLE_EP6IN_STATUS
    DEFINE(USB_EP_TABLE_EP6IN_STATUS)
#else
    MISSING(USB_EP_TABLE_EP6IN_STATUS)
#endif

#ifdef USB_EP_TABLE_EP6OUT_AUXDATAH
    DEFINE(USB_EP_TABLE_EP6OUT_AUXDATAH)
#else
    MISSING(USB_EP_TABLE_EP6OUT_AUXDATAH)
#endif

#ifdef USB_EP_TABLE_EP6OUT_AUXDATAL
    DEFINE(USB_EP_TABLE_EP6OUT_AUXDATAL)
#else
    MISSING(USB_EP_TABLE_EP6OUT_AUXDATAL)
#endif

#ifdef USB_EP_TABLE_EP6OUT_CNTH
    DEFINE(USB_EP_TABLE_EP6OUT_CNTH)
#else
    MISSING(USB_EP_TABLE_EP6OUT_CNTH)
#endif

#ifdef USB_EP_TABLE_EP6OUT_CNTL
    DEFINE(USB_EP_TABLE_EP6OUT_CNTL)
#else
    MISSING(USB_EP_TABLE_EP6OUT_CNTL)
#endif

#ifdef USB_EP_TABLE_EP6OUT_CTRL
    DEFINE(USB_EP_TABLE_EP6OUT_CTRL)
#else
    MISSING(USB_EP_TABLE_EP6OUT_CTRL)
#endif

#ifdef USB_EP_TABLE_EP6OUT_DATAPTRH
    DEFINE(USB_EP_TABLE_EP6OUT_DATAPTRH)
#else
    MISSING(USB_EP_TABLE_EP6OUT_DATAPTRH)
#endif

#ifdef USB_EP_TABLE_EP6OUT_DATAPTRL
    DEFINE(USB_EP_TABLE_EP6OUT_DATAPTRL)
#else
    MISSING(USB_EP_TABLE_EP6OUT_DATAPTRL)
#endif

#ifdef USB_EP_TABLE_EP6OUT_STATUS
    DEFINE(USB_EP_TABLE_EP6OUT_STATUS)
#else
    MISSING(USB_EP_TABLE_EP6OUT_STATUS)
#endif

#ifdef USB_EP_TABLE_EP7IN_AUXDATAH
    DEFINE(USB_EP_TABLE_EP7IN_AUXDATAH)
#else
    MISSING(USB_EP_TABLE_EP7IN_AUXDATAH)
#endif

#ifdef USB_EP_TABLE_EP7IN_AUXDATAL
    DEFINE(USB_EP_TABLE_EP7IN_AUXDATAL)
#else
    MISSING(USB_EP_TABLE_EP7IN_AUXDATAL)
#endif

#ifdef USB_EP_TABLE_EP7IN_CNTH
    DEFINE(USB_EP_TABLE_EP7IN_CNTH)
#else
    MISSING(USB_EP_TABLE_EP7IN_CNTH)
#endif

#ifdef USB_EP_TABLE_EP7IN_CNTL
    DEFINE(USB_EP_TABLE_EP7IN_CNTL)
#else
    MISSING(USB_EP_TABLE_EP7IN_CNTL)
#endif

#ifdef USB_EP_TABLE_EP7IN_CTRL
    DEFINE(USB_EP_TABLE_EP7IN_CTRL)
#else
    MISSING(USB_EP_TABLE_EP7IN_CTRL)
#endif

#ifdef USB_EP_TABLE_EP7IN_DATAPTRH
    DEFINE(USB_EP_TABLE_EP7IN_DATAPTRH)
#else
    MISSING(USB_EP_TABLE_EP7IN_DATAPTRH)
#endif

#ifdef USB_EP_TABLE_EP7IN_DATAPTRL
    DEFINE(USB_EP_TABLE_EP7IN_DATAPTRL)
#else
    MISSING(USB_EP_TABLE_EP7IN_DATAPTRL)
#endif

#ifdef USB_EP_TABLE_EP7IN_STATUS
    DEFINE(USB_EP_TABLE_EP7IN_STATUS)
#else
    MISSING(USB_EP_TABLE_EP7IN_STATUS)
#endif

#ifdef USB_EP_TABLE_EP7OUT_AUXDATAH
    DEFINE(USB_EP_TABLE_EP7OUT_AUXDATAH)
#else
    MISSING(USB_EP_TABLE_EP7OUT_AUXDATAH)
#endif

#ifdef USB_EP_TABLE_EP7OUT_AUXDATAL
    DEFINE(USB_EP_TABLE_EP7OUT_AUXDATAL)
#else
    MISSING(USB_EP_TABLE_EP7OUT_AUXDATAL)
#endif

#ifdef USB_EP_TABLE_EP7OUT_CNTH
    DEFINE(USB_EP_TABLE_EP7OUT_CNTH)
#else
    MISSING(USB_EP_TABLE_EP7OUT_CNTH)
#endif

#ifdef USB_EP_TABLE_EP7OUT_CNTL
    DEFINE(USB_EP_TABLE_EP7OUT_CNTL)
#else
    MISSING(USB_EP_TABLE_EP7OUT_CNTL)
#endif

#ifdef USB_EP_TABLE_EP7OUT_CTRL
    DEFINE(USB_EP_TABLE_EP7OUT_CTRL)
#else
    MISSING(USB_EP_TABLE_EP7OUT_CTRL)
#endif

#ifdef USB_EP_TABLE_EP7OUT_DATAPTRH
    DEFINE(USB_EP_TABLE_EP7OUT_DATAPTRH)
#else
    MISSING(USB_EP_TABLE_EP7OUT_DATAPTRH)
#endif

#ifdef USB_EP_TABLE_EP7OUT_DATAPTRL
    DEFINE(USB_EP_TABLE_EP7OUT_DATAPTRL)
#else
    MISSING(USB_EP_TABLE_EP7OUT_DATAPTRL)
#endif

#ifdef USB_EP_TABLE_EP7OUT_STATUS
    DEFINE(USB_EP_TABLE_EP7OUT_STATUS)
#else
    MISSING(USB_EP_TABLE_EP7OUT_STATUS)
#endif

#ifdef USB_EP_TABLE_EP8IN_AUXDATAH
    DEFINE(USB_EP_TABLE_EP8IN_AUXDATAH)
#else
    MISSING(USB_EP_TABLE_EP8IN_AUXDATAH)
#endif

#ifdef USB_EP_TABLE_EP8IN_AUXDATAL
    DEFINE(USB_EP_TABLE_EP8IN_AUXDATAL)
#else
    MISSING(USB_EP_TABLE_EP8IN_AUXDATAL)
#endif

#ifdef USB_EP_TABLE_EP8IN_CNTH
    DEFINE(USB_EP_TABLE_EP8IN_CNTH)
#else
    MISSING(USB_EP_TABLE_EP8IN_CNTH)
#endif

#ifdef USB_EP_TABLE_EP8IN_CNTL
    DEFINE(USB_EP_TABLE_EP8IN_CNTL)
#else
    MISSING(USB_EP_TABLE_EP8IN_CNTL)
#endif

#ifdef USB_EP_TABLE_EP8IN_CTRL
    DEFINE(USB_EP_TABLE_EP8IN_CTRL)
#else
    MISSING(USB_EP_TABLE_EP8IN_CTRL)
#endif

#ifdef USB_EP_TABLE_EP8IN_DATAPTRH
    DEFINE(USB_EP_TABLE_EP8IN_DATAPTRH)
#else
    MISSING(USB_EP_TABLE_EP8IN_DATAPTRH)
#endif

#ifdef USB_EP_TABLE_EP8IN_DATAPTRL
    DEFINE(USB_EP_TABLE_EP8IN_DATAPTRL)
#else
    MISSING(USB_EP_TABLE_EP8IN_DATAPTRL)
#endif

#ifdef USB_EP_TABLE_EP8IN_STATUS
    DEFINE(USB_EP_TABLE_EP8IN_STATUS)
#else
    MISSING(USB_EP_TABLE_EP8IN_STATUS)
#endif

#ifdef USB_EP_TABLE_EP8OUT_AUXDATAH
    DEFINE(USB_EP_TABLE_EP8OUT_AUXDATAH)
#else
    MISSING(USB_EP_TABLE_EP8OUT_AUXDATAH)
#endif

#ifdef USB_EP_TABLE_EP8OUT_AUXDATAL
    DEFINE(USB_EP_TABLE_EP8OUT_AUXDATAL)
#else
    MISSING(USB_EP_TABLE_EP8OUT_AUXDATAL)
#endif

#ifdef USB_EP_TABLE_EP8OUT_CNTH
    DEFINE(USB_EP_TABLE_EP8OUT_CNTH)
#else
    MISSING(USB_EP_TABLE_EP8OUT_CNTH)
#endif

#ifdef USB_EP_TABLE_EP8OUT_CNTL
    DEFINE(USB_EP_TABLE_EP8OUT_CNTL)
#else
    MISSING(USB_EP_TABLE_EP8OUT_CNTL)
#endif

#ifdef USB_EP_TABLE_EP8OUT_CTRL
    DEFINE(USB_EP_TABLE_EP8OUT_CTRL)
#else
    MISSING(USB_EP_TABLE_EP8OUT_CTRL)
#endif

#ifdef USB_EP_TABLE_EP8OUT_DATAPTRH
    DEFINE(USB_EP_TABLE_EP8OUT_DATAPTRH)
#else
    MISSING(USB_EP_TABLE_EP8OUT_DATAPTRH)
#endif

#ifdef USB_EP_TABLE_EP8OUT_DATAPTRL
    DEFINE(USB_EP_TABLE_EP8OUT_DATAPTRL)
#else
    MISSING(USB_EP_TABLE_EP8OUT_DATAPTRL)
#endif

#ifdef USB_EP_TABLE_EP8OUT_STATUS
    DEFINE(USB_EP_TABLE_EP8OUT_STATUS)
#else
    MISSING(USB_EP_TABLE_EP8OUT_STATUS)
#endif

#ifdef USB_EP_TABLE_EP9IN_AUXDATAH
    DEFINE(USB_EP_TABLE_EP9IN_AUXDATAH)
#else
    MISSING(USB_EP_TABLE_EP9IN_AUXDATAH)
#endif

#ifdef USB_EP_TABLE_EP9IN_AUXDATAL
    DEFINE(USB_EP_TABLE_EP9IN_AUXDATAL)
#else
    MISSING(USB_EP_TABLE_EP9IN_AUXDATAL)
#endif

#ifdef USB_EP_TABLE_EP9IN_CNTH
    DEFINE(USB_EP_TABLE_EP9IN_CNTH)
#else
    MISSING(USB_EP_TABLE_EP9IN_CNTH)
#endif

#ifdef USB_EP_TABLE_EP9IN_CNTL
    DEFINE(USB_EP_TABLE_EP9IN_CNTL)
#else
    MISSING(USB_EP_TABLE_EP9IN_CNTL)
#endif

#ifdef USB_EP_TABLE_EP9IN_CTRL
    DEFINE(USB_EP_TABLE_EP9IN_CTRL)
#else
    MISSING(USB_EP_TABLE_EP9IN_CTRL)
#endif

#ifdef USB_EP_TABLE_EP9IN_DATAPTRH
    DEFINE(USB_EP_TABLE_EP9IN_DATAPTRH)
#else
    MISSING(USB_EP_TABLE_EP9IN_DATAPTRH)
#endif

#ifdef USB_EP_TABLE_EP9IN_DATAPTRL
    DEFINE(USB_EP_TABLE_EP9IN_DATAPTRL)
#else
    MISSING(USB_EP_TABLE_EP9IN_DATAPTRL)
#endif

#ifdef USB_EP_TABLE_EP9IN_STATUS
    DEFINE(USB_EP_TABLE_EP9IN_STATUS)
#else
    MISSING(USB_EP_TABLE_EP9IN_STATUS)
#endif

#ifdef USB_EP_TABLE_EP9OUT_AUXDATAH
    DEFINE(USB_EP_TABLE_EP9OUT_AUXDATAH)
#else
    MISSING(USB_EP_TABLE_EP9OUT_AUXDATAH)
#endif

#ifdef USB_EP_TABLE_EP9OUT_AUXDATAL
    DEFINE(USB_EP_TABLE_EP9OUT_AUXDATAL)
#else
    MISSING(USB_EP_TABLE_EP9OUT_AUXDATAL)
#endif

#ifdef USB_EP_TABLE_EP9OUT_CNTH
    DEFINE(USB_EP_TABLE_EP9OUT_CNTH)
#else
    MISSING(USB_EP_TABLE_EP9OUT_CNTH)
#endif

#ifdef USB_EP_TABLE_EP9OUT_CNTL
    DEFINE(USB_EP_TABLE_EP9OUT_CNTL)
#else
    MISSING(USB_EP_TABLE_EP9OUT_CNTL)
#endif

#ifdef USB_EP_TABLE_EP9OUT_CTRL
    DEFINE(USB_EP_TABLE_EP9OUT_CTRL)
#else
    MISSING(USB_EP_TABLE_EP9OUT_CTRL)
#endif

#ifdef USB_EP_TABLE_EP9OUT_DATAPTRH
    DEFINE(USB_EP_TABLE_EP9OUT_DATAPTRH)
#else
    MISSING(USB_EP_TABLE_EP9OUT_DATAPTRH)
#endif

#ifdef USB_EP_TABLE_EP9OUT_DATAPTRL
    DEFINE(USB_EP_TABLE_EP9OUT_DATAPTRL)
#else
    MISSING(USB_EP_TABLE_EP9OUT_DATAPTRL)
#endif

#ifdef USB_EP_TABLE_EP9OUT_STATUS
    DEFINE(USB_EP_TABLE_EP9OUT_STATUS)
#else
    MISSING(USB_EP_TABLE_EP9OUT_STATUS)
#endif

#ifdef USB_EP_TABLE_FRAMENUMH
    DEFINE(USB_EP_TABLE_FRAMENUMH)
#else
    MISSING(USB_EP_TABLE_FRAMENUMH)
#endif

#ifdef USB_EP_TABLE_FRAMENUML
    DEFINE(USB_EP_TABLE_FRAMENUML)
#else
    MISSING(USB_EP_TABLE_FRAMENUML)
#endif

#ifdef USB_FIFORP
    DEFINE(USB_FIFORP)
#else
    MISSING(USB_FIFORP)
#endif

#ifdef USB_FIFOWP
    DEFINE(USB_FIFOWP)
#else
    MISSING(USB_FIFOWP)
#endif

#ifdef USB_INTCTRLA
    DEFINE(USB_INTCTRLA)
#else
    MISSING(USB_INTCTRLA)
#endif

#ifdef USB_INTCTRLB
    DEFINE(USB_INTCTRLB)
#else
    MISSING(USB_INTCTRLB)
#endif

#ifdef USB_INTFLAGSACLR
    DEFINE(USB_INTFLAGSACLR)
#else
    MISSING(USB_INTFLAGSACLR)
#endif

#ifdef USB_INTFLAGSASET
    DEFINE(USB_INTFLAGSASET)
#else
    MISSING(USB_INTFLAGSASET)
#endif

#ifdef USB_INTFLAGSBCLR
    DEFINE(USB_INTFLAGSBCLR)
#else
    MISSING(USB_INTFLAGSBCLR)
#endif

#ifdef USB_INTFLAGSBSET
    DEFINE(USB_INTFLAGSBSET)
#else
    MISSING(USB_INTFLAGSBSET)
#endif

#ifdef USB_STATUS
    DEFINE(USB_STATUS)
#else
    MISSING(USB_STATUS)
#endif

#ifdef USIBR
    DEFINE(USIBR)
#else
    MISSING(USIBR)
#endif

#ifdef USICR
    DEFINE(USICR)
#else
    MISSING(USICR)
#endif

#ifdef USIDR
    DEFINE(USIDR)
#else
    MISSING(USIDR)
#endif

#ifdef USIPP
    DEFINE(USIPP)
#else
    MISSING(USIPP)
#endif

#ifdef USISR
    DEFINE(USISR)
#else
    MISSING(USISR)
#endif

#ifdef USPCR
    DEFINE(USPCR)
#else
    MISSING(USPCR)
#endif

#ifdef USPDR
    DEFINE(USPDR)
#else
    MISSING(USPDR)
#endif

#ifdef USPSR
    DEFINE(USPSR)
#else
    MISSING(USPSR)
#endif

#ifdef USR
    DEFINE(USR)
#else
    MISSING(USR)
#endif

#ifdef VADAC0
    DEFINE(VADAC0)
#else
    MISSING(VADAC0)
#endif

#ifdef VADAC1
    DEFINE(VADAC1)
#else
    MISSING(VADAC1)
#endif

#ifdef VADAC2
    DEFINE(VADAC2)
#else
    MISSING(VADAC2)
#endif

#ifdef VADAC3
    DEFINE(VADAC3)
#else
    MISSING(VADAC3)
#endif

#ifdef VADC
    DEFINE(VADC)
#else
    MISSING(VADC)
#endif

#ifdef VADCH
    DEFINE(VADCH)
#else
    MISSING(VADCH)
#endif

#ifdef VADCL
    DEFINE(VADCL)
#else
    MISSING(VADCL)
#endif

#ifdef VADCSR
    DEFINE(VADCSR)
#else
    MISSING(VADCSR)
#endif

#ifdef VADIC
    DEFINE(VADIC)
#else
    MISSING(VADIC)
#endif

#ifdef VADICH
    DEFINE(VADICH)
#else
    MISSING(VADICH)
#endif

#ifdef VADICL
    DEFINE(VADICL)
#else
    MISSING(VADICL)
#endif

#ifdef VADMUX
    DEFINE(VADMUX)
#else
    MISSING(VADMUX)
#endif

#ifdef VBAT_BACKUP0
    DEFINE(VBAT_BACKUP0)
#else
    MISSING(VBAT_BACKUP0)
#endif

#ifdef VBAT_BACKUP1
    DEFINE(VBAT_BACKUP1)
#else
    MISSING(VBAT_BACKUP1)
#endif

#ifdef VBAT_CTRL
    DEFINE(VBAT_CTRL)
#else
    MISSING(VBAT_CTRL)
#endif

#ifdef VBAT_STATUS
    DEFINE(VBAT_STATUS)
#else
    MISSING(VBAT_STATUS)
#endif

#ifdef VCOTUNE
    DEFINE(VCOTUNE)
#else
    MISSING(VCOTUNE)
#endif

#ifdef VELACC1
    DEFINE(VELACC1)
#else
    MISSING(VELACC1)
#endif

#ifdef VELACC2
    DEFINE(VELACC2)
#else
    MISSING(VELACC2)
#endif

#ifdef VELACC3
    DEFINE(VELACC3)
#else
    MISSING(VELACC3)
#endif

#ifdef VELCVEL
    DEFINE(VELCVEL)
#else
    MISSING(VELCVEL)
#endif

#ifdef VELDEC1
    DEFINE(VELDEC1)
#else
    MISSING(VELDEC1)
#endif

#ifdef VELDEC2
    DEFINE(VELDEC2)
#else
    MISSING(VELDEC2)
#endif

#ifdef VELDEC3
    DEFINE(VELDEC3)
#else
    MISSING(VELDEC3)
#endif

#ifdef VELHI1
    DEFINE(VELHI1)
#else
    MISSING(VELHI1)
#endif

#ifdef VELHI2
    DEFINE(VELHI2)
#else
    MISSING(VELHI2)
#endif

#ifdef VELHI3
    DEFINE(VELHI3)
#else
    MISSING(VELHI3)
#endif

#ifdef VELIFLG
    DEFINE(VELIFLG)
#else
    MISSING(VELIFLG)
#endif

#ifdef VELIMSK
    DEFINE(VELIMSK)
#else
    MISSING(VELIMSK)
#endif

#ifdef VELLOW1
    DEFINE(VELLOW1)
#else
    MISSING(VELLOW1)
#endif

#ifdef VELLOW2
    DEFINE(VELLOW2)
#else
    MISSING(VELLOW2)
#endif

#ifdef VELLOW3
    DEFINE(VELLOW3)
#else
    MISSING(VELLOW3)
#endif

#ifdef VELSTB
    DEFINE(VELSTB)
#else
    MISSING(VELSTB)
#endif

#ifdef VELTVEL
    DEFINE(VELTVEL)
#else
    MISSING(VELTVEL)
#endif

#ifdef VELVGCTL
    DEFINE(VELVGCTL)
#else
    MISSING(VELVGCTL)
#endif

#ifdef VERSION_NUM
    DEFINE(VERSION_NUM)
#else
    MISSING(VERSION_NUM)
#endif

#ifdef VLMCSR
    DEFINE(VLMCSR)
#else
    MISSING(VLMCSR)
#endif

#ifdef VMCSR
    DEFINE(VMCSR)
#else
    MISSING(VMCSR)
#endif

#ifdef VPORT0_DIR
    DEFINE(VPORT0_DIR)
#else
    MISSING(VPORT0_DIR)
#endif

#ifdef VPORT0_IN
    DEFINE(VPORT0_IN)
#else
    MISSING(VPORT0_IN)
#endif

#ifdef VPORT0_INTFLAGS
    DEFINE(VPORT0_INTFLAGS)
#else
    MISSING(VPORT0_INTFLAGS)
#endif

#ifdef VPORT0_OUT
    DEFINE(VPORT0_OUT)
#else
    MISSING(VPORT0_OUT)
#endif

#ifdef VPORT1_DIR
    DEFINE(VPORT1_DIR)
#else
    MISSING(VPORT1_DIR)
#endif

#ifdef VPORT1_IN
    DEFINE(VPORT1_IN)
#else
    MISSING(VPORT1_IN)
#endif

#ifdef VPORT1_INTFLAGS
    DEFINE(VPORT1_INTFLAGS)
#else
    MISSING(VPORT1_INTFLAGS)
#endif

#ifdef VPORT1_OUT
    DEFINE(VPORT1_OUT)
#else
    MISSING(VPORT1_OUT)
#endif

#ifdef VPORT2_DIR
    DEFINE(VPORT2_DIR)
#else
    MISSING(VPORT2_DIR)
#endif

#ifdef VPORT2_IN
    DEFINE(VPORT2_IN)
#else
    MISSING(VPORT2_IN)
#endif

#ifdef VPORT2_INTFLAGS
    DEFINE(VPORT2_INTFLAGS)
#else
    MISSING(VPORT2_INTFLAGS)
#endif

#ifdef VPORT2_OUT
    DEFINE(VPORT2_OUT)
#else
    MISSING(VPORT2_OUT)
#endif

#ifdef VPORT3_DIR
    DEFINE(VPORT3_DIR)
#else
    MISSING(VPORT3_DIR)
#endif

#ifdef VPORT3_IN
    DEFINE(VPORT3_IN)
#else
    MISSING(VPORT3_IN)
#endif

#ifdef VPORT3_INTFLAGS
    DEFINE(VPORT3_INTFLAGS)
#else
    MISSING(VPORT3_INTFLAGS)
#endif

#ifdef VPORT3_OUT
    DEFINE(VPORT3_OUT)
#else
    MISSING(VPORT3_OUT)
#endif

#ifdef VREG_CTRL
    DEFINE(VREG_CTRL)
#else
    MISSING(VREG_CTRL)
#endif

#ifdef WDTCKD
    DEFINE(WDTCKD)
#else
    MISSING(WDTCKD)
#endif

#ifdef WDTCLR
    DEFINE(WDTCLR)
#else
    MISSING(WDTCLR)
#endif

#ifdef WDTCR
    DEFINE(WDTCR)
#else
    MISSING(WDTCR)
#endif

#ifdef WDTCSR
    DEFINE(WDTCSR)
#else
    MISSING(WDTCSR)
#endif

#ifdef WDT_CTRL
    DEFINE(WDT_CTRL)
#else
    MISSING(WDT_CTRL)
#endif

#ifdef WDT_STATUS
    DEFINE(WDT_STATUS)
#else
    MISSING(WDT_STATUS)
#endif

#ifdef WDT_WINCTRL
    DEFINE(WDT_WINCTRL)
#else
    MISSING(WDT_WINCTRL)
#endif

#ifdef WUTCSR
    DEFINE(WUTCSR)
#else
    MISSING(WUTCSR)
#endif

#ifdef XAH_CTRL_0
    DEFINE(XAH_CTRL_0)
#else
    MISSING(XAH_CTRL_0)
#endif

#ifdef XAH_CTRL_1
    DEFINE(XAH_CTRL_1)
#else
    MISSING(XAH_CTRL_1)
#endif

#ifdef XDIV
    DEFINE(XDIV)
#else
    MISSING(XDIV)
#endif

#ifdef XMCRA
    DEFINE(XMCRA)
#else
    MISSING(XMCRA)
#endif

#ifdef XMCRB
    DEFINE(XMCRB)
#else
    MISSING(XMCRB)
#endif

#ifdef XOSC_CTRL
    DEFINE(XOSC_CTRL)
#else
    MISSING(XOSC_CTRL)
#endif